@@ -57,6 +57,7 @@ import java.io.IOException;
 import java.io.InputStream;
 import java.io.InputStreamReader;
 import java.io.OutputStreamWriter;
+import java.io.PrintStream;
 import java.io.Writer;
 import java.rmi.RemoteException;
 import java.util.HashMap;
@@ -89,8 +90,7 @@ import com.openexchange.guard.management.maintenance.internal.TestUserResult;
  */
 public class Guard extends AbstractRmiCLI<Void> {
 
-    private final char[] optionsWithArgs = { 't', 'e', 'n', 'u', 'j', 'w', 'o', 'x', 'g', 'c' };
-
+    private final char[] optionsWithArgs = { 't', 'e', 'n', 'u', 'j', 'w', 'o', 'x', 'g', 'm', 'r', 'c' };
 
     private static final String serviceURL = "service:jmx:rmi:///jndi/rmi://";
 
@@ -125,6 +125,9 @@ public class Guard extends AbstractRmiCLI<Void> {
             if (arg.trim().equals("-D") || arg.trim().equals("--delete")) {
                 return true;
             }
+            if (arg.trim().equals("-m") || arg.trim().equals("--import")) {
+                return true;
+            }
         }
         return false;
     }
@@ -153,14 +156,18 @@ public class Guard extends AbstractRmiCLI<Void> {
         options.addOption("t", "test", true, "Test the specified e-mail address against the MailResolver\ne.g. guard --test john@somewhere.com");
         options.addOption("e", "reset", true, "Resets the specified e-mail address and sends a new password to the user\ne.g. guard --reset john@somewhere.com");
         options.addOption("n", "remove-pin", true, "Removes the PIN for the specified user\ne.g. guard --remove-pin john@somewhere.com");
-        options.addOption("u", "upgrade", true, "Upgrades the specified guest account to an OX account\ne.g. guard --upgrade john@somewhere.com");
+        options.addOption("u", "upgrade", true, "Upgrades the specified guest account to an OX account\ne.g. guard --upgrade john@somewhere.com\nIf error, try specifying id and context of new user\nguard --upgrade john@somwhere.com --id 2 --context 3");
+        options.addOption(null, "context", true, "Context of a user");
+        options.addOption(null, "id", true, "ID of a user");
         options.addOption("D", "delete", true, "Deletes a specified Guard user");
         options.addOption("g", "guestreset", true, "Reset a Guest account.  Creates new keys for the user.  If has password recovery, must specify force to reset account.\ne.g. guard --g john@somewhere [-f]");
         options.addOption("f", "force", false, "Force.  Used with guestreset");
+        options.addOption("m", "import", true, "Import a System PGP Public Key");
         options.addOption("j", "jmx-user", true, "JMX user");
         options.addOption("w", "jmx-password", true, "JMX password");
         options.addOption("o", "jmx-port", true, "JMX port (default: '9999')");
         options.addOption("x", "jmx-host", true, "JMX host (default: 'localhost')");
+        options.addOption("r", "repair", true, "Check database integrity and repair if able.  Specify argument update or dryRun \ne.g. guard -r update");
     }
 
     /*
@@ -218,7 +225,9 @@ public class Guard extends AbstractRmiCLI<Void> {
                 changeUser(createProxy(jmxHost, jmxPort, jmxUser, jmxPassword), email, newEmail);
             } else if (cmd.hasOption('u')) {
                 String email = cmd.getOptionValue('u');
-                upgrade(createProxy(jmxHost, jmxPort, jmxUser, jmxPassword), email);
+                String cid = cmd.getOptionValue("context");
+                String userid = cmd.getOptionValue("id");
+                upgrade(createProxy(jmxHost, jmxPort, jmxUser, jmxPassword), email, userid, cid);
             } else if (cmd.hasOption('t')) {
                 String email = cmd.getOptionValue('t');
                 test(createProxy(jmxHost, jmxPort, jmxUser, jmxPassword), email);
@@ -228,6 +237,17 @@ public class Guard extends AbstractRmiCLI<Void> {
             } else if (cmd.hasOption('D')) {
                 String email = cmd.getOptionValue('D');
                 delete(createProxy(jmxHost, jmxPort, jmxUser, jmxPassword), email);
+            } else if (cmd.hasOption('m')) {
+                String file = cmd.getOptionValue('m');
+                importPublic (createProxy(jmxHost, jmxPort, jmxUser, jmxPassword), file);
+            } else if (cmd.hasOption('r')) {
+                String dry = cmd.getOptionValue('r');
+                if (dry != null && dry.toLowerCase().startsWith("update")) {
+                    repairDatabase(createProxy(jmxHost, jmxPort, jmxUser, jmxPassword), false);
+                } else if (dry != null && dry.toLowerCase().startsWith("dry")) {
+                    System.out.println("Dry run");
+                    repairDatabase(createProxy(jmxHost, jmxPort, jmxUser, jmxPassword), true);
+                }
             } else {
                 printHelp(options);
                 System.exit(0);
@@ -260,8 +280,8 @@ public class Guard extends AbstractRmiCLI<Void> {
         System.out.println("PIN has been removed.");
     }
 
-    private void upgrade(GuardMaintenanceMBean proxy, String email) throws MBeanException {
-        proxy.upgrade(email);
+    private void upgrade(GuardMaintenanceMBean proxy, String email, String userid, String cid) throws MBeanException {
+        proxy.upgrade(email, userid, cid);
         System.out.println(String.format("Guest (%s) has been upgraded.", email));
     }
 
@@ -275,6 +295,11 @@ public class Guard extends AbstractRmiCLI<Void> {
         System.out.println(String.format("Guest (%s) has been reset.", email));
     }
 
+    private void importPublic (GuardMaintenanceMBean proxy, String filename) throws MBeanException {
+        proxy.importPublic(filename);
+        System.out.println("PGP Key Imported");
+    }
+
     private void test(GuardMaintenanceMBean proxy, String email) throws MBeanException {
         TestUserResult testResult = proxy.testUser(email);
         System.out.println("User id: " + testResult.getUserId());
@@ -283,6 +308,12 @@ public class Guard extends AbstractRmiCLI<Void> {
         System.out.println("Name: " + testResult.getDisplayName());
     }
 
+    private void repairDatabase (GuardMaintenanceMBean proxy, boolean dryRun) throws MBeanException {
+        StringBuilder results = proxy.repair(dryRun);
+        System.out.println(results);
+        System.out.println("Repair procedure complete");
+    }
+
     private void changeUser(GuardMaintenanceMBean proxy, String email, String newEmail) throws MBeanException {
         if (email == null) {
             System.out.println("Identifying email address required.  Please enter with option -e");
@@ -383,9 +414,14 @@ public class Guard extends AbstractRmiCLI<Void> {
         File masterPasswordFile = new File(f, "oxguardpass");
         System.out.print("Saving to " + masterPasswordFile.getAbsolutePath() + "...");
         Writer writer = new BufferedWriter(new OutputStreamWriter(new FileOutputStream(masterPasswordFile), "UTF-8"));
-        writer.write("MC" + mcSalt + "\n");
-        writer.write("RC" + rcSalt + "\n");
-        writer.close();
+        try {
+            writer.write("MC" + mcSalt + "\n");
+            writer.write("RC" + rcSalt + "\n");
+        } finally {
+            if (writer != null) {
+                writer.close();
+            }
+        }
 
         System.out.println("done.");
 
@@ -521,5 +557,6 @@ public class Guard extends AbstractRmiCLI<Void> {
         public String getOutput() throws InterruptedException {
             return output.take();
         }
+
     }
 }
