@@ -67,6 +67,7 @@ import org.slf4j.LoggerFactory;
 public final class CipherUtil {
 
     private static final Logger logger = LoggerFactory.getLogger(CipherUtil.class);
+    protected static final char[] encoding = "ybndrfg8ejkmcpqxot1uwisza345h769".toCharArray();
 
     /**
      * Get the SHA hash from the specified password.
@@ -134,4 +135,63 @@ public final class CipherUtil {
 
         return Base64.encodeBase64String(salt);
     }
+
+    public static String getEmailUserHash (String email) {
+        if (email.contains("@")) {
+            String username = email.substring(0, email.indexOf("@"));
+            return getZbaseSHA (username);
+        }
+        return "";
+    }
+
+
+    /**
+     * ZBase32 Encoding used in WebKey service
+     * As described RFC6189, section 5.1.6
+     * @param in
+     * @return
+     */
+    public static String encodeZBase32(byte[] in) {
+        StringBuilder sb = new StringBuilder();
+
+        for (int i = 0; i < in.length; i += 5) {
+            sb.append(
+                    encoding[((in[i] & 0xff) >> 3) & 0x1f]
+                );
+            sb.append(
+                    encoding[(((in[i] & 0xff) << 2) | ((in[i + 1] & 0xff) >> 6)) & 0x1f]
+                );
+            sb.append(
+                    encoding[((in[i + 1] & 0xff) >> 1) & 0x1f]
+                );
+            sb.append(
+                    encoding[(((in[i + 1] & 0xff) << 4) | ((in[i + 2] & 0xff) >> 4)) & 0x1f]
+                );
+            sb.append(
+                    encoding[(((in[i + 2] & 0xff) << 1) | ((in[i + 3] & 0xff) >> 7)) & 0x1f]
+                );
+            sb.append(
+                    encoding[((in[i + 3] & 0xff) >> 2) & 0x1f]
+                );
+            sb.append(
+                    encoding[(((in[i + 3] & 0xff) << 3) | ((in[i + 4] & 0xff) >> 5)) & 0x1f]
+                );
+            sb.append(
+                    encoding[(in[i + 4] & 0xff) & 0x1f]
+                );
+        }
+        return (sb.toString());
+    }
+
+    public static String getZbaseSHA (String data) {
+        MessageDigest crypt;
+        try {
+            crypt = MessageDigest.getInstance("SHA-1");
+            crypt.update(data.toLowerCase().getBytes("UTF-8"));
+            return (encodeZBase32(crypt.digest()));
+        } catch (NoSuchAlgorithmException | UnsupportedEncodingException e) {
+            logger.error("Problem computing SHA hash", e);
+            return null;
+        }
+    }
 }
