@@ -72,6 +72,12 @@ public final class GuardAuthExceptionMessages implements LocalizableStrings {
     /** Returned when a user is authenticated but the requested operation is not permitted **/
     public static final String FORBIDDEN_MSG = "The operation is not permitted.";
 
+    /** Retunred when a client is not sending authentication information **/
+    public static final String AUTH_MISSING_MSG = "Authentication parameters are missing";
+
+    /** Returned if error obtaining session token during authentication */
+    public static final String TOKEN_ERROR_MSG = "Unable to obtain a session token.";
+
     /**
      * Prevent instantiation.
      */
