@@ -94,10 +94,12 @@ public enum GuardProperty {
      */
     badPasswordCount(5),
     /**
-     * Specifies how long e-mails sent to external users should be cached in the Guard backend.
-     * This caching is used for fast access and easy decoding of the encrypted mail content.
+     * Base domain defines the domain used to generate support links.
+     * For example, a URL may be constructed using
+     * https://baseDomain/uiWebPath/link
+     * If empty, externalEmailUrl used
      */
-    cacheDays(30),
+    baseDomain(""),
     /**
      * The timeout for all HTTP(S) connections in ms
      */
@@ -144,8 +146,6 @@ public enum GuardProperty {
      * their webmail to read the encrypted item. This setting is used to point to a generic
      * log in for the webmail system. Sent to multiple recipients, so not customised to
      * the individual recipient. OK domain:port. HTTPS will always be added
-     * This value will be used as the default unless over-written by cascade value
-     * 'com.openexchange.guard.externalOxUI'
      */
     externalEmailURL("example.com"),
     /**
@@ -160,6 +160,13 @@ public enum GuardProperty {
      */
     externalReaderPath("example.com/guard/reader/reader.html"),
     externalReaderURL,
+    /**
+     * If the PGP message does not have MDC tags attached, either 1) message is rejected
+     * or 2) a warning message is displayed to the user and the email is converted to
+     * plaintext.  Default is false, which displays the message.  Setting to true
+     * will result in emails being rejected if the MDC data doesn't exist
+     */
+    failForMissingMDC(false),
     /**
      * The directory used for buffering uploaded data.
      * Default: empty which falls back to use "java.io.tmpdir"
@@ -176,6 +183,16 @@ public enum GuardProperty {
      */
     forceTLSForHKPSRV(false),
     fromEmail,
+    /**
+     * Guest Caching.  Enabled local caching for Guest users/data
+     */
+    guestCaching(true),
+
+    /**
+     * Guest email accounts that aren't used after this number of days are cleaned.  The mail items are removed, and guest scheduled for removal.
+     *
+     */
+    guestCleanedAfterDaysOfInactivity(365),
     /**
      * Specifies the SMTP server password.
      */
@@ -277,16 +294,18 @@ public enum GuardProperty {
      */
     noDeletePrivate(false),
     /**
-     * If the user should be able to delete the password recovery
-     * then enable here. There will be no way to retrieve the
-     * password if the recovery is deleted and the user forgets
-     * their password
-     * can also set configuration cascade value
-     * 'com.openexchange.capability.guard-nodeleterecovery=true'
-     * If either is true, then no recovery will be available
-     * Default = true
+     * Option to deny users the ability to delete the password recovery.
+     * There will be no way to retrieve the password
+     * if the recovery is deleted and the user forgets
+     * their password.  Users, though, may want to delete the recovery for
+     * security reasons.
+     * Can also set configuration cascade value
+     * com.openexchange.capability.guard-nodeleterecovery=true
+     * If either is true, then the user will not be able to
+     * delete their password recovery
+     * Default: false, allowing the user the option to delete
      */
-    noDeleteRecovery(true),
+    noDeleteRecovery(false),
     /**
      * If password recovery is disabled, then there will be no way to
      * recover passwords. This will increase the security of the
@@ -352,6 +371,11 @@ public enum GuardProperty {
      * Specifies the display name for the password reset e-mail
      */
     passwordFromName,
+    /**
+     * Optional PIN service for Guest emails.  Sender assigns a PIN to the newly created Guest account.
+     * The sender must get this PIN to the user using another method (phone, text, etc)
+     */
+    pinEnabled(false),
     /**
      * PGP Key's from the remote servers are stored in a cache for a set period of time
      * before the remote servers are queried again. Set the time for the cache here
@@ -395,6 +419,12 @@ public enum GuardProperty {
      */
     untrustedPGPDirectory(""),
 
+    /**
+     * Timeout when searching for remote keys.  Total elapsed time in milliseconds before giving up search for keys.
+     * This time should be less than the timeout between middleware and Guard
+     */
+    remoteKeyLookupTimeout(10000),
+
     /**
      * Specifies the hostname of the Open-Xchange REST API server. The REST API is a
      * service on the Open-Xchange backend. Use 'localhost' in case that the Guard service
@@ -477,6 +507,39 @@ public enum GuardProperty {
      * Time in hours
      */
     temporaryTokenLifespan(48),
+    /**
+     * A threshold value which defines which key sources are trusted.
+     * Every key source with a trust value equals or higher than this value is considered to be marked as "trusted".
+     */
+    trustThreshold(4, GuardProperty.PREFIX + "keySources."),
+    /**
+     * The trust level for keys created by OX Guard
+     */
+    trustLevelGuard(5, GuardProperty.PREFIX + "keySources."),
+    /**
+     * The trust level for keys uploaded by a user
+     */
+    trustLevelGuardUserUploaded(4, GuardProperty.PREFIX + "keySources."),
+    /**
+     * The trust level for keys uploaded by a user and shared among users in the same context
+     */
+    trustLevelGuardUserShared(3, GuardProperty.PREFIX + "keySources."),
+    /**
+     * The trust level for keys fetched from public HKP servers
+     */
+    trustLevelHKPPublicServer(1, GuardProperty.PREFIX + "keySources."),
+    /**
+     * The trust level for keys fetched from HKP servers marked as trusted
+     */
+    trustLevelHKPTrustedServer(5, GuardProperty.PREFIX + "keySources."),
+    /**
+     * The trust level for keys fetched from HKP servers queried via SRV DNS record
+     */
+    trustLevelHKPSRVServer(4, GuardProperty.PREFIX + "keySources."),
+    /**
+     * The trust level for keys fetched from HKP servers queried via DNSSEC protected SRV DNS record
+     */
+    trustLevelHKPSRVDNSSECServer(4, GuardProperty.PREFIX + "keySources."),
     /**
      * Defines the version of the 'Upgrader'
      */
