@@ -57,7 +57,6 @@ import com.openexchange.config.ConfigurationService;
 import com.openexchange.config.DefaultInterests;
 import com.openexchange.config.Interests;
 import com.openexchange.config.cascade.ComposedConfigProperty;
-import com.openexchange.config.cascade.ConfigProperty;
 import com.openexchange.config.cascade.ConfigView;
 import com.openexchange.config.cascade.ConfigViewFactory;
 import com.openexchange.exception.OXException;
@@ -240,11 +239,6 @@ public class GuardConfigurationServiceImpl implements GuardConfigurationService
         return (T) config.asMap().get(configKey);
     }
 
-    @Override
-	public String getContextSetStringProperty(GuardProperty property, int userId, int contextId, String defaultValue) throws OXException {
-    	return getContextSetProperty(property.getFQPropertyName(), userId, contextId, String.class, defaultValue);
-    }
-
     /**
      * Gets the value T of specified server property and coerce it to the specified type T
      *
@@ -268,31 +262,6 @@ public class GuardConfigurationServiceImpl implements GuardConfigurationService
         return defaultValue;
     }
 
-    
-    private <T> T getContextSetProperty(String property, int userId, int contextId, Class<T> coerceTo, T defaultValue) {
-        if (contextId == 0) {
-            return defaultValue;
-        }
-        if (contextId < 0) {
-            contextId = -contextId;
-            userId = -1;
-        }
-        try {
-            ConfigViewFactory factory = Services.getService(ConfigViewFactory.class);
-            ConfigView view = factory.getView(userId, contextId);
-
-            ConfigProperty<T> p = view.property("contextSets", property, coerceTo);
-            if (!p.isDefined()) {
-                return defaultValue;
-            }
-
-            return p.get();
-        } catch (OXException e) {
-            logger.error("Error getting '{}' property for user '{}' in context '{}'. Returning the default value of '{}'", property, userId, contextId, defaultValue, e);
-        }
-        return defaultValue;
-
-    }
     /**
      * Get the value T of specified property for the specified user in the specified context and coerce it to the specified type T
      *
