@@ -65,6 +65,7 @@ import com.openexchange.guard.database.update.GuardCreateTableTask;
 import com.openexchange.guard.updater.ChangeOGKeyTableSizes;
 import com.openexchange.guard.updater.ChangePGPPublicKeySize;
 import com.openexchange.guard.updater.CreateMailvelopeTableTask;
+import com.openexchange.guard.updater.SetDBEngineUpdateTask;
 import com.openexchange.osgi.HousekeepingActivator;
 
 /**
@@ -99,7 +100,7 @@ public class GuardDatabaseActivator extends HousekeepingActivator {
 
         // Register update tasks for user schema
         registerService(UpdateTaskProviderService.class, new DefaultUpdateTaskProviderService(new GuardCreateTableTask(databaseService)));
-        registerService(UpdateTaskProviderService.class, new DefaultUpdateTaskProviderService(new ChangePGPPublicKeySize(databaseService), new CreateMailvelopeTableTask(databaseService), new ChangeOGKeyTableSizes(databaseService)));
+        registerService(UpdateTaskProviderService.class, new DefaultUpdateTaskProviderService(new ChangePGPPublicKeySize(), new CreateMailvelopeTableTask(databaseService), new ChangeOGKeyTableSizes(), new SetDBEngineUpdateTask()));
 
         GuardConfigurationService guardConfigService = getService(GuardConfigurationService.class);
         GuardDatabaseService guardDatabaseService = new GuardDatabaseServiceImpl(databaseService, guardConfigService, getService(AssignmentFactory.class));
