@@ -7,8 +7,10 @@ import java.util.Collection;
 import org.apache.http.HttpResponse;
 import org.apache.http.HttpStatus;
 import org.apache.http.client.HttpClient;
+import org.apache.http.client.config.RequestConfig;
 import org.apache.http.client.methods.HttpGet;
 import org.apache.http.client.utils.HttpClientUtils;
+import org.apache.http.impl.client.HttpClientBuilder;
 import org.apache.http.util.EntityUtils;
 import org.bouncycastle.openpgp.PGPPublicKeyRing;
 import org.slf4j.Logger;
@@ -85,6 +87,14 @@ public class HKPClient {
         this.tlsMode = tlsMode;
     }
 
+    private HttpClient getClient(int connectionTimeout) {
+        RequestConfig requestConfig = RequestConfig.custom()
+            .setConnectTimeout(connectionTimeout)
+            .setSocketTimeout(connectionTimeout)
+            .build();
+        return HttpClientBuilder.create().setDefaultRequestConfig(requestConfig).build();
+    }
+
     /**
      * Internal method to perform HTTP GET requests
      *
@@ -92,15 +102,15 @@ public class HKPClient {
      * @return response as string
      * @throws OXException
      */
-    private String doRequest(String url) throws OXException {
+    private String doRequest(String url, int timeout) throws OXException {
+        if (timeout <= 0) return null;  // Already timed out
         if(url.startsWith(HKP)) {
             url = url.replace(HKP, HTTP);
         }
         else if(url.startsWith(HKPS)) {
             url = url.replace(HKPS, HTTPS);
         }
-        HttpConnectionPoolService poolService = Services.getService(HttpConnectionPoolService.class);
-        HttpClient httpClient = poolService.getClient();
+        HttpClient httpClient = getClient(timeout);
         HttpGet getRequest = new HttpGet(url);
         HttpResponse response = null;
         try {
@@ -118,10 +128,15 @@ public class HKPClient {
                 throw HKPClientExceptionCodes.UNSUPPORTED.create();
             }
         } catch (IOException ste) {
-            LOG.warn("Unable to retrieve keys from server.", ste);
+            if (ste.getClass().equals(java.net.SocketTimeoutException.class)) {
+                LOG.warn("Timeout waiting for remote key server " + url + " - time remaining in lookup queue was " + timeout + "ms");
+            } else {
+                LOG.warn("Unable to retrieve keys from server.", ste);
+            }
         } finally {
             HttpClientUtils.closeQuietly(response);
             getRequest.releaseConnection();
+            HttpClientUtils.closeQuietly(httpClient);
         }
         return null;
     }
@@ -134,7 +149,7 @@ public class HKPClient {
      * @return the sever's response as string
      * @throws Exception
      */
-    private String index(String url, String email) throws Exception {
+    private String index(String url, String email, int timeout) throws Exception {
         if (!url.contains("lookup?")) {
             if (!url.endsWith("/")) {
                 url += "/";
@@ -143,11 +158,11 @@ public class HKPClient {
         }
         String queryUrl = url + HKP_OP_SEARCH + email;
         try {
-            String answer = doRequest(queryUrl);
+            String answer = doRequest(queryUrl, timeout);
             return (answer);
         } catch (OXException x) {
             if (HKPClientExceptionCodes.UNSUPPORTED.equals(x)) {
-                return (get(url, email));
+                return (get(url, email, timeout));
             }
         }
         return null;
@@ -161,7 +176,7 @@ public class HKPClient {
      * @return The requested key data as String or null if no such key was found
      * @throws Exception
      */
-    private String get(String url, String keyid) throws Exception {
+    private String get(String url, String keyid, int timeout) throws Exception {
         if (!url.contains("lookup?")) {
             if (!url.endsWith("/")) {
                 url += "/";
@@ -172,7 +187,7 @@ public class HKPClient {
         if (keyid.contains("@")) {
             params = HKP_OP_GETEMAIL + keyid;
         }
-        return doRequest(url + params);
+        return doRequest(url + params, timeout);
     }
 
     /**
@@ -199,7 +214,7 @@ public class HKPClient {
                 }
             }
             if (line.startsWith("uid")) {
-                if (line.contains(email)) {
+                if (email != null && line.toLowerCase().contains(email.toLowerCase())) {
                     if (!pubids.contains(pub)) {
                         pubids.add(pub);
                     }
@@ -271,16 +286,16 @@ public class HKPClient {
      * @return A list of public key rings found for the given email
      * @throws Exception
      */
-    public Collection<PGPPublicKeyRing> findKeys(String url, String email) throws OXException {
+    public Collection<PGPPublicKeyRing> findKeys(String url, String email, int timeout) throws OXException {
 
         ArrayList<PGPPublicKeyRing> ret = new ArrayList<PGPPublicKeyRing>();
         try {
-            String response = index(url, email);
+            String response = index(url, email, timeout);
             if (response != null && !response.isEmpty()) {
                 ArrayList<String> ids = parseIndexResponse(response, email);
                 if (ids.size() > 0) {
                     for (int j = 0; j < ids.size(); j++) {
-                        PGPPublicKeyRing ring = parseGetResponse(get(url, ids.get(j)));
+                        PGPPublicKeyRing ring = parseGetResponse(get(url, ids.get(j), timeout));
                         if (ring != null) {
                             ret.add(ring);
                         }
@@ -302,10 +317,10 @@ public class HKPClient {
      * @return A list of public key rings found for the given email
      * @throws Exception
      */
-    public Collection<PGPPublicKeyRing> findKeys(String host, int port, String email) throws OXException {
+    public Collection<PGPPublicKeyRing> findKeys(String host, int port, String email, int timeout) throws OXException {
 
         try {
-            return findKeys(getURL(host, port), email);
+            return findKeys(getURL(host, port), email, timeout);
         } catch (Exception e) {
             throw HKPClientExceptionCodes.UNEXPECTED_HKP_ERROR.create(e, e.getMessage());
         }
@@ -320,9 +335,9 @@ public class HKPClient {
      * @return the PublicKeyRing
      * @throws OXException
      */
-    public PGPPublicKeyRing getKeyById(String host, int port, String id) throws OXException {
+    public PGPPublicKeyRing getKeyById(String host, int port, String id, int timeout) throws OXException {
         try {
-            return parseGetResponse(get(getURL(host, port), id));
+            return parseGetResponse(get(getURL(host, port), id, timeout));
         } catch (Exception e) {
             throw HKPClientExceptionCodes.UNEXPECTED_HKP_ERROR.create(e, e.getMessage());
         }
@@ -337,9 +352,9 @@ public class HKPClient {
      * @return the PublicKeyRing
      * @throws OXException
      */
-    public PGPPublicKeyRing getKeyById(String url, String id) throws OXException {
+    public PGPPublicKeyRing getKeyById(String url, String id, int timeout) throws OXException {
         try {
-            return parseGetResponse(get(url, id));
+            return parseGetResponse(get(url, id, timeout));
         } catch (Exception e) {
             throw HKPClientExceptionCodes.UNEXPECTED_HKP_ERROR.create(e, e.getMessage());
         }
