@@ -1,20 +1,25 @@
 
 package com.openexchange.guard.hkpclient.services;
 
+import java.time.Duration;
+import java.time.Instant;
 import java.util.ArrayList;
 import java.util.Collection;
-import java.util.List;
+import java.util.Collections;
 import org.bouncycastle.openpgp.PGPPublicKey;
 import org.bouncycastle.openpgp.PGPPublicKeyRing;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import org.xbill.DNS.SRVRecord;
 import com.openexchange.exception.OXException;
+import com.openexchange.guard.dns.DNSResult;
 import com.openexchange.guard.dns.DNSService;
+import com.openexchange.guard.dns.ValidationResult;
 import com.openexchange.guard.exceptions.GuardCoreExceptionCodes;
 import com.openexchange.guard.hkpclient.client.HKPClient;
 import com.openexchange.guard.hkpclient.client.HKPClient.TLSMODE;
 import com.openexchange.guard.hkpclient.osgi.Services;
+import com.openexchange.guard.hkpclient.util.TimeTracker;
 
 /**
  *
@@ -25,11 +30,31 @@ import com.openexchange.guard.hkpclient.osgi.Services;
  */
 public class SRVHKPClientService implements HKPClientService {
 
-    private static final Logger logger = LoggerFactory.getLogger(SRVHKPClientService.class);
-    private static final String HKPS_SERVICE_NAME = "_hkps._tcp.";
-    private static final String HKP_SERVICE_NAME  = "_hkp._tcp.";
-    private final HKPClientService delegate;
-    private final boolean forceTLS;
+    private static final Logger                       logger            = LoggerFactory.getLogger(SRVHKPClientService.class);
+    private static final Collection<PGPPublicKeyRing> EMPTY_LIST        = Collections.emptyList();
+    private static final String                       HKPS_SERVICE_NAME = "_hkps._tcp.";
+    private static final String                       HKP_SERVICE_NAME  = "_hkp._tcp.";
+    private final HKPClientService                    delegate;
+    private final boolean                             forceTLS;
+
+    private class QueryResult {
+
+        private final Collection<PGPPublicKeyRing> result;
+        private final ValidationResult             validationResult;
+
+        public QueryResult(Collection<PGPPublicKeyRing> result, ValidationResult validationResult) {
+            this.result = Collections.unmodifiableCollection(result);
+            this.validationResult = validationResult;
+        }
+
+        public Collection<PGPPublicKeyRing> getResult() {
+            return result;
+        }
+
+        public ValidationResult getValidationResult() {
+            return validationResult;
+        }
+    }
 
     /**
      *
@@ -51,6 +76,21 @@ public class SRVHKPClientService implements HKPClientService {
         this.forceTLS = forceTLS;
     }
 
+    /**
+     * Internal method to determine the TLS mode.
+     * <br>
+     * TLS is used if forced by the caller, or if the <code>serviceName</code> parameter is equals {@link #HKPS_SERVICE_NAME}
+     *
+     * @param serviceName The service name used to query keys
+     * @return True if the usage of TLS is mandatory, false if not mandatory.
+     */
+    private boolean isForceTLS(String serviceName) {
+        if (forceTLS || (serviceName != null && serviceName.equals(HKPS_SERVICE_NAME))) {
+            return true;
+        }
+        return false;
+    }
+
     /**
      * Internal method to query HKP servers which were configured in the email-domain's DNS SRV record
      *
@@ -59,34 +99,26 @@ public class SRVHKPClientService implements HKPClientService {
      * @return a list of found PGP key rings for the given email, an empty collection if no keys were found or the email's domain has no HKP SRV set
      * @throws Exception
      */
-    private Collection<PGPPublicKeyRing> findForSRVRecords(String clientToken, String email) throws Exception {
-        TLSMODE tlsMode = forceTLS ? TLSMODE.TLS : TLSMODE.BY_PORT;
+    private QueryResult findForSRVRecords(String serviceName, String clientToken, String email, int timeout) throws Exception {
         DNSService dnsService = Services.getService(DNSService.class);
-        List<SRVRecord> records = dnsService.getSrvs(HKPS_SERVICE_NAME, email);
-        if(records.isEmpty()) {
-            records = dnsService.getSrvs(HKP_SERVICE_NAME, email);
-        }
-        else {
-            //always force TLS for HKPS
-            tlsMode = TLSMODE.TLS;
-        }
+        DNSResult result = dnsService.getSrvs(serviceName, email);
 
         Collection<PGPPublicKeyRing> rings = new ArrayList<PGPPublicKeyRing>();
         int current = 0;
         SRVRecord nextcheck;
-        while ((nextcheck = dnsService.findNext(current, records)) != null) {
+        while ((nextcheck = dnsService.findNext(current, result.getResultRecords())) != null) {
             String target = nextcheck.getTarget().toString();
             if (target.endsWith(".")) {
                 target = target.substring(0, target.length() - 1);
             }
             int port = nextcheck.getPort();
-            rings = new HKPClient(clientToken, tlsMode).findKeys(target, port, email);
+            rings = new HKPClient(clientToken, isForceTLS(serviceName) ? TLSMODE.TLS : TLSMODE.BY_PORT).findKeys(target, port, email, timeout);
             if (rings != null) {
-                return rings;
+                return new QueryResult(rings, result.getValidationResult());
             }
             current = nextcheck.getPriority();
         }
-        return rings;
+        return new QueryResult(EMPTY_LIST, null);
     }
 
     /**
@@ -97,20 +129,27 @@ public class SRVHKPClientService implements HKPClientService {
      * @return A list of public keys for the email
      * @throws Exception
      */
-    private Collection<RemoteKeyResult> findAllInternal(String clientToken, String email) throws Exception {
+    private Collection<RemoteKeyResult> findAllInternal(String clientToken, String email, int timeout) throws Exception {
 
+        TimeTracker timer = new TimeTracker(timeout);
         //Searching DNS SRV records
         try {
-            Collection<PGPPublicKeyRing> results = findForSRVRecords(clientToken, email);
-            if (results != null && results.size() > 0) {
+            QueryResult result = findForSRVRecords(HKPS_SERVICE_NAME, clientToken, email, timeout);
+            if (result.getResult().isEmpty()) {
+                result = findForSRVRecords(HKP_SERVICE_NAME, clientToken, email, timeout);
+            }
+
+            if (result != null && result.getResult() != null && result.getResult().size() > 0) {
                 logger.debug("Remote keys found through SRV");
-                return RemoteKeyResult.createCollectionFrom(results, HKPKeySources.SRV_HKP_REMOTE_SERVER);
+                return RemoteKeyResult.createCollectionFrom(result.getResult(),
+                    result.getValidationResult() != null && result.getValidationResult()
+                        .isValidated() ? HKPKeySources.SRV_HKP_DNSSEC_REMOTE_SERVER : HKPKeySources.SRV_HKP_REMOTE_SERVER);
             }
         } catch (Exception e) {
             logger.error("Error querying remote HKP server form SRV record", e);
         }
         if (delegate != null) {
-            return delegate.find(clientToken, email);
+            return delegate.find(clientToken, email, timer.getRemaining());
         }
         return null;
     }
@@ -125,10 +164,11 @@ public class SRVHKPClientService implements HKPClientService {
      * @return
      * @throws Exception
      */
-    private RemoteKeyResult findInternal(String clientToken, Long id, String email) throws Exception {
+    private RemoteKeyResult findInternal(String clientToken, Long id, String email, int timeout) throws Exception {
         // To do SRV lookup, we have to search by email address to get domain
+        TimeTracker timer = new TimeTracker(timeout);
         if (email != null) {
-            Collection<RemoteKeyResult> res = findAllInternal(clientToken, email);
+            Collection<RemoteKeyResult> res = findAllInternal(clientToken, email, timeout);
             if (res != null && !res.isEmpty()) {  //If results, then search all to see if has the key by id
                 for (PGPPublicKeyRing ring : RemoteKeyResult.getRingsFrom(res)) {
                     PGPPublicKey found = ring.getPublicKey(id);
@@ -140,25 +180,25 @@ public class SRVHKPClientService implements HKPClientService {
         }
         RemoteKeyResult result = null;
         if (delegate != null) {
-            result = delegate.find(clientToken, email, id);
+            result = delegate.find(clientToken, email, id, timer.getRemaining());
         }
         return result;
 
     }
 
     @Override
-    public Collection<RemoteKeyResult> find(String clientToken, String email) throws OXException {
+    public Collection<RemoteKeyResult> find(String clientToken, String email, int timeout) throws OXException {
         try {
-            return findAllInternal(clientToken, email);
+            return findAllInternal(clientToken, email, timeout);
         } catch (Exception e) {
             throw GuardCoreExceptionCodes.IO_ERROR.create(e, e.getMessage());
         }
     }
 
     @Override
-    public RemoteKeyResult find(String clientToken, String email, Long id) throws OXException {
+    public RemoteKeyResult find(String clientToken, String email, Long id, int timeout) throws OXException {
         try {
-            return findInternal(clientToken, id, email);
+            return findInternal(clientToken, id, email, timeout);
         } catch (Exception e) {
             throw GuardCoreExceptionCodes.IO_ERROR.create(e, e.getMessage());
         }
