@@ -78,7 +78,6 @@ import com.openexchange.guard.keymanagement.commons.GuardKeys;
 import com.openexchange.guard.keymanagement.commons.PGPKeys;
 import com.openexchange.guard.keymanagement.commons.exceptions.KeysExceptionCodes;
 import com.openexchange.guard.keymanagement.commons.util.PGPUtil;
-import com.openexchange.guard.keymanagement.commons.util.UserIDCreator;
 import com.openexchange.guard.keymanagement.services.GuardKeyService;
 import com.openexchange.guard.keymanagement.services.GuardMasterKeyService;
 import com.openexchange.guard.keymanagement.services.KeyRecoveryService;
@@ -88,7 +87,7 @@ import com.openexchange.guard.keymanagement.services.impl.osgi.Services;
 import com.openexchange.guard.keymanagement.storage.KeyTableStorage;
 import com.openexchange.guard.keymanagement.storage.PGPKeysStorage;
 import com.openexchange.guard.user.GuardCapabilities;
-import com.openexchange.guard.user.GuardUserService;
+import com.openexchange.guard.user.OXUserService;
 import com.openexchange.pgp.keys.tools.PGPKeysUtil;
 import com.openexchange.tools.encoding.Base64;
 
@@ -145,7 +144,12 @@ public class GuardKeyServiceImpl implements GuardKeyService {
         int shard = 0;
         if (cid < 0) {
             GuardShardingService sharding = Services.getService(GuardShardingService.class);
-            shard = sharding.getShard(id, cid);
+            if(sharding.hasShard(id, cid)) {
+                shard = sharding.getShard(id, cid);
+            }
+            else {
+                return null;
+            }
         }
         KeyTableStorage ogKeyTableStorage = Services.getService(KeyTableStorage.class);
         return ogKeyTableStorage.getCurrentKeyForUser(id, cid, shard);
@@ -161,7 +165,12 @@ public class GuardKeyServiceImpl implements GuardKeyService {
         int shard = 0;
         if (cid < 0) {
             GuardShardingService sharding = Services.getService(GuardShardingService.class);
-            shard = sharding.getShard(id, cid);
+            if(sharding.hasShard(id, cid)) {
+                shard = sharding.getShard(id, cid);
+            }
+            else {
+                return null;
+            }
         }
         KeyTableStorage ogKeyTableStorage = Services.getService(KeyTableStorage.class);
         return ogKeyTableStorage.getKeyForUserById(id, cid, shard, Long.toString(keyId));
@@ -195,6 +204,21 @@ public class GuardKeyServiceImpl implements GuardKeyService {
         return null;
     }
 
+    /* (non-Javadoc)
+     * @see com.openexchange.guard.keymanagement.services.GuardKeyService#getKeysBySubKey(int, int, long)
+     */
+    @Override
+    public GuardKeys getKeysBySubKeyId(int id, int cid, long keyId) throws OXException {
+        PGPKeys keyMapping = Services.getService(PGPKeysStorage.class).getById(keyId);  // May be sub-key, key master for lookup
+        if(keyMapping != null) {
+             GuardKeys keys = getKeys(keyMapping.getKeyId());
+             if(keys != null && keys.getUserid() == id && keys.getContextid() == cid) {
+                 return keys;
+             }
+        }
+        return null;
+    }
+
     /* (non-Javadoc)
      * @see com.openexchange.guard.keymanagement.services.GuardKeyService#getAllKeys(int, int)
      */
@@ -497,17 +521,17 @@ public class GuardKeyServiceImpl implements GuardKeyService {
     }
 
     /* (non-Javadoc)
-     * @see com.openexchange.guard.keymanagement.services.GuardKeyService#delete(com.openexchange.guard.keymanagement.commons.GuardKeys)
+     * @see com.openexchange.guard.keymanagement.services.GuardKeyService#delete(com.openexchange.guard.keymanagement.commons.GuardKeys, java.lang.String, int, int)
      */
     @Override
-    public void delete(GuardKeys key, String password) throws OXException {
+    public void delete(GuardKeys key, String password ,int userId, int contextId) throws OXException {
 
-        GuardUserService userService = Services.getService(GuardUserService.class);
+        OXUserService userService = Services.getService(OXUserService.class);
         PGPKeysStorage pgpKeysStorage = Services.getService(PGPKeysStorage.class);
         KeyTableStorage ogKeyTableStorage = Services.getService(KeyTableStorage.class);
         EmailStorage ogEmailStorage = Services.getService(EmailStorage.class);
 
-        GuardCapabilities settings = userService.getGuardCapabilieties(key.getContextid(), key.getUserid());
+        GuardCapabilities settings = userService.getGuardCapabilieties(contextId, userId);
         if (settings.isNoDeletePrivate()) {
             LOG.info("Key deletion is disabled by configuration for user");
             throw GuardAuthExceptionCodes.FORBIDDEN.create();
@@ -559,34 +583,35 @@ public class GuardKeyServiceImpl implements GuardKeyService {
     @Override
     public void addUserId(GuardKeys key, String newUserId, String password) throws OXException {
         key = Objects.requireNonNull(key, "key must not be null");
-        PGPSecretKey signingSecretKey = PGPKeysUtil.getSigningKey(key.getPGPSecretKeyRing());
+        PGPSecretKey masterSecretKey = key.getPGPSecretKey();
+        if(masterSecretKey == null || masterSecretKey.isPrivateKeyEmpty()) {
+           throw GuardCoreExceptionCodes.KEY_NOT_FOUND_PRIVATE_MASTER.create();
+        }
 
         //Getting the private key used for singing
         PGPPrivateKey signingPrivateKey = null;
         try {
-            signingPrivateKey = PGPUtil.decodePrivate(signingSecretKey, password, key.getSalt());
+            signingPrivateKey = PGPUtil.decodePrivate(masterSecretKey, password, key.getSalt());
         } catch (PGPException e) {
             throw GuardAuthExceptionCodes.BAD_PASSWORD.create();
         }
 
-        //Adding the user id to the public key ring
-        PGPPublicKeyRing modifiedKeyRing = null;
-        try {            
-            modifiedKeyRing = UserIDCreator.addUID(key.getPGPPublicKeyRing(), signingPrivateKey, newUserId);
+        try {
+            //Adding the user id to the public key ring material
+            PGPPublicKeyRing modifiedPublicKeyRing = PGPKeysUtil.addUID(key.getPGPPublicKeyRing(), signingPrivateKey, newUserId);
+            key.setPGPPublicKeyRing(modifiedPublicKeyRing);
+            updateKeyMaterial(key);
         } catch (PGPException e) {
-            KeysExceptionCodes.PGP_ERROR.create(e, e.getMessage());
+            throw KeysExceptionCodes.PGP_ERROR.create(e, e.getMessage());
         }
 
-        //Set and update
-        key.setPGPPublicKeyRing(modifiedKeyRing);
-        updateKeyMaterial(key);
     }
 
     /* (non-Javadoc)
      * @see com.openexchange.guard.keymanagement.services.GuardKeyService#revokeKey(com.openexchange.guard.keymanagement.commons.GuardKeys, com.openexchange.guard.keymanagement.services.RevocationReason, java.lang.String)
      */
     @Override
-    public void revokeKey(GuardKeys key, RevocationReason revocationReason, String password) throws OXException {
+    public void revokeKey(GuardKeys key, long keyId, RevocationReason revocationReason, String password) throws OXException {
         key = Objects.requireNonNull(key, "key must not be null");
 
         //Getting the private key used for singing
@@ -599,7 +624,7 @@ public class GuardKeyServiceImpl implements GuardKeyService {
 
         PGPPublicKeyRing modifiedKeyRing = null;
         try {
-            modifiedKeyRing = PGPKeysUtil.revokeKey(privateKey, key.getPGPPublicKeyRing(), revocationReason.toString());
+            modifiedKeyRing = PGPKeysUtil.revokeKey(privateKey, key.getPGPPublicKeyRing(), keyId, revocationReason.toString());
         } catch (PGPException e) {
             KeysExceptionCodes.PGP_ERROR.create(e, e.getMessage());
         }
