@@ -176,6 +176,10 @@ public class KeyCreationServiceImpl implements KeyCreationService {
 
         try {
             long start = System.currentTimeMillis();
+            // Avoid key name being null
+            if (name == null || name.isEmpty()) {
+                name = email;
+            }
 
             String salt = CipherUtil.generateSalt();
             char[] pass = CipherUtil.getSHA(password, salt).toCharArray();
