@@ -51,6 +51,7 @@ package com.openexchange.guard.keymanagement.services.impl;
 
 import java.io.IOException;
 import java.util.ArrayList;
+import java.util.Collection;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Locale;
@@ -204,10 +205,20 @@ public class KeyImportServiceImpl implements KeyImportService {
         return keyMappings.size() > 0 ? keyMappings.get(0) : null;
     }
 
-    /* (non-Javadoc)
-     * @see com.openexchange.guard.keymanagement.services.KeyImportService#importPrivateKeyRing(int, int, org.bouncycastle.openpgp.PGPSecretKeyRing)
+    /**
+     * Internal method to import a PGPSecretKeyRing
+     *
+     * @param userId The ID of the user
+     * @param contextId The ID of the user's context
+     * @param email The user's email
+     * @param locale The user's locale
+     * @param password The password associated with the given secret key ring.
+     * @param newPassword The password to set during import
+     * @param secretKeyRing The key ring to import.
+     * @return The imported object
+     * @throws OXException
      */
-    private void importPrivateKeyRing(int userId, int contextId, String email, Locale locale, String password, String newPassword, PGPSecretKeyRing secretKeyRing) throws OXException {
+    private GuardKeys importPrivateKeyRing(int userId, int contextId, String email, Locale locale, String password, String newPassword, PGPSecretKeyRing secretKeyRing) throws OXException {
 
         GuardKeys newKeys = new GuardKeys();
         newKeys.setEmail(email);
@@ -268,7 +279,7 @@ public class KeyImportServiceImpl implements KeyImportService {
             GuardKeys existingKeys = guardKeyService.getKeys(existingKeyMapping.getKeyId());
 
             //Verify it has the same password
-            if(!PGPUtil.verifyPassword(existingKeys.getPGPSecretKeyRing(), newPassword, existingKeys.getSalt())) {
+            if(existingKeys.hasPrivateKey() && !PGPUtil.verifyPassword(existingKeys.getPGPSecretKeyRing(), newPassword, existingKeys.getSalt())) {
                 throw GuardAuthExceptionCodes.BAD_PASSWORD.create();
             }
 
@@ -297,12 +308,21 @@ public class KeyImportServiceImpl implements KeyImportService {
                 throw GuardCoreExceptionCodes.UNEXPECTED_ERROR.create("Error while merging keys");
             }
         }
+        return newKeys;
     }
 
-    /* (non-Javadoc)
-     * @see com.openexchange.guard.keymanagement.services.KeyImportService#importPublicKeyRing(int, int, org.bouncycastle.openpgp.PGPPublicKeyRing)
+    /**
+     * Internal method to import a PGPPublicKeyRing
+     *
+     * @param userId The ID of the user
+     * @param contextId The ID of the user's context
+     * @param email The email of the user
+     * @param locale The user's locale
+     * @param publicKeyRing The PublicKeyRing to import
+     * @return The imported object
+     * @throws OXException
      */
-    private void importPublicKeyRing(int userId, int contextId, String email, Locale locale, PGPPublicKeyRing publicKeyRing) throws OXException {
+    private GuardKeys importPublicKeyRing(int userId, int contextId, String email, Locale locale, PGPPublicKeyRing publicKeyRing) throws OXException {
         GuardKeys newKeys = new GuardKeys();
         newKeys.setEmail(email);
         newKeys.setUserid(userId);
@@ -343,26 +363,30 @@ public class KeyImportServiceImpl implements KeyImportService {
                 throw GuardCoreExceptionCodes.UNEXPECTED_ERROR.create("Error while merging keys");
             }
         }
+        return newKeys;
     }
 
     /* (non-Javadoc)
      * @see com.openexchange.guard.keymanagement.services.KeyImportService#importPublicKeyRing(int, int, org.bouncycastle.openpgp.PGPPublicKeyRing)
      */
     @Override
-    public void importPublicKeyRing(int userId, int contextId, String email, Locale locale, PGPPublicKeyRing...publicKeyRings) throws OXException {
+    public Collection<GuardKeys> importPublicKeyRing(int userId, int contextId, String email, Locale locale, PGPPublicKeyRing...publicKeyRings) throws OXException {
+        Collection<GuardKeys> importedKeyRings = new ArrayList<GuardKeys>(publicKeyRings.length);
         for(PGPPublicKeyRing ring : publicKeyRings) {
-            importPublicKeyRing(userId, contextId, email, locale, ring);
+            importedKeyRings.add(importPublicKeyRing(userId, contextId, email, locale, ring));
         }
+        return importedKeyRings;
     }
 
     /* (non-Javadoc)
      * @see com.openexchange.guard.keymanagement.services.KeyImportService#importPrivateKeyRing(int, int, org.bouncycastle.openpgp.PGPSecretKeyRing)
      */
     @Override
-    public void importPrivateKeyRing(int userId, int contextId, String email, Locale locale, String password, String newPassword, PGPSecretKeyRing...privateKeyRings) throws OXException {
+    public Collection<GuardKeys> importPrivateKeyRing(int userId, int contextId, String email, Locale locale, String password, String newPassword, PGPSecretKeyRing...privateKeyRings) throws OXException {
+        Collection<GuardKeys> importedKeyRings = new ArrayList<GuardKeys>(privateKeyRings.length);
         for(PGPSecretKeyRing ring : privateKeyRings) {
-            importPrivateKeyRing(userId, contextId, email, locale, password, newPassword, ring);
+            importedKeyRings.add(importPrivateKeyRing(userId, contextId, email, locale, password, newPassword, ring));
         }
+        return importedKeyRings;
     }
-
 }
