@@ -64,7 +64,7 @@ import com.openexchange.guard.keymanagement.services.impl.exceptions.GuardKeyTab
 import com.openexchange.guard.keymanagement.services.impl.osgi.Services;
 import com.openexchange.guard.keymanagement.storage.KeyTableStorage;
 import com.openexchange.guard.user.GuardCapabilities;
-import com.openexchange.guard.user.GuardUserService;
+import com.openexchange.guard.user.OXUserService;
 
 /**
  * {@link KeyRecoveryServiceImpl}
@@ -75,7 +75,7 @@ import com.openexchange.guard.user.GuardUserService;
 public class KeyRecoveryServiceImpl implements KeyRecoveryService {
 
     private final GuardConfigurationService configurationService;
-    private final GuardUserService userService;
+    private final OXUserService userService;
 
     /**
      * Initializes a new {@link KeyRecoveryServiceImpl}.
@@ -83,7 +83,7 @@ public class KeyRecoveryServiceImpl implements KeyRecoveryService {
      * @param configurationService The configuration service
      * @param userService The user service
      */
-    public KeyRecoveryServiceImpl(GuardConfigurationService configurationService, GuardUserService userService) {
+    public KeyRecoveryServiceImpl(GuardConfigurationService configurationService, OXUserService userService) {
         this.configurationService = configurationService;
         this.userService = userService;
     }
