@@ -98,8 +98,8 @@ public class HKPRecipKeyLookupStrategy implements RecipKeyLookupStrategy {
      * @see com.openexchange.guard.keymanagement.services.impl.RecipKeyLookupStrategy#lookup(java.lang.String)
      */
     @Override
-    public RecipKey lookup(String email) throws OXException {
-        Collection<RemoteKeyResult> results = Services.getService(HKPClientService.class).find(hkpClientToken, email);
+    public RecipKey lookup(String email, int timeout) throws OXException {
+        Collection<RemoteKeyResult> results = Services.getService(HKPClientService.class).find(hkpClientToken, email, timeout);
         if(results != null && !results.isEmpty()) {
             return toRecipKey(email, results.iterator().next());
         }
