@@ -139,7 +139,7 @@ public class UserUploadedRecipKeyLookupStrategy implements RecipKeyLookupStrateg
      * @see com.openexchange.guard.keymanagement.services.impl.RecipKeyLookupStrategy#lookup(java.lang.String)
      */
     @Override
-    public RecipKey lookup(String email) throws OXException {
+    public RecipKey lookup(String email, int timeout) throws OXException {
         OGPGPKeysStorage ogpgpKeysStorage = Services.getService(OGPGPKeysStorage.class);
         List<OGPGPKey> ogPGPKeys = ogpgpKeysStorage.getForUserByEmail(userId, contextId, Arrays.asList(new String[] { email }));
         for (OGPGPKey ogPGPKey : ogPGPKeys) {
