@@ -55,6 +55,7 @@ import java.util.Collection;
 import org.bouncycastle.jce.provider.BouncyCastleProvider;
 import org.bouncycastle.openpgp.PGPEncryptedData;
 import org.osgi.framework.BundleContext;
+import com.openexchange.contact.ContactService;
 import com.openexchange.guard.antiabuse.GuardAntiAbuseService;
 import com.openexchange.guard.cipher.GuardCipherAlgorithm;
 import com.openexchange.guard.cipher.GuardCipherFactoryService;
@@ -68,8 +69,10 @@ import com.openexchange.guard.keymanagement.keysources.CompositeKeyPairSource;
 import com.openexchange.guard.keymanagement.keysources.DbCachingKeyPairSource;
 import com.openexchange.guard.keymanagement.keysources.RealtimeKeyPairSource;
 import com.openexchange.guard.keymanagement.services.AccountCreationService;
+import com.openexchange.guard.keymanagement.services.ContactKeyService;
 import com.openexchange.guard.keymanagement.services.GuardKeyService;
 import com.openexchange.guard.keymanagement.services.GuardMasterKeyService;
+import com.openexchange.guard.keymanagement.services.ImportSystemPublicKey;
 import com.openexchange.guard.keymanagement.services.KeyCreationService;
 import com.openexchange.guard.keymanagement.services.KeyImportService;
 import com.openexchange.guard.keymanagement.services.KeyPairSource;
@@ -78,8 +81,10 @@ import com.openexchange.guard.keymanagement.services.PasswordChangeService;
 import com.openexchange.guard.keymanagement.services.PublicExternalKeyService;
 import com.openexchange.guard.keymanagement.services.RecipKeyService;
 import com.openexchange.guard.keymanagement.services.impl.AccountCreationServiceImpl;
+import com.openexchange.guard.keymanagement.services.impl.ContactKeyServiceImpl;
 import com.openexchange.guard.keymanagement.services.impl.GuardKeyServiceImpl;
 import com.openexchange.guard.keymanagement.services.impl.GuardMasterKeyServiceImpl;
+import com.openexchange.guard.keymanagement.services.impl.ImportSystemPublicKeyImpl;
 import com.openexchange.guard.keymanagement.services.impl.KeyCreationServiceImpl;
 import com.openexchange.guard.keymanagement.services.impl.KeyImportServiceImpl;
 import com.openexchange.guard.keymanagement.services.impl.KeyRecoveryServiceImpl;
@@ -91,10 +96,12 @@ import com.openexchange.guard.keymanagement.storage.KeyTableStorage;
 import com.openexchange.guard.keymanagement.storage.OGPGPKeysStorage;
 import com.openexchange.guard.keymanagement.storage.PGPKeysStorage;
 import com.openexchange.guard.ratifier.GuardRatifierService;
+import com.openexchange.guard.secondfactor.SecondFactorService;
 import com.openexchange.guard.session.GuardSessionService;
 import com.openexchange.guard.translation.GuardTranslationService;
-import com.openexchange.guard.user.GuardUserService;
+import com.openexchange.guard.user.OXUserService;
 import com.openexchange.osgi.HousekeepingActivator;
+import com.openexchange.pgp.keys.parsing.PGPKeyRingParser;
 
 /**
  * {@link KeyManagementServicesImplActivator}
@@ -113,8 +120,8 @@ public class KeyManagementServicesImplActivator extends HousekeepingActivator {
     protected Class<?>[] getNeededServices() {
         return new Class<?>[] { GuardCipherFactoryService.class, GuardConfigurationService.class, GuardShardingService.class, GuardRatifierService.class,
                                 KeyTableStorage.class, EmailStorage.class, KeyCacheStorage.class, PGPKeysStorage.class, OGPGPKeysStorage.class,
-                                GuardUserService.class, GuardAntiAbuseService.class, GuardSessionService.class, GuardTranslationService.class,
-                                HKPClientService.class};
+                                OXUserService.class, GuardAntiAbuseService.class, GuardSessionService.class, GuardTranslationService.class,
+                                HKPClientService.class, PGPKeyRingParser.class, ContactService.class, SecondFactorService.class};
     }
 
     private int getSymetricKeyAlgorithm() {
@@ -173,7 +180,7 @@ public class KeyManagementServicesImplActivator extends HousekeepingActivator {
         openTrackers();
 
         //register the key recovery service
-        KeyRecoveryService keyRecoveryService = new KeyRecoveryServiceImpl(getService(GuardConfigurationService.class), getService(GuardUserService.class));
+        KeyRecoveryService keyRecoveryService = new KeyRecoveryServiceImpl(getService(GuardConfigurationService.class), getService(OXUserService.class));
         registerService(KeyRecoveryService.class, keyRecoveryService);
         trackService(KeyRecoveryService.class);
 
@@ -201,18 +208,24 @@ public class KeyManagementServicesImplActivator extends HousekeepingActivator {
         trackService(GuardMasterKeyService.class);
 
         //Register the RecipKey lookup service
-        registerService(RecipKeyService.class, new RecipKeyServiceImpl(keyService));
+        registerService(RecipKeyService.class, new RecipKeyServiceImpl(keyService,
+            getService(GuardConfigurationService.class).getIntProperty(GuardProperty.remoteKeyLookupTimeout)));
         trackService(RecipKeyService.class);
         openTrackers();
 
         //Service for external public key handling
-        registerService(PublicExternalKeyService.class, new PublicExternalKeyServiceImpl(getService(GuardRatifierService.class),
-                                                                                         getService(OGPGPKeysStorage.class)));
+        PublicExternalKeyService publicExternalKeyService = new PublicExternalKeyServiceImpl(getService(GuardRatifierService.class), getService(OGPGPKeysStorage.class));
+        registerService(PublicExternalKeyService.class, publicExternalKeyService);
+
+        //Service for getting keys per contact
+        registerService(ContactKeyService.class, new ContactKeyServiceImpl(keyService, publicExternalKeyService, getService(ContactService.class)));
 
         //Service for importing client created, custom keys
         registerService(KeyImportService.class, new KeyImportServiceImpl(keyRecoveryService,keyService,
                                                                          getService(KeyTableStorage.class),
                                                                          getService(PGPKeysStorage.class)));
+        //Service for importing keys from command line
+        registerService(ImportSystemPublicKey.class, new ImportSystemPublicKeyImpl());
 
         //Account creation Service
         registerService(AccountCreationService.class, new AccountCreationServiceImpl());
