@@ -54,6 +54,7 @@ import java.sql.PreparedStatement;
 import java.sql.ResultSet;
 import java.sql.SQLException;
 import java.util.ArrayList;
+import java.util.Collections;
 import java.util.List;
 import com.google.gson.JsonObject;
 import com.openexchange.exception.OXException;
@@ -108,7 +109,7 @@ public class KeyTableStorageImpl implements KeyTableStorage {
             }
             return key;
         } catch (SQLException e) {
-            throw GuardKeyTableStorageExceptionCodes.SQL_ERROR.create(e, e.getMessage());
+            throw GuardCoreExceptionCodes.SQL_ERROR.create(e, e.getMessage());
         }
     }
 
@@ -117,7 +118,12 @@ public class KeyTableStorageImpl implements KeyTableStorage {
         GuardShardingService shardingService = Services.getService(GuardShardingService.class);
         int shard = 0;
         if (contextId < 0) {// If guest, get shard number, then check tables exist
-            shard = shardingService.getShard(userId, contextId);
+            if(shardingService.hasShard(userId, contextId)) {
+                shard = shardingService.getShard(userId, contextId);
+            }
+            else {
+                return Collections.emptyList();
+            }
         }
         return getKeysForUser(userId,contextId,shard);
     }
@@ -142,7 +148,7 @@ public class KeyTableStorageImpl implements KeyTableStorage {
             return ret;
 
         } catch (SQLException e) {
-            throw GuardKeyTableStorageExceptionCodes.SQL_ERROR.create(e, e.getMessage());
+            throw GuardCoreExceptionCodes.SQL_ERROR.create(e,e.getMessage());
         } finally {
             DBUtils.closeSQLStuff(resultSet, stmt);
             guardDatabaseService.backReadOnly(connectionWrapper);
@@ -169,7 +175,7 @@ public class KeyTableStorageImpl implements KeyTableStorage {
             }
             return null;
         } catch (SQLException e) {
-            throw GuardKeyTableStorageExceptionCodes.SQL_ERROR.create(e, e.getMessage());
+            throw GuardCoreExceptionCodes.SQL_ERROR.create(e,e.getMessage());
         } finally {
             DBUtils.closeSQLStuff(resultSet, stmt);
             guardDatabaseService.backReadOnly(connectionWrapper);
@@ -196,7 +202,7 @@ public class KeyTableStorageImpl implements KeyTableStorage {
             }
             return null;
         } catch (SQLException e) {
-            throw GuardKeyTableStorageExceptionCodes.SQL_ERROR.create(e, e.getMessage());
+            throw GuardCoreExceptionCodes.SQL_ERROR.create(e,e.getMessage());
         } finally {
             DBUtils.closeSQLStuff(resultSet, stmt);
             guardDatabaseService.backReadOnly(connectionWrapper);
@@ -224,7 +230,7 @@ public class KeyTableStorageImpl implements KeyTableStorage {
             }
             return null;
         } catch (SQLException e) {
-            throw GuardKeyTableStorageExceptionCodes.SQL_ERROR.create(e, e.getMessage());
+            throw GuardCoreExceptionCodes.SQL_ERROR.create(e,e.getCause());
         } finally {
             DBUtils.closeSQLStuff(resultSet, stmt);
             guardDatabaseService.backReadOnly(connectionWrapper);
@@ -250,8 +256,7 @@ public class KeyTableStorageImpl implements KeyTableStorage {
             }
             return ret;
         } catch (SQLException e) {
-            throw GuardKeyTableStorageExceptionCodes.SQL_ERROR.create(e, e.getMessage());
-
+            throw GuardCoreExceptionCodes.SQL_ERROR.create(e,e.getMessage());
         } finally {
             DBUtils.closeSQLStuff(resultSet, stmt);
             guardDatabaseService.backReadOnly(contextId, connection);
@@ -288,7 +293,7 @@ public class KeyTableStorageImpl implements KeyTableStorage {
             }
             return null;
         } catch (SQLException e) {
-            throw GuardKeyTableStorageExceptionCodes.SQL_ERROR.create(e, e.getMessage());
+            throw GuardCoreExceptionCodes.SQL_ERROR.create(e,e.getMessage());
         } finally {
             DBUtils.closeSQLStuff(resultSet, stmt);
             guardDatabaseService.backReadOnly(connectionWrapper);
@@ -318,7 +323,7 @@ public class KeyTableStorageImpl implements KeyTableStorage {
             }
             return null;
         } catch (SQLException e) {
-            throw GuardKeyTableStorageExceptionCodes.SQL_ERROR.create(e, e.getMessage());
+            throw GuardCoreExceptionCodes.SQL_ERROR.create(e,e.getMessage());
         } finally {
             DBUtils.closeSQLStuff(resultSet, stmt);
             guardDatabaseService.backReadOnly(connectionWrapper);
@@ -343,7 +348,7 @@ public class KeyTableStorageImpl implements KeyTableStorage {
             }
             return null;
         } catch (SQLException e) {
-            throw GuardKeyTableStorageExceptionCodes.SQL_ERROR.create(e, e.getMessage());
+            throw GuardCoreExceptionCodes.SQL_ERROR.create(e,e.getMessage());
         } finally {
             DBUtils.closeSQLStuff(resultSet, stmt);
             guardDatabaseService.backReadOnly(connectionWrapper);
@@ -369,7 +374,7 @@ public class KeyTableStorageImpl implements KeyTableStorage {
             }
             return null;
         } catch (SQLException e) {
-            throw GuardKeyTableStorageExceptionCodes.SQL_ERROR.create(e, e.getMessage());
+            throw GuardCoreExceptionCodes.SQL_ERROR.create(e, e.getMessage());
         } finally {
             DBUtils.closeSQLStuff(resultSet, stmt);
             guardDatabaseService.backReadOnly(connectionWrapper);
@@ -392,7 +397,7 @@ public class KeyTableStorageImpl implements KeyTableStorage {
             }
             return null;
         } catch (SQLException e) {
-            throw GuardKeyTableStorageExceptionCodes.SQL_ERROR.create(e, e.getMessage());
+            throw GuardCoreExceptionCodes.SQL_ERROR.create(e,e.getMessage());
         } finally {
             DBUtils.closeSQLStuff(resultSet, stmt);
             guardDatabaseService.backReadOnlyForGuard(connection);
@@ -440,11 +445,40 @@ public class KeyTableStorageImpl implements KeyTableStorage {
         }
     }
 
+    @Override
+    public int getMinFromSystemTable () throws OXException {
+        GuardDatabaseService guardDatabaseService = Services.getService(GuardDatabaseService.class);
+        Connection connection = guardDatabaseService.getReadOnlyForGuard();
+        PreparedStatement stmt = null;
+        ResultSet resultSet = null;
+        try {
+            stmt = connection.prepareStatement(KeyTableSql.GET_MIN_FROM_SYSTEM_TABLE);
+            resultSet = stmt.executeQuery();
+            if (resultSet.next()) {
+                return (resultSet.getInt(1));
+            } else {
+                throw GuardCoreExceptionCodes.SQL_ERROR.create("Unable to get key index.");
+            }
+        } catch (SQLException e) {
+            throw GuardCoreExceptionCodes.SQL_ERROR.create(e,e.getMessage());
+        } finally {
+            DBUtils.closeSQLStuff(resultSet, stmt);
+            guardDatabaseService.backReadOnlyForGuard(connection);
+        }
+
+
+
+    }
+
     @Override
     public void insert(Connection connection, GuardKeys key, boolean setLastMod) throws OXException {
         PreparedStatement stmt = null;
         try {
             String sql = setLastMod ? KeyTableSql.INSERT_AND_SET_LASTMOD_STMT : KeyTableSql.INSERT_STMT;
+            String question = key.getQuestion();
+            if (key.getQuestion() == null && setLastMod) {  // If user created key, question should not be null, bug 55911
+                question = "";
+            }
             stmt = connection.prepareStatement(sql);
             if (key.getUserid() == 0) {
                 stmt.setNull(1, java.sql.Types.INTEGER);
@@ -462,7 +496,7 @@ public class KeyTableStorageImpl implements KeyTableStorage {
             stmt.setString(10, key.getLanguage());
             stmt.setLong(11, key.getPGPPublicKeyRing().getPublicKey().getKeyID());
             stmt.setInt(12, key.getVersion());
-            stmt.setString(13, key.getQuestion());
+            stmt.setString(13, question);
             stmt.setString(14, key.getAnswer());
             if (key.getSettings() == null) {
                 stmt.setNull(15, java.sql.Types.VARCHAR);
@@ -474,7 +508,7 @@ public class KeyTableStorageImpl implements KeyTableStorage {
 
             stmt.executeUpdate();
         } catch (SQLException e) {
-            throw GuardKeyTableStorageExceptionCodes.SQL_ERROR.create(e, e.getMessage());
+            throw GuardCoreExceptionCodes.SQL_ERROR.create(e,e.getMessage());
         } finally {
             DBUtils.closeSQLStuff(stmt);
         }
@@ -497,7 +531,7 @@ public class KeyTableStorageImpl implements KeyTableStorage {
 
             stmt.executeUpdate();
         } catch (SQLException e) {
-            throw GuardKeyTableStorageExceptionCodes.SQL_ERROR.create(e, e.getMessage());
+            throw GuardCoreExceptionCodes.SQL_ERROR.create(e,e.getMessage());
         } finally {
             DBUtils.closeSQLStuff(stmt);
             guardDatabaseService.backWritable(connectionWrapper);
@@ -514,11 +548,12 @@ public class KeyTableStorageImpl implements KeyTableStorage {
         try {
             stmt = connectionWrapper.getConnection().prepareStatement(KeyTableSql.UPDATE_EMAIL_ADDRESS);
             stmt.setString(1, newEmail);
-            stmt.setString(2, key.getEmail());
+            stmt.setInt(2, key.getContextid());
+            stmt.setString(3, key.getEmail());
 
             stmt.executeUpdate();
         } catch (SQLException e) {
-            throw GuardKeyTableStorageExceptionCodes.SQL_ERROR.create(e, e.getMessage());
+            throw GuardCoreExceptionCodes.SQL_ERROR.create(e,e.getMessage());
         } finally {
             DBUtils.closeSQLStuff(stmt);
             guardDatabaseService.backWritable(connectionWrapper);
@@ -541,7 +576,7 @@ public class KeyTableStorageImpl implements KeyTableStorage {
 
             stmt.executeUpdate();
         } catch (SQLException e) {
-            throw GuardKeyTableStorageExceptionCodes.SQL_ERROR.create(e, e.getMessage());
+            throw GuardCoreExceptionCodes.SQL_ERROR.create(e,e.getMessage());
         } finally {
             DBUtils.closeSQLStuff(stmt);
             guardDatabaseService.backWritable(connectionWrapper);
@@ -570,7 +605,7 @@ public class KeyTableStorageImpl implements KeyTableStorage {
 
             stmt.executeUpdate();
         } catch (SQLException e) {
-            throw GuardKeyTableStorageExceptionCodes.SQL_ERROR.create(e, e.getMessage());
+            throw GuardCoreExceptionCodes.SQL_ERROR.create(e,e.getMessage());
         } finally {
             DBUtils.closeSQLStuff(stmt);
             guardDatabaseService.backWritable(connectionWrapper);
@@ -594,7 +629,7 @@ public class KeyTableStorageImpl implements KeyTableStorage {
 
             stmt.executeUpdate();
         } catch (SQLException e) {
-            throw GuardKeyTableStorageExceptionCodes.SQL_ERROR.create(e, e.getMessage());
+            throw GuardCoreExceptionCodes.SQL_ERROR.create(e,e.getMessage());
         } finally {
             DBUtils.closeSQLStuff(stmt);
             guardDatabaseService.backWritable(connectionWrapper);
@@ -622,7 +657,7 @@ public class KeyTableStorageImpl implements KeyTableStorage {
 
             stmt.executeUpdate();
         } catch (SQLException e) {
-            throw GuardKeyTableStorageExceptionCodes.SQL_ERROR.create(e, e.getMessage());
+            throw GuardCoreExceptionCodes.SQL_ERROR.create(e,e.getMessage());
         } finally {
             DBUtils.closeSQLStuff(stmt);
             guardDatabaseService.backWritable(connectionWrapper);
@@ -644,7 +679,7 @@ public class KeyTableStorageImpl implements KeyTableStorage {
 
             stmt.executeUpdate();
         } catch (SQLException e) {
-            throw GuardKeyTableStorageExceptionCodes.SQL_ERROR.create(e, e.getMessage());
+            throw GuardCoreExceptionCodes.SQL_ERROR.create(e,e.getMessage());
         } finally {
             DBUtils.closeSQLStuff(stmt);
             guardDatabaseService.backWritable(connectionWrapper);
@@ -667,7 +702,7 @@ public class KeyTableStorageImpl implements KeyTableStorage {
 
             stmt.executeUpdate();
         } catch (SQLException e) {
-            throw GuardKeyTableStorageExceptionCodes.SQL_ERROR.create(e, e.getMessage());
+            throw GuardCoreExceptionCodes.SQL_ERROR.create(e,e.getMessage());
         } finally {
             DBUtils.closeSQLStuff(stmt);
             guardDatabaseService.backWritable(connectionWrapper);
@@ -712,7 +747,7 @@ public class KeyTableStorageImpl implements KeyTableStorage {
 
             stmt.executeUpdate();
         } catch (SQLException e) {
-            throw GuardKeyTableStorageExceptionCodes.SQL_ERROR.create(e, e.getMessage());
+            throw GuardCoreExceptionCodes.SQL_ERROR.create(e,e.getMessage());
         } finally {
             DBUtils.closeSQLStuff(stmt);
             guardDatabaseService.backWritable(connectionWrapper);
@@ -735,7 +770,7 @@ public class KeyTableStorageImpl implements KeyTableStorage {
 
             stmt.executeUpdate();
         } catch (SQLException e) {
-            throw GuardKeyTableStorageExceptionCodes.SQL_ERROR.create(e, e.getMessage());
+            throw GuardCoreExceptionCodes.SQL_ERROR.create(e,e.getMessage());
         } finally {
             DBUtils.closeSQLStuff(stmt);
             guardDatabaseService.backWritable(connectionWrapper);
@@ -756,7 +791,7 @@ public class KeyTableStorageImpl implements KeyTableStorage {
 
             stmt.executeUpdate();
         } catch (SQLException e) {
-            throw GuardKeyTableStorageExceptionCodes.SQL_ERROR.create(e, e.getMessage());
+            throw GuardCoreExceptionCodes.SQL_ERROR.create(e,e.getMessage());
         } finally {
             DBUtils.closeSQLStuff(stmt);
             guardDatabaseService.backWritable(connectionWrapper);
@@ -778,7 +813,7 @@ public class KeyTableStorageImpl implements KeyTableStorage {
 
             stmt.executeUpdate();
         } catch (SQLException e) {
-            throw GuardKeyTableStorageExceptionCodes.SQL_ERROR.create(e, e.getMessage());
+            throw GuardCoreExceptionCodes.SQL_ERROR.create(e, e.getMessage());
         } finally {
             DBUtils.closeSQLStuff(stmt);
             guardDatabaseService.backWritable(connectionWrapper);
@@ -807,7 +842,7 @@ public class KeyTableStorageImpl implements KeyTableStorage {
 
             stmt.executeUpdate();
         } catch (SQLException e) {
-            throw GuardKeyTableStorageExceptionCodes.SQL_ERROR.create(e, e.getMessage());
+            throw GuardCoreExceptionCodes.SQL_ERROR.create(e, e.getMessage());
         } finally {
             DBUtils.closeSQLStuff(stmt);
         }
@@ -825,7 +860,7 @@ public class KeyTableStorageImpl implements KeyTableStorage {
 
             stmt.executeUpdate();
         } catch (SQLException e) {
-            throw GuardKeyTableStorageExceptionCodes.SQL_ERROR.create(e, e.getMessage());
+            throw GuardCoreExceptionCodes.SQL_ERROR.create(e, e.getMessage());
         } finally {
             DBUtils.closeSQLStuff(stmt);
             guardDatabaseService.backWritable(contextId, connection);
@@ -846,7 +881,7 @@ public class KeyTableStorageImpl implements KeyTableStorage {
 
             stmt.executeUpdate();
         } catch (SQLException e) {
-            throw GuardKeyTableStorageExceptionCodes.SQL_ERROR.create(e, e.getMessage());
+            throw GuardCoreExceptionCodes.SQL_ERROR.create(e, e.getMessage());
         } finally {
             DBUtils.closeSQLStuff(stmt);
             guardDatabaseService.backWritable(connectionWrapper);
@@ -865,8 +900,7 @@ public class KeyTableStorageImpl implements KeyTableStorage {
 
             stmt.executeUpdate();
         } catch (SQLException e) {
-            throw GuardKeyTableStorageExceptionCodes.SQL_ERROR.create(e, e.getMessage());
-
+            throw GuardCoreExceptionCodes.SQL_ERROR.create(e,e.getMessage());
         } finally {
             DBUtils.closeSQLStuff(stmt);
             guardDatabaseService.backWritableForShard(shardId, connection);
@@ -898,7 +932,7 @@ public class KeyTableStorageImpl implements KeyTableStorage {
                 key = getKeyFromRS(resultSet);
             }
         } catch (SQLException e) {
-            throw GuardKeyTableStorageExceptionCodes.SQL_ERROR.create(e, e.getMessage());
+            throw GuardCoreExceptionCodes.SQL_ERROR.create(e,e.getMessage());
         } finally {
             DBUtils.closeSQLStuff(resultSet, stmt);
             guardDatabaseService.backReadOnly(connectionWrapper);
@@ -925,7 +959,7 @@ public class KeyTableStorageImpl implements KeyTableStorage {
             }
             return null;
         } catch (SQLException e) {
-            throw GuardKeyTableStorageExceptionCodes.SQL_ERROR.create(e, e.getMessage());
+            throw GuardCoreExceptionCodes.SQL_ERROR.create(e,e.getMessage());
         } finally {
             DBUtils.closeSQLStuff(resultSet, stmt);
             guardDatabaseService.backReadOnlyForShard(shardId, connection);
@@ -942,7 +976,7 @@ public class KeyTableStorageImpl implements KeyTableStorage {
         try {
             return DBUtils.tableExists(readOnly.getConnection(), KeyTableSql.OG_KEY_TABLE);
         } catch (SQLException e) {
-            throw GuardKeyTableStorageExceptionCodes.SQL_ERROR.create(e, e.getMessage());
+            throw GuardCoreExceptionCodes.SQL_ERROR.create(e, e.getMessage());
         }
         finally {
             guardDatabaseService.backReadOnly(readOnly);
@@ -988,7 +1022,7 @@ public class KeyTableStorageImpl implements KeyTableStorage {
             }
             return key;
         } catch (SQLException e) {
-            throw GuardKeyTableStorageExceptionCodes.SQL_ERROR.create(e, e.getMessage());
+            throw GuardCoreExceptionCodes.SQL_ERROR.create(e,e.getMessage());
         }
     }
 
