@@ -405,6 +405,12 @@ public interface KeyTableStorage {
      */
     public boolean exists(int userId, int contextId, int shardId) throws OXException;
 
+    /**
+     * Gets the lowest existing key number for guard.og_KeyTable
+     * @return
+     * @throws OXException
+     */
+    int getMinFromSystemTable() throws OXException;
 
     /**
      * Updates the misc data for a key
