@@ -58,7 +58,9 @@ import com.openexchange.guard.keymanagement.commons.util.PGPUtil;
  *
  * @author greg
  * @author <a href="mailto:benjamin.gruedelbach@open-xchange.com">Benjamin Gruedelbach</a>
+*  @deprecated use {@link com.openexchange.guard.keymanagement.services.KeySignatureVerificationResult} instead
  */
+@Deprecated
 public class KeySignatureVerificationResult {
 
     private final String id;
