@@ -86,11 +86,11 @@ import com.openexchange.guard.common.util.CipherUtil;
 import com.openexchange.guard.common.util.LongUtil;
 import com.openexchange.guard.configuration.GuardConfigurationService;
 import com.openexchange.guard.configuration.GuardProperty;
+import com.openexchange.guard.exceptions.GuardCoreExceptionCodes;
 import com.openexchange.guard.keymanagement.commons.GuardKeys;
 import com.openexchange.guard.keymanagement.commons.OGPGPKey;
 import com.openexchange.guard.keymanagement.commons.PGPKeys;
 import com.openexchange.guard.keymanagement.commons.util.PGPUtil;
-import com.openexchange.guard.keymanagement.commons.util.UserIDCreator;
 import com.openexchange.guard.keymanagement.services.GuardKeyService;
 import com.openexchange.guard.keymanagement.storage.KeyTableStorage;
 import com.openexchange.guard.keymanagement.storage.OGPGPKeysStorage;
@@ -302,7 +302,7 @@ public class PGPKeyServiceImpl implements PGPKeyService {
     @Override
     public PGPPublicKeyRing addUID(PGPPrivateKey privateKey, PGPPublicKeyRing publicKeyRing, String userId) throws OXException {
         try {
-        	return UserIDCreator.addUID(publicKeyRing, privateKey, userId);
+            return PGPKeysUtil.addUID(publicKeyRing, privateKey, userId);
         } catch (PGPException e) {
             throw PGPKeyExceptionCodes.PGP_ERROR.create(e, e.getMessage());
         }
@@ -362,7 +362,7 @@ public class PGPKeyServiceImpl implements PGPKeyService {
                 try {
                     publicKeyRing = new PGPPublicKeyRing(key.getEncoded(), new JcaKeyFingerprintCalculator());
                 } catch (IOException e) {
-                    throw PGPKeyExceptionCodes.IO_ERROR.create(e, e.getMessage());
+                    throw GuardCoreExceptionCodes.IO_ERROR.create(e,e.getMessage());
                 }
             } else {
                 publicKeyRing = PGPPublicKeyRing.insertPublicKey(publicKeyRing, key);
@@ -460,7 +460,7 @@ public class PGPKeyServiceImpl implements PGPKeyService {
         } catch (PGPException e) {
             throw PGPKeyExceptionCodes.PGP_ERROR.create(e, e.getMessage());
         } catch (IOException e) {
-            throw PGPKeyExceptionCodes.IO_ERROR.create(e, e.getMessage());
+            throw GuardCoreExceptionCodes.IO_ERROR.create(e,e.getMessage());
         }
     }
 
@@ -676,7 +676,7 @@ public class PGPKeyServiceImpl implements PGPKeyService {
             // and that object should be a PGPPublicKeyRing.
             o = factory.nextObject();
         } catch (IOException e) {
-            throw PGPKeyExceptionCodes.IO_ERROR.create(e, e.getMessage());
+            throw GuardCoreExceptionCodes.IO_ERROR.create(e,e.getMessage());
         }
         if (o instanceof PGPSecretKeyRing) {
             PGPSecretKeyRing secretRing = (PGPSecretKeyRing) o;
@@ -703,10 +703,19 @@ public class PGPKeyServiceImpl implements PGPKeyService {
             }
 
             try {
-                PGPPrivateKey pkey = PGPUtil.decodePrivate(keys.getPGPSecretKey(), guardPassword, keys.getSalt());
-                if (pkey == null) {
-                    LOG.error("Error decoding PGP Private key for import");
-                    return null;
+                PGPSecretKey verificationKey  = PGPKeysUtil.getDecryptionKey(keys.getPGPSecretKeyRing());
+                if(verificationKey == null) {
+                   verificationKey = PGPKeysUtil.getSigningKey(keys.getPGPSecretKeyRing());
+                }
+                if(verificationKey != null && !verificationKey.isPrivateKeyEmpty()) {
+                    PGPPrivateKey privateaDecryptionKey = PGPUtil.decodePrivate(verificationKey,guardPassword,keys.getSalt());
+                    if (privateaDecryptionKey == null) {
+                        LOG.error("Error decoding PGP Private key for import");
+                        return null;
+                    }
+                }
+                else {
+                    LOG.error("Error finding PGP secret decryption key");
                 }
             } catch (PGPException e) {
                 LOG.error("Problem importing PGP Private ", e);
