@@ -64,8 +64,6 @@ import com.openexchange.guard.common.java.Strings;
 import com.openexchange.guard.configuration.GuardConfigurationService;
 import com.openexchange.guard.configuration.GuardProductName;
 import com.openexchange.guard.configuration.GuardProperty;
-import com.openexchange.guard.email.storage.ogEmail.Email;
-import com.openexchange.guard.email.storage.ogEmail.EmailStorage;
 import com.openexchange.guard.mailcreator.MailCreatorService;
 import com.openexchange.guard.translation.ConditionalVissibleTemplateTransformation;
 import com.openexchange.guard.translation.GuardTranslationService;
@@ -80,6 +78,7 @@ import com.openexchange.guard.translation.TemplateTransformation;
 public class MailCreatorServiceImpl implements MailCreatorService {
 
     private static Logger LOG = LoggerFactory.getLogger(MailCreatorServiceImpl.class);
+
     public static final String OUTSITE_TEMPLATE = "";
 
     public static final String PASSWORD_EMAIL_TEMPLATE = "";
@@ -361,26 +360,12 @@ public class MailCreatorServiceImpl implements MailCreatorService {
      */
     @Override
     public ArrayList<String> getFromAddress(String name, String email, int userid, int cid) throws OXException {
-    	
-    	EmailStorage emailStorage = Services.getService(EmailStorage.class);
-
         ArrayList<String> answer = new ArrayList<String>();
         // Check if Backend has a from address for this person in config cascade
         String fromemail = null;
         GuardConfigurationService guardConfigService = Services.getService(GuardConfigurationService.class);
         if (userid != 0) {
-        	fromemail = guardConfigService.getProperty(GuardProperty.fromEmail, userid, cid);
-
-        	if ( (fromemail == null || fromemail.isEmpty()) && cid < 0) {
-        		//Guests only:
-        		//Workaround for Bug 59842 - password reset from address override by config cascade not working
-        		//Explicit query fromEmail from the contextSet (and only the contextSet) for a user in the guest's context 
-        		List<Email> forContext = emailStorage.getForContext(cid * -1, 1);
-        		Email userInContext = forContext != null && forContext.size() > 0 ? forContext.get(0) : null;
-        		if(userInContext != null) {
-        			fromemail = guardConfigService.getContextSetStringProperty(GuardProperty.fromEmail, userInContext.getUserId(), userInContext.getContextId(), null);
-        		}
-        	}
+            fromemail = guardConfigService.getProperty(GuardProperty.fromEmail, userid, cid);
         }
         // If no config cascade
         if (fromemail == null || fromemail.isEmpty()) {
