@@ -55,23 +55,31 @@ import java.nio.charset.StandardCharsets;
 import java.util.Objects;
 import javax.mail.MessagingException;
 import javax.mail.internet.MimeMessage;
-import javax.servlet.http.HttpServletResponse;
-import com.google.gson.JsonObject;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 import com.openexchange.exception.OXException;
-import com.openexchange.guard.common.servlets.utils.ServletUtils;
 import com.openexchange.guard.configuration.GuardConfigurationService;
+import com.openexchange.guard.email.storage.ogEmail.EmailStorage;
 import com.openexchange.guard.exceptions.GuardAuthExceptionCodes;
+import com.openexchange.guard.exceptions.GuardCoreExceptionCodes;
+import com.openexchange.guard.guest.GuardGuestService;
+import com.openexchange.guard.guest.metadata.storage.GuardGuestEMailMetadataService;
 import com.openexchange.guard.keymanagement.commons.GuardKeys;
 import com.openexchange.guard.keymanagement.services.GuardKeyService;
-import com.openexchange.guard.mime.encryptor.pgp.impl.PGPProcessMime;
-import com.openexchange.guard.mime.encryptor.pgp.impl.SignMime;
-import com.openexchange.guard.mime.services.MimeEncryptionService;
-import com.openexchange.guard.pgpcore.services.PGPCryptoService;
-import com.openexchange.guard.user.UserIdentity;
-import com.openexchange.pgp.mail.PGPMimeService;
-import com.openexchange.guard.mime.services.GuardParsedMimeMessage;
+import com.openexchange.guard.mailcreator.MailCreatorService;
 import com.openexchange.guard.mime.encryptor.exceptions.MimeEncryptorExceptionCodes;
 import com.openexchange.guard.mime.encryptor.osgi.Services;
+import com.openexchange.guard.mime.encryptor.pgp.impl.PGPProcessMime;
+import com.openexchange.guard.mime.encryptor.pgp.impl.SignMime;
+import com.openexchange.guard.mime.helpfiles.HelpFileService;
+import com.openexchange.guard.mime.services.GuardParsedMimeMessage;
+import com.openexchange.guard.mime.services.MimeEncryptionService;
+import com.openexchange.guard.notification.GuardNotificationService;
+import com.openexchange.guard.pgpcore.services.PGPCryptoService;
+import com.openexchange.guard.pgpcore.services.PGPMimeCryptoService;
+import com.openexchange.guard.pgpcore.services.PGPSigningService;
+import com.openexchange.guard.user.UserIdentity;
+import com.openexchange.pgp.mail.PGPMimeService;
 
 /**
  * {@link PGPMimeEncryptionService}
@@ -84,6 +92,16 @@ public class PGPMimeEncryptionService implements MimeEncryptionService {
     private final PGPCryptoService pgpCryptoService;
     private final PGPMimeService pgpMimeService;
     private final GuardConfigurationService configurationService;
+    private final PGPMimeCryptoService pgpMimeCryptoService;
+    private final HelpFileService helpFileService;
+    private GuardNotificationService guardNotificationService;
+    private final GuardGuestEMailMetadataService guardMetaDataService;
+    private final EmailStorage emailStorage;
+    private GuardGuestService guestService;
+    private PGPSigningService pgpSigningService;
+    private MailCreatorService mailCreatorService;
+
+    private static Logger LOG = LoggerFactory.getLogger(PGPMimeEncryptionService.class);
 
     /**
      * Initializes a new {@link PGPMimeEncryptionService}.
@@ -91,12 +109,28 @@ public class PGPMimeEncryptionService implements MimeEncryptionService {
      * @param pgpCryptoService The {@link PGPCryptoService} to use for encrypting mime messages.
      */
     public PGPMimeEncryptionService(PGPCryptoService pgpCryptoService,
+                                    PGPSigningService pgpSigningService,
+                                    PGPMimeCryptoService  pgpMimeCryptoService,
                                     PGPMimeService pgpMimeService,
-                                    GuardConfigurationService configurationService) {
+                                    GuardConfigurationService configurationService,
+                                    HelpFileService helpFileService,
+                                    GuardGuestService guestService,
+                                    GuardNotificationService guardNotificationService,
+                                    GuardGuestEMailMetadataService guardMetaDataService,
+                                    EmailStorage emailStorage,
+                                    MailCreatorService mailCreatorService) {
 
+        this.pgpSigningService = Objects.requireNonNull(pgpSigningService, "pgpSigningService must not ben ull");
         this.pgpCryptoService = Objects.requireNonNull(pgpCryptoService, "pgpCryptoService must not be null");
+        this.pgpMimeCryptoService = Objects.requireNonNull(pgpMimeCryptoService, "pgpMimeCryptoService must not be null");
         this.pgpMimeService = Objects.requireNonNull(pgpMimeService, "pgpMimeService must not be null");
         this.configurationService = Objects.requireNonNull(configurationService, "configurationService must not be null");
+        this.helpFileService = Objects.requireNonNull(helpFileService, "helpFileService must not be null");
+        this.guestService = Objects.requireNonNull(guestService, "guestService must not be null");
+        this.guardNotificationService = Objects.requireNonNull(guardNotificationService, "guardNotificationService must not be null");
+        this.guardMetaDataService = Objects.requireNonNull(guardMetaDataService, "Guest metadata service must not be null");
+        this.emailStorage = Objects.requireNonNull(emailStorage, "Email storage service must not be null");
+        this.mailCreatorService = Objects.requireNonNull(mailCreatorService, "Mail Creator Service must not be null");
     }
 
     @Override
@@ -122,7 +156,7 @@ public class PGPMimeEncryptionService implements MimeEncryptionService {
             throw e;
         } catch (Exception e) {
             //TODO  Improve
-            throw MimeEncryptorExceptionCodes.UNKNOWN_EXCEPTION.create(e, e.getMessage());
+            throw GuardCoreExceptionCodes.UNEXPECTED_ERROR.create(e, e.getMessage());
         }
     }
 
@@ -138,10 +172,50 @@ public class PGPMimeEncryptionService implements MimeEncryptionService {
     private void doSigning (OutputStream output, int userId, int contextId, String password, GuardParsedMimeMessage msg) throws Exception {
         GuardKeyService keyService = Services.getService(GuardKeyService.class);
         GuardKeys key = keyService.getKeys(userId, contextId);
-        SignMime signer = new SignMime(pgpMimeService);
+        SignMime signer = new SignMime(pgpMimeService, pgpSigningService);
         output.write(signer.signMime(msg, key, password).getBytes(StandardCharsets.UTF_8));
     }
 
+    /**
+     * Internal method to create a {@link ProcessMime} instance
+     *
+     * @return The new {@link ProcessMime} instance
+     */
+    private ProcessMime createMimeProcessor() {
+        return new PGPProcessMime(
+            configurationService,
+            pgpCryptoService,
+            pgpMimeService,
+            pgpMimeCryptoService,
+            helpFileService,
+            guestService,
+            guardNotificationService,
+            guardMetaDataService,
+            emailStorage,
+            mailCreatorService
+            );
+    }
+
+    /**
+     * Check the msg for unsupported actions
+     * Currently checking for share links
+     * @param msg
+     * @throws OXException
+     */
+    private void checkUnsupported (GuardParsedMimeMessage msg) throws OXException {
+        // Check for attachment link
+        String[] linkHeader;
+        try {
+            linkHeader = msg.getMessage().getHeader("X-Open-Xchange-Share-URL");
+            if (linkHeader != null && linkHeader.length > 0) {
+                LOG.error("Sending encrypted email using Drive Mail is currently not supported by Guard");
+                throw GuardAuthExceptionCodes.FORBIDDEN.create();
+            }
+        } catch (MessagingException e1) {
+            LOG.error("Problem checking incoming email for unsupported options", e1);
+        }
+    }
+
     /**
      * Do email encryption +/- signing and send response
      * @param response
@@ -153,33 +227,14 @@ public class PGPMimeEncryptionService implements MimeEncryptionService {
      * @throws OXException
      */
     private void doEncrypt (OutputStream output, int userId, int contextId, String password, GuardParsedMimeMessage msg) throws IOException, OXException {
-        ProcessMime mimeProcessor = new PGPProcessMime(configurationService, pgpCryptoService);
+        checkUnsupported(msg);
+        ProcessMime mimeProcessor = createMimeProcessor();
         output.write(mimeProcessor.doEncrypt(msg, userId, contextId, password).getBytes(StandardCharsets.UTF_8));
     }
 
     private void doDecrypt(OutputStream output, int userId, int contextId, GuardParsedMimeMessage msg, UserIdentity userIdentity) throws IOException, OXException, MessagingException {
-        ProcessMime mimeProcessor = new PGPProcessMime(configurationService, pgpCryptoService);
-        MimeMessage resultMessage =  mimeProcessor.doDecrypt(msg, userId, contextId, userIdentity);
+        ProcessMime mimeProcessor = createMimeProcessor();
+        MimeMessage resultMessage =  mimeProcessor.doDecrypt(msg.getMessage(), userId, contextId, userIdentity);
         resultMessage.writeTo(output);
     }
-
-    /**
-     * Create error JSON
-     * @param ex
-     * @param response
-     * @throws IOException
-     */
-    private void handleOXException (OXException ex, HttpServletResponse response) throws IOException {
-        JsonObject error = new JsonObject();
-        JsonObject message = new JsonObject();
-        message.addProperty("message", ex.getLocalizedMessage());
-        error.add("error", message);
-        if (ex.getCode() == GuardAuthExceptionCodes.BAD_PASSWORD.getNumber()) {
-            ServletUtils.sendAnswer(response, 401, error.toString());
-        } else {
-            ServletUtils.sendNotAcceptable(response, error.toString());
-        }
-    }
-
-
 }
