@@ -78,7 +78,7 @@ import com.openexchange.guard.keymanagement.commons.util.PGPUtil;
 import com.openexchange.guard.keymanagement.services.GuardMasterKeyService;
 import com.openexchange.guard.mime.encryptor.osgi.Services;
 import com.openexchange.guard.mime.services.GuardParsedMimeMessage;
-import com.openexchange.guard.pgp.PGPUtils;
+import com.openexchange.guard.pgpcore.services.PGPSigningService;
 import com.openexchange.pgp.keys.tools.PGPKeysUtil;
 import com.openexchange.pgp.mail.PGPMimeService;
 import net.htmlparser.jericho.Source;
@@ -87,15 +87,17 @@ public class SignMime {
 
     private static Logger LOG = LoggerFactory.getLogger(SignMime.class);
     private final PGPMimeService pgpMimeService;
+    private PGPSigningService pgpSigningService;
 
     /**
      * Initializes a new {@link SignMime}.
      *
      * @param pgpMimeService The service used for signing
      */
-    public SignMime(PGPMimeService pgpMimeService) {
+    public SignMime(PGPMimeService pgpMimeService, PGPSigningService signingService) {
         super();
         this.pgpMimeService = pgpMimeService;
+        this.pgpSigningService = signingService;
     }
 
     private MimeMessage sign(MimeMessage message, PGPSecretKey signingKey, String password, String salt) throws Exception {
@@ -122,7 +124,7 @@ public class SignMime {
             throw GuardAuthExceptionCodes.BAD_PASSWORD.create();
         }
         if (msg.isInline()) {
-            SignMime sm = new SignMime(pgpMimeService);
+            SignMime sm = new SignMime(pgpMimeService, pgpSigningService);
             String signed = sm.SignInline(message, key, password);
             if (signed != null) {
                 return signed;
@@ -259,10 +261,10 @@ public class SignMime {
     }
 
     private String signString(String message, GuardKeys key, String password) throws SignatureException, IOException, PGPException, OXException {
-        PGPUtils util = new PGPUtils();
         ByteArrayInputStream in = new ByteArrayInputStream(message.getBytes("UTF-8"));
         ByteArrayOutputStream out = new ByteArrayOutputStream();
-        util.createDetachedSignature(in, out, key, password, true);
+        final boolean armored = true;
+        pgpSigningService.sign(in, out, armored, key, password.toCharArray());
         String signature = new String(out.toByteArray(), "UTF-8");
         out.close();
         in.close();
