@@ -61,12 +61,19 @@ import javax.mail.internet.MimeBodyPart;
 import javax.mail.internet.MimeMessage;
 import javax.mail.internet.MimeMultipart;
 import org.apache.commons.io.IOUtils;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 import com.openexchange.exception.OXException;
+import com.openexchange.guard.common.streams.FilteringStream;
+import com.openexchange.guard.configuration.GuardConfigurationService;
+import com.openexchange.guard.configuration.GuardProperty;
 import com.openexchange.guard.mime.encryptor.Decryptor;
 import com.openexchange.guard.mime.encryptor.exceptions.MimeEncryptorExceptionCodes;
+import com.openexchange.guard.mime.encryptor.pgp.impl.HTMLStripper;
 import com.openexchange.guard.pgp.signing.impl.SignatureResults;
 import com.openexchange.guard.pgpcore.services.PGPCryptoService;
 import com.openexchange.guard.user.UserIdentity;
+import com.openexchange.pgp.core.PGPDecryptionResult;
 import com.openexchange.pgp.core.PGPSignatureVerificationResult;
 
 /**
@@ -82,6 +89,8 @@ public class PGPInlineDecryptor extends Decryptor {
     private static final int STREAM_INSPECTION_SIZE = 1024;
     private final PGPCryptoService pgpCryptoService;
     private final UserIdentity userIdentity;
+    private final GuardConfigurationService guardConfigService;
+    private static Logger LOG = LoggerFactory.getLogger(PGPInlineDecryptor.class);
 
     /**
      * Initializes a new {@link PGPInlineDecryptor}.
@@ -89,9 +98,10 @@ public class PGPInlineDecryptor extends Decryptor {
      * @param pgpCryptoService The {@link PGPCryptoService} to use for decrypting content.
      * @param userIdentity The identity of the user to decrypt the content for.
      */
-    public PGPInlineDecryptor(PGPCryptoService pgpCryptoService, UserIdentity userIdentity) {
+    public PGPInlineDecryptor(PGPCryptoService pgpCryptoService, GuardConfigurationService guardConfigService, UserIdentity userIdentity) {
         this.pgpCryptoService = pgpCryptoService;
         this.userIdentity = userIdentity;
+        this.guardConfigService = guardConfigService;
     }
 
     /**
@@ -139,9 +149,14 @@ public class PGPInlineDecryptor extends Decryptor {
     private boolean decryptTextMessage(MimeMessage message) throws OXException, IOException, MessagingException {
         if (isPGPInlineInputStream(message.getInputStream(), STREAM_INSPECTION_SIZE)) {
             ByteArrayOutputStream decryptedContent = new ByteArrayOutputStream();
-            List<PGPSignatureVerificationResult> signatureResults = pgpCryptoService.decrypt(message.getInputStream(), decryptedContent, userIdentity);
+            PGPDecryptionResult result = pgpCryptoService.decrypt(
+                new FilteringStream(message.getInputStream(), new FilteringStream.PrintableFilter()),
+                decryptedContent, userIdentity);
+            List<PGPSignatureVerificationResult> signatureResults = result.getSignatureVerificationResults();
             message = addSignatureResults (message, signatureResults);
-            message.setContent(new String(decryptedContent.toByteArray(), StandardCharsets.UTF_8), message.getContentType());
+            message.setContent(
+                getText(decryptedContent, message.getContentType(), result.getMDCVerificationResult().isPresent()),
+                message.getContentType());
             return true;
         }
         return false;
@@ -190,9 +205,16 @@ public class PGPInlineDecryptor extends Decryptor {
             if (bodyPart.getContentType() != null && bodyPart.getContentType().contains("html")) {  // If HTML bodypart, strip the html formatting
                 data = stripHTML (data);
             }
+            data = data + "\r";
             ByteArrayInputStream in = new ByteArrayInputStream(data.getBytes());
-            signatureResults = pgpCryptoService.decrypt(in, decryptedContent, userIdentity);
-            bodyPart.setContent(getText(decryptedContent, bodyPart.getContentType()), bodyPart.getContentType());
+            PGPDecryptionResult result = pgpCryptoService.decrypt(
+                new FilteringStream(in, new FilteringStream.PrintableFilter()),
+                decryptedContent, userIdentity);
+            signatureResults = result.getSignatureVerificationResults();
+
+            bodyPart.setContent(
+                getText(decryptedContent, bodyPart.getContentType(), result.getMDCVerificationResult().isPresent()),
+                bodyPart.getContentType());
 
             //Update PGP File extension
             updateFileName(bodyPart);
@@ -207,9 +229,21 @@ public class PGPInlineDecryptor extends Decryptor {
      * @param decryptedContent
      * @param type contenttype of the mail body part
      * @return
+     * @throws OXException
      */
-    private String getText(ByteArrayOutputStream decryptedContent, String type) {
+    private String getText(ByteArrayOutputStream decryptedContent, String type, boolean mdcVerified) throws OXException {
         String result = new String(decryptedContent.toByteArray(), StandardCharsets.UTF_8);
+        if (!mdcVerified) {
+            if (guardConfigService.getBooleanProperty(GuardProperty.failForMissingMDC)) {
+                throw MimeEncryptorExceptionCodes.MISSING_MDC.create();
+            }
+            LOG.warn("PGP Inline message missing MDC integrity check data.  Stripping HTML");
+            if (type != null && type.contains("html")) {
+                result = new HTMLStripper().stripAllHTML(result);
+            } else {
+                result = new HTMLStripper().convertTextHTML(result);
+            }
+        }
         if (type != null && type.contains("html")) {  // If type HTML
             if (result.contains("<br") || result.contains("<p>")) {  // If already has HTML formatting, return contents
                 return result;
@@ -229,7 +263,7 @@ public class PGPInlineDecryptor extends Decryptor {
     private String stripHTML (String data) {
         data = data.substring(data.indexOf(BEGIN_PGP_MESSAGE_MARKER));
         data = data.substring(0, data.indexOf(END_PGP_MESSAGE_MARKER) + END_PGP_MESSAGE_MARKER.length());
-        data = data.replaceAll("<br>", "");
+        data = data.replaceAll("\r<br>", "\r").replaceAll("<br>\r", "\r").replaceAll("<br>", "\r");
         StringBuilder sb = new StringBuilder();
         String [] lines = data.split("\r");
         for (String line: lines) {
@@ -237,7 +271,7 @@ public class PGPInlineDecryptor extends Decryptor {
             sb.append("\r");
         }
         sb.append("\r");
-        return sb.toString();
+        return sb.toString().replaceAll("\\<.*?>","");
     }
 
     /**
@@ -252,7 +286,8 @@ public class PGPInlineDecryptor extends Decryptor {
     private List<PGPSignatureVerificationResult> decryptBinaryPart(MimeBodyPart bodyPart) throws IOException, MessagingException, OXException {
         //Decrypt body part and update it with the decoded data
         ByteArrayOutputStream decryptedContent = new ByteArrayOutputStream();
-        List<PGPSignatureVerificationResult> signatures = pgpCryptoService.decrypt(bodyPart.getInputStream(), decryptedContent, userIdentity);
+        PGPDecryptionResult result = pgpCryptoService.decrypt(bodyPart.getInputStream(), decryptedContent, userIdentity);
+        List<PGPSignatureVerificationResult> signatures = result.getSignatureVerificationResults();
         bodyPart.setContent(decryptedContent.toByteArray(), bodyPart.getContentType());
 
         //Update PGP File extension
@@ -274,6 +309,11 @@ public class PGPInlineDecryptor extends Decryptor {
         try {
             if (!message.getContentType().contains("multipart")) {
                 //Plain message
+                if (message.getContentType().contains("html")) {
+                    String plaintext = stripHTML((String) message.getContent());
+                    message.setText(plaintext);
+                    message.saveChanges();
+                }
                 decryptTextMessage(message);
             } else {
                 //A multipart message
