@@ -52,7 +52,6 @@ package com.openexchange.guard.mime.encryptor.pgp.pgpmime;
 import java.io.ByteArrayOutputStream;
 import java.io.IOException;
 import java.util.ArrayList;
-import java.util.HashMap;
 import java.util.List;
 import java.util.Objects;
 import javax.mail.BodyPart;
@@ -63,17 +62,15 @@ import org.bouncycastle.openpgp.PGPPublicKey;
 import org.bouncycastle.openpgp.PGPSecretKey;
 import com.openexchange.exception.OXException;
 import com.openexchange.guard.common.util.CipherUtil;
-import com.openexchange.guard.configuration.GuardConfigurationService;
-import com.openexchange.guard.configuration.GuardProperty;
 import com.openexchange.guard.exceptions.GuardCoreExceptionCodes;
 import com.openexchange.guard.keymanagement.commons.GuardKeys;
 import com.openexchange.guard.keymanagement.commons.RecipKey;
 import com.openexchange.guard.keymanagement.services.GuardKeyService;
 import com.openexchange.guard.mime.encryptor.Encryptor;
 import com.openexchange.guard.mime.encryptor.exceptions.MimeEncryptorExceptionCodes;
-import com.openexchange.guard.mime.encryptor.pgp.impl.HelpFileService;
-import com.openexchange.guard.mime.services.GuardParsedMimeMessage;
 import com.openexchange.guard.mime.encryptor.osgi.Services;
+import com.openexchange.guard.mime.helpfiles.HelpFileService;
+import com.openexchange.guard.mime.services.GuardParsedMimeMessage;
 import com.openexchange.guard.pgpcore.services.PGPCryptoService;
 import com.openexchange.pgp.keys.tools.PGPKeysUtil;
 import com.openexchange.pgp.mail.PGPMimeService;
@@ -88,13 +85,30 @@ import com.openexchange.pgp.mail.PGPMimeService;
  */
 public class GuardPGPMimeEncryptor extends Encryptor {
 
-    private final HashMap<String, String> savedHeaders;
-    private final GuardConfigurationService guardConfigurationService;
+    private HelpFileService helpFileService;
 
-    public GuardPGPMimeEncryptor (PGPCryptoService pgpCryptoService, GuardConfigurationService guardConfigurationService, GuardParsedMimeMessage msg, ArrayList<RecipKey> recips, int userid, int cid, String password) {
+    public GuardPGPMimeEncryptor (PGPCryptoService pgpCryptoService,
+                                  HelpFileService helpFileService,
+                                  GuardParsedMimeMessage msg,
+                                  ArrayList<RecipKey> recips,
+                                  int userid,
+                                  int cid,
+                                  String password) {
         super (pgpCryptoService, msg, recips, userid, cid, password);
-        this.guardConfigurationService = Objects.requireNonNull(guardConfigurationService, "guardConfigurationService must not be null");
-        savedHeaders = null;
+        this.helpFileService = Objects.requireNonNull(helpFileService, "helpFileService must not be null");
+    }
+
+    /**
+     * Internal method to fetch the sender's PGP key
+     *
+     * @return The sender's key
+     * @throws OXException
+     */
+    private GuardKeys getKey() throws OXException {
+        GuardKeyService guardKeyService = Services.getService(GuardKeyService.class);
+        return msg.senderIsGuest() ?
+                guardKeyService.getKeys(msg.getSenderEmail()) :
+                guardKeyService.getKeys(userid, cid);
     }
 
     @Override
@@ -105,8 +119,7 @@ public class GuardPGPMimeEncryptor extends Encryptor {
                 msg.setMessage(pgpAttach.getDecoded());
             }
 
-            GuardKeyService gk = Services.getService(GuardKeyService.class);
-            GuardKeys key = gk.getKeys(userid, cid);
+            GuardKeys key = getKey();
             if(key == null) {
                 throw GuardCoreExceptionCodes.KEY_NOT_FOUND_FOR_IDS_ERROR.create(userid, cid);
             }
@@ -118,8 +131,8 @@ public class GuardPGPMimeEncryptor extends Encryptor {
             recips.add(senderKey);  // Add the sender here so it can be read in sent folder
 
             //Get additional help files to attach to the message
-            final boolean attachHelpFiles = guardConfigurationService.getBooleanProperty(GuardProperty.attachHelpFile);
-            final List<BodyPart> helpFiles  = attachHelpFiles ? new HelpFileService().getHelpFiles(recips) : null;
+            final List<BodyPart> helpFiles  = helpFileService.getHelpFiles(recips);
+
 
             PGPMimeService pgpMimeService = Services.getService(PGPMimeService.class);
             MimeMessage ret = null;
@@ -136,7 +149,7 @@ public class GuardPGPMimeEncryptor extends Encryptor {
 
             return ret;
         } catch (Exception e) {
-            throw MimeEncryptorExceptionCodes.UNKNOWN_EXCEPTION.create(e, e.getMessage());
+            throw GuardCoreExceptionCodes.UNEXPECTED_ERROR.create(e, e.getMessage());
         }
 
     }
