@@ -102,7 +102,6 @@ public class GuardNotificationServiceImpl implements GuardNotificationService {
     private static final int MAX_IMAGE_LINE_LENGTH = 76;
     private static final String X_ORIG_IP = "X-Originating-IP";
 
-    private static Logger LOG = LoggerFactory.getLogger(GuardNotificationServiceImpl.class);
     boolean attachSenderIp;
     GuardRatifierService guardRatifierService;
     GuardConfigurationService guardConfigService;
@@ -113,20 +112,21 @@ public class GuardNotificationServiceImpl implements GuardNotificationService {
         this.attachSenderIp = attachSenderIp;
     }
 
+
+    private static Logger LOG = LoggerFactory.getLogger(GuardNotificationServiceImpl.class);
+
     @Override
-    public void send(final JsonObject email, String senderIp) throws OXException {
-        final GuardConfigurationService guardConfigService = Services.getService(GuardConfigurationService.class);
+    public void send(final JsonObject email, final String senderIp) throws OXException {
         send(email, null, "", 0, guardConfigService.getProperty(GuardProperty.defaultLanguage), getMessageID(), senderIp);
     }
 
     @Override
-    public void send(final JsonObject email, String lang, String senderIp) throws OXException {
+    public void send(final JsonObject email, String lang, final String senderIp) throws OXException {
         send (email, null, "", 0, lang, getMessageID(), senderIp);
     }
 
     @Override
-    public void send(final JsonObject email, final List<BodyPart> attachments, String senderIp) throws OXException {
-        final GuardConfigurationService guardConfigService = Services.getService(GuardConfigurationService.class);
+    public void send(final JsonObject email, final List<BodyPart> attachments, final String senderIp) throws OXException {
         send(email, attachments, "", 0, guardConfigService.getProperty(GuardProperty.defaultLanguage), getMessageID(), senderIp);
     }
 
@@ -323,11 +323,12 @@ public class GuardNotificationServiceImpl implements GuardNotificationService {
     }
 
     @Override
-    public void sendMessage(final Message msg, final String sender, int senderCid, final String lang, String senderIp) throws OXException {
+    public void sendMessage(final Message msg, final String sender, int senderCid, final String lang, final String senderIp) throws OXException {
         final Session session = getSession(isLocal(senderCid));
         Transport transport;
         try {
             if (!sender.equals("")) {
+                msg.removeHeader("Reply-To");
                 msg.addHeader("Reply-To", msg.getFrom()[0].toString());
                 final InternetAddress fromaddr = (InternetAddress) msg.getFrom()[0];
                 GuardTranslationService translationService = Services.getService(GuardTranslationService.class);
@@ -368,7 +369,6 @@ public class GuardNotificationServiceImpl implements GuardNotificationService {
      * @throws OXException if the GuardConfigurationService is absent
      */
     private Session getSession(boolean local) throws OXException {
-        final GuardConfigurationService guardConfigService = Services.getService(GuardConfigurationService.class);
         final String server = guardConfigService.getProperty(GuardProperty.guestSMTPServer);
         final int port = guardConfigService.getIntProperty(GuardProperty.guestSMTPPort);
         final String username = guardConfigService.getProperty(GuardProperty.guestSMTPUsername);
@@ -476,9 +476,8 @@ public class GuardNotificationServiceImpl implements GuardNotificationService {
      * @return the message identifier
      */
     protected String getMessageID() {
-        final GuardConfigurationService guardConfigurationService = Services.getService(GuardConfigurationService.class);
-        String mailIdDomain = guardConfigurationService.getProperty(GuardProperty.mailIdDomain);
-        final String oxURL = guardConfigurationService.getProperty(GuardProperty.externalEmailURL);
+        String mailIdDomain = guardConfigService.getProperty(GuardProperty.mailIdDomain);
+        final String oxURL = guardConfigService.getProperty(GuardProperty.externalEmailURL);
         if (mailIdDomain.equals("")) {  // If maildomain not defined, try to extract domain from URL
             if (oxURL.contains("/")) {
                 mailIdDomain = oxURL.substring(0, oxURL.indexOf("/"));
@@ -493,4 +492,6 @@ public class GuardNotificationServiceImpl implements GuardNotificationService {
         return "<" + CipherUtil.getUUID() + "@" + mailIdDomain + ">";
     }
 
+
+
 }
