@@ -191,12 +191,15 @@ public class Api {
             request.addHeader("content-type", "application/x-www-form-urlencoded");
             response = httpClient.execute(request, httpContext);
             BufferedReader reader = new BufferedReader(new InputStreamReader(response.getEntity().getContent(), "UTF-8"));
-            String json = reader.readLine();
-            JsonParser parser = new JsonParser();
-            JsonObject result = (JsonObject) parser.parse(json);
-            this.session = result.get("session").getAsString();
-            reader.close();
-            request.releaseConnection();
+            try {
+                String json = reader.readLine();
+                JsonParser parser = new JsonParser();
+                JsonObject result = (JsonObject) parser.parse(json);
+                this.session = result.get("session").getAsString();
+            } finally {
+                reader.close();
+                request.releaseConnection();
+            }
             return session;
         } catch (Exception ex) {
             LOG.error("Login error for user " + username, ex);
@@ -305,9 +308,16 @@ public class Api {
             throw new RuntimeException("Failed : HTTP error code : " + response.getStatusLine().getStatusCode() + " " + response.getStatusLine().getReasonPhrase());
         }
         BufferedReader reader = new BufferedReader(new InputStreamReader(response.getEntity().getContent(), "UTF-8"));
-        String json = reader.readLine();
-        JsonParser parser = new JsonParser();
-        JsonObject result = (JsonObject) parser.parse(json);
+        JsonObject result;
+        try {
+            String json = reader.readLine();
+            JsonParser parser = new JsonParser();
+            result = (JsonObject) parser.parse(json);
+        } finally {
+            if (reader != null) {
+                reader.close();
+            }
+        }
         reader.close();
         HttpClientUtils.closeQuietly(response);
         postRequest.releaseConnection();
@@ -342,8 +352,14 @@ public class Api {
             response = httpClient.execute(postRequest, httpContext);
         }
         BufferedReader reader = new BufferedReader(new InputStreamReader(response.getEntity().getContent(), "UTF-8"));
-        String result = reader.readLine();
-        reader.close();
+        String result;
+        try {
+            result = reader.readLine();
+        } finally {
+            if (reader != null) {
+                reader.close();
+            }
+        }
         HttpClientUtils.closeQuietly(response);
         postRequest.releaseConnection();
         if (Utilities.checkFail(result)) {
@@ -374,8 +390,14 @@ public class Api {
         int statusCode = response.getStatusLine().getStatusCode();
         if (statusCode == HttpStatus.SC_OK) {
             BufferedReader reader = new BufferedReader(new InputStreamReader(response.getEntity().getContent(), "UTF-8"));
-            String json = reader.readLine();
-            reader.close();
+            String json;
+            try {
+                json = reader.readLine();
+            } finally {
+                if (reader != null) {
+                    reader.close();
+                }
+            }
             HttpClientUtils.closeQuietly(response);
             postRequest.releaseConnection();
             if (json.contains("{")) {
@@ -559,6 +581,22 @@ public class Api {
         }
     }
 
+    /**
+     * Check JSON data for error and log
+     * @param data
+     * @param objectName  - name of the object that was being retrieved
+     * @return
+     */
+    private boolean checkError (JsonObject data, String objectName) {
+        if (data != null && data.has("data")) return false;
+        if (data != null && data.has("error")) {
+            LOG.error("Problem getting " + objectName + " from middleware.  " + data.get("error").getAsString());
+            return true;
+        }
+        LOG.error("Problem getting " + objectName + " from middleware.  Incorrect or no middleware response.");
+        return true;
+    }
+
     public int getContextId() {
         String params = "config/context_id?session=" + session;
 
@@ -566,6 +604,9 @@ public class Api {
         try {
             response = getResponse(params);
             JsonObject data = ResponseHelper.getJson(response);
+            if (checkError(data, "contextId")) {
+                return 0;
+            }
             return (data.get("data").getAsInt());
         } catch (Exception ex) {
             LOG.error("Error getting contextId", ex);
@@ -575,6 +616,25 @@ public class Api {
         }
     }
 
+    public JsonObject getUserData(int userid) {
+        String params = "user?action=get&session=" + session;
+        if (userid > 0) {
+            params += "&id=" + userid;
+        }
+
+        HttpResponse response = null;
+        try {
+            response = getResponse(params);
+            JsonObject data = ResponseHelper.getJson(response);
+            return data;
+        } catch (Exception ex) {
+            LOG.error("Error getting user information", ex);
+            return null;
+        } finally {
+            HttpClientUtils.closeQuietly(response);
+        }
+    }
+
     public String getFolder(int id) {
         String params = "folders?action=get" + "&id=" + id;
 
@@ -627,15 +687,8 @@ public class Api {
     }
 
     public boolean verifyLogin() {
-        String folders = getFolders();
-        if (folders != null && !folders.isEmpty()) {
-            JsonParser parser = new JsonParser();
-            JsonObject json = (JsonObject) parser.parse(folders);
-            if (json.get("data") != null) {
-                return true;
-            }
-        }
-        return false;
+        int contextId = getContextId();
+        return contextId > 0;
     }
 
     public JsonObject getInfoItemJson(String id, String folder) throws UnsupportedEncodingException {
@@ -758,7 +811,7 @@ public class Api {
                 //Error handling
                 HttpClientUtils.closeQuietly(response);
                 getRequest.releaseConnection();
-                throw OXApiExceptionCodes.IO_ERROR.create(String.format("Error reading input stream from remote drive item id " + fileId + " folder " + folderId + "d. HTTP-Error: " + response.toString()));
+                throw GuardCoreExceptionCodes.IO_ERROR.create(String.format("Error reading input stream from remote drive item id " + fileId + " folder " + folderId + "d. HTTP-Error: " + response.toString()));
             }
         } catch (URISyntaxException e) {
             throw GuardCoreExceptionCodes.UNEXPECTED_ERROR.create(e, "Could not construct redirect location for URI '" + builder.toString() + "'");
@@ -904,7 +957,12 @@ public class Api {
         try {
             String data = getConfig("mail");
             JsonObject json = JsonUtil.parseAsJsonObject(data);
-            return (json.get("data").getAsJsonObject().get("defaultaddress").getAsString());
+            if (json.has("data") && json.get("data").getAsJsonObject().has("defaultaddress")) {
+                return (json.get("data").getAsJsonObject().get("defaultaddress").getAsString());
+            } else {
+                json = getUserData(0);
+                return (json.get("data").getAsJsonObject().get("email1").getAsString());
+            }
         } catch (Exception e) {
             LOG.error("Error getting primary email address ", e);
             return ("");
@@ -1032,7 +1090,7 @@ public class Api {
 
     /**
      * Uploads a new input stream to drive
-     * 
+     *
      * @param inputStream The InputStream to upload
      * @param streamHandler A handler to define a operation performed on the stream data during upload
      * @param fileName The new name of the file
@@ -1048,7 +1106,7 @@ public class Api {
 
     /**
      * Uploads an input stream and updates an already existing item
-     * 
+     *
      * @param inputStream The InputStream to upload
      * @param streamHandler A handler to define a operation performed on the stream data during upload
      * @param fileName The new name of the file
@@ -1110,8 +1168,14 @@ public class Api {
 
             Integer returnStatus = response.getStatusLine().getStatusCode();
             BufferedReader reader = new BufferedReader(new InputStreamReader(response.getEntity().getContent(), "UTF-8"));
-            String result = reader.readLine();
-            reader.close();
+            String result;
+            try {
+                result = reader.readLine();
+            } finally {
+                if (reader != null) {
+                    reader.close();
+                }
+            }
             HttpClientUtils.closeQuietly(response);
             postRequest.releaseConnection();
             if (!returnStatus.toString().startsWith("2") /* Status 2xx Success */) {
