@@ -72,6 +72,7 @@ import com.openexchange.exception.OXException;
 import com.openexchange.guard.common.java.Strings;
 import com.openexchange.guard.configuration.GuardConfigurationService;
 import com.openexchange.guard.configuration.GuardProperty;
+import com.openexchange.guard.exceptions.GuardCoreExceptionCodes;
 import com.openexchange.guard.oxapi.context.CustomHttpClientContext;
 import com.openexchange.guard.oxapi.exceptions.OXApiExceptionCodes;
 import com.openexchange.guard.oxapi.osgi.Services;
@@ -185,7 +186,7 @@ public class MailResolver extends AbstractOXCalls {
         try {
             return URLEncoder.encode(value, "UTF-8");
         } catch (UnsupportedEncodingException e) {
-            throw OXApiExceptionCodes.UNEXPECTED_ERROR.create(e);
+            throw GuardCoreExceptionCodes.UNEXPECTED_ERROR.create(e,e.getMessage());
         }
     }
 
@@ -211,9 +212,9 @@ public class MailResolver extends AbstractOXCalls {
         try {
             return mapper.readValue(jsonResult.toString(), MailResolverResult.class);
         } catch (JsonParseException | JsonMappingException e) {
-            throw OXApiExceptionCodes.UNEXPECTED_ERROR.create(e, e.getMessage());
+            throw GuardCoreExceptionCodes.UNEXPECTED_ERROR.create(e, e.getMessage());
         } catch (IOException e) {
-            throw OXApiExceptionCodes.IO_ERROR.create(e, e.getMessage());
+            throw GuardCoreExceptionCodes.IO_ERROR.create(e, e.getMessage());
         }
     }
 
