@@ -11,6 +11,7 @@ import org.apache.http.client.methods.HttpGet;
 import com.google.gson.JsonObject;
 import com.google.gson.JsonParser;
 import com.openexchange.exception.OXException;
+import com.openexchange.guard.exceptions.GuardCoreExceptionCodes;
 import com.openexchange.guard.oxapi.exceptions.OXApiExceptionCodes;
 import com.openexchange.guard.oxapi.osgi.Services;
 import com.openexchange.guard.oxapi.pooling.HttpConnectionPoolService;
@@ -49,7 +50,7 @@ public class SessionInformation extends AbstractOXCalls {
                 }
             }
         } catch (IOException e) {
-            throw OXApiExceptionCodes.IO_ERROR.create(e, e.getMessage());
+            throw GuardCoreExceptionCodes.IO_ERROR.create(e, e.getMessage());
         } finally {
             get.releaseConnection();
         }
