@@ -67,8 +67,10 @@ import com.openexchange.guard.pgpcore.services.GuardKeyRingRetrievalStrategy;
 import com.openexchange.guard.pgpcore.services.TokenAuthenticationService;
 import com.openexchange.guard.pgpcore.services.exceptions.PGPCoreServicesExceptionCodes;
 import com.openexchange.guard.session.GuardSessionService;
-import com.openexchange.guard.user.GuardUserService;
+import com.openexchange.guard.user.OXGuardUser;
+import com.openexchange.guard.user.OXUserService;
 import com.openexchange.guard.user.UserIdentity;
+import com.openexchange.pgp.keys.common.PGPSymmetricKey;
 
 /**
  * {@link TokenAuthenticationServiceImpl}
@@ -81,7 +83,7 @@ public class TokenAuthenticationServiceImpl implements TokenAuthenticationServic
     private final GuardKeyRingRetrievalStrategy keyRingRetrievalStrategy;
     private final GuardSessionService guardSessionService;
     private final GuardCipherService guardCipherService;
-    private final GuardUserService guardUserService;
+    private final OXUserService guardUserService;
     private static final Logger logger = LoggerFactory.getLogger(TokenAuthenticationServiceImpl.class);
 
     /**
@@ -93,7 +95,7 @@ public class TokenAuthenticationServiceImpl implements TokenAuthenticationServic
         GuardKeyRingRetrievalStrategy keyRingRetrievalStrategy,
         GuardSessionService guardSessionService,
         GuardCipherService guardCipherService,
-        GuardUserService guardUserService) {
+        OXUserService guardUserService) {
         this.keyRingRetrievalStrategy = keyRingRetrievalStrategy;
         this.guardSessionService = guardSessionService;
         this.guardCipherService = guardCipherService;
@@ -171,11 +173,16 @@ public class TokenAuthenticationServiceImpl implements TokenAuthenticationServic
         else if(json.has("email") && json.has("encr_password")) {
             ret = new UserIdentity(json.getString("email"), json.getString("encr_password"));
         }
+        else if(json.has("email") && json.has("pgp_session_key")) {
+            ret = new UserIdentity(json.getString("email"))
+                .setPGPSession(PGPSymmetricKey.fromBase64(json.getString("pgp_session_key")));
+        }
 
         if(json.has("user_id") && json.has("cid")) {
             final int userId = json.getInt("user_id");
             final int cid = json.getInt("cid");
-            ret.setGuardUser(guardUserService.getUser(cid, userId));
+            ret.setOXGuardUser(new OXGuardUser(userId, cid));
+            ret.setOXUser(guardUserService.getUser(cid, userId));
         }
         return ret;
     }
