@@ -56,7 +56,8 @@ import com.openexchange.exception.OXException;
 import com.openexchange.guard.keymanagement.commons.GuardKeys;
 import com.openexchange.guard.keymanagement.commons.RecipKey;
 import com.openexchange.guard.user.UserIdentity;
-import com.openexchange.pgp.core.PGPSignatureVerificationResult;
+import com.openexchange.pgp.core.PGPDecryptionResult;
+import com.openexchange.pgp.keys.common.PGPSymmetricKey;
 
 /**
  * {@link PGPCryptoService}
@@ -122,10 +123,10 @@ public interface PGPCryptoService {
      * @param input The input stream to read the data from
      * @param output The output stream to write the decoded data to
      * @param recipient The PGP user identity of the user who want's to decode the data
-     * @return A list of Signature verification results, or an empty list, if the encrypted data was not signed
+     * @return A result object containing information about signature verification
      * @throws OXException
      */
-    public List<PGPSignatureVerificationResult> decrypt(InputStream input, OutputStream output, UserIdentity recipient) throws OXException;
+    public PGPDecryptionResult decrypt(InputStream input, OutputStream output, UserIdentity recipient) throws OXException;
 
     /**
      * Decrypts data with a specific key.
@@ -134,8 +135,20 @@ public interface PGPCryptoService {
      * @param output The output stream to write the decoded data to
      * @param key The specific key used for decryption
      * @param password The password for the secret key
-     * @return A list of Signature verification results, or an empty list, if the encrypted data was not signed
+     * @return A result object containing information about signature verification
      * @throws OXException
      */
-    public List<PGPSignatureVerificationResult> decrypt(InputStream input, OutputStream output, GuardKeys key, String password) throws OXException;
+    public PGPDecryptionResult decrypt(InputStream input, OutputStream output, GuardKeys key, String password) throws OXException;
+
+    /**
+     *
+     * Decrypts data with a PGP symmetric session key.
+     *
+     * @param input The input stream to read the data from
+     * @param output The output stream to write the decoded data to
+     * @param  symmetricKey The symmetric key for decrypting the PGP data
+     * @param recipient The PGP user identity of the user who want's to decode the data
+     * @return A list of Signature verification results, or an empty list, if the encrypted data was not signed
+     */
+    public PGPDecryptionResult decrypt(InputStream input, OutputStream output, PGPSymmetricKey symmetricKey, UserIdentity recipient) throws OXException;
 }
