@@ -71,7 +71,8 @@ public enum PGPCoreServicesExceptionCodes implements DisplayableOXExceptionCode
     SIGNING_ERROR("An PGP signing error occured: %1$s", PGPCoreServicesExceptionMessages.SIGNING_ERROR,Category.CATEGORY_ERROR,5),
     SIGNATURE_VERIFICATION_ERROR("An PGP signature verification error occured: %1$s",PGPCoreServicesExceptionMessages.SIGNATURE_VERIFICATION_ERROR, Category.CATEGORY_ERROR,6),
     UNEXPECTED_ERROR("Unexpected error occured: %1$s", PGPCoreServicesExceptionMessages.UNEXPECTED_ERROR, CATEGORY_ERROR,7),
-    RECIPIENT_PARSING_ERROR("Unable to parse the given recipient (%1$s)",PGPCoreServicesExceptionMessages.RECIPIENT_PARSING_ERROR,Category.CATEGORY_ERROR,8);
+    RECIPIENT_PARSING_ERROR("Unable to parse the given recipient (%1$s)",PGPCoreServicesExceptionMessages.RECIPIENT_PARSING_ERROR,Category.CATEGORY_ERROR,8),
+    NOT_A_MULTIPART_MSG_ERROR("The provided message is not a valid multipart message", PGPCoreServicesExceptionMessages.NOT_A_MULTIPART_MSG_ERROR, Category.CATEGORY_ERROR, 9);
 
     ;
 
