@@ -53,6 +53,6 @@ class GuardSessionSql {
 
     static final String SELECT_STMT = "SELECT sessionid, token, date, userid, cid FROM oxguard_session WHERE sessionid = ?;";
     static final String INSERT_STMT = "INSERT INTO oxguard_session (sessionid, token, date, userid, cid) VALUES (?, ?, ?, ?, ?) ON DUPLICATE KEY UPDATE sessionid = ?, token = ?, date = ?;";
-    static final String DELETE_BY_ID_STMT = "DELETE FROM oxguard_session WHERE sessionid = ?;";
+    static final String DELETE_BY_ID_STMT = "DELETE FROM oxguard_session WHERE sessionid = ? LIMIT 1;";
     static final String DELETE_OLD_STMT = "DELETE FROM oxguard_session WHERE DATE < NOW() - INTERVAL ? SECOND;";
 }
