@@ -84,6 +84,7 @@ import com.openexchange.guard.common.java.Strings;
 import com.openexchange.guard.common.util.LocaleUtil;
 import com.openexchange.guard.configuration.GuardConfigurationService;
 import com.openexchange.guard.configuration.GuardProperty;
+import com.openexchange.guard.exceptions.GuardCoreExceptionCodes;
 import com.openexchange.guard.translation.GuardTranslationService;
 import com.openexchange.guard.translation.TemplateTransformation;
 import com.openexchange.guard.translation.exceptions.GuardTranslationExceptionCodes;
@@ -135,9 +136,14 @@ public class GuardTranslationServiceImpl implements GuardTranslationService {
         try {
             // Read the languages file
             FileInputStream inputStream = new FileInputStream(l10nDirectory + File.separator + "languages.xml");
-            String xmlfile = IOUtils.toString(inputStream, "UTF-8");
-            inputStream.close();
-
+            String xmlfile;
+            try {
+                xmlfile = IOUtils.toString(inputStream, "UTF-8");
+            } finally {
+                if (inputStream != null) {
+                    inputStream.close();
+                }
+            }
             // Build the XML document
             DocumentBuilderFactory factory = DocumentBuilderFactory.newInstance();
             DocumentBuilder builder = factory.newDocumentBuilder();
@@ -494,13 +500,26 @@ public class GuardTranslationServiceImpl implements GuardTranslationService {
         while (it.hasNext()) {
             Entry<String, Map<String, String>> entry = it.next();
             Map<String, String> value = entry.getValue();
-            if (!value.containsKey(code)) {
-                code = code.substring(0, 2);
+            String avail = null;
+            // Find what locale is available
+            if (value.containsKey(code)) {
+                avail = code;
+            } else {
+                if (value.containsKey(code.substring(0, 2))) {
+                    avail = code.substring(0, 2);
+                } else {  // Try defaults
+                    if (value.containsKey(defaultCode)) {
+                        avail = defaultCode;
+                    } else {
+                        if (value.containsKey(defaultCode.substring(0, 2))) {
+                            avail = defaultCode.substring(0,2);
+                        }
+                    }
+                }
             }
-            if (!value.containsKey(code)) {
-                code = defaultCode; // If we don't have that translation, server default language
+            if (avail != null) {  // If available, add
+                available.put(entry.getKey(), value.get(avail));
             }
-            available.put(entry.getKey(), value.get(code));
         }
         return available;
     }
@@ -554,7 +573,7 @@ public class GuardTranslationServiceImpl implements GuardTranslationService {
                 br.close();
             }
         } catch (IOException e) {
-            throw GuardTranslationExceptionCodes.IO_ERROR.create(e, e.getMessage());
+            throw GuardCoreExceptionCodes.IO_ERROR.create(e, e.getMessage());
         }
     }
 
