@@ -54,19 +54,25 @@ import org.slf4j.LoggerFactory;
 import com.google.gson.JsonObject;
 import com.openexchange.exception.OXException;
 import com.openexchange.guard.GuardMaintenanceService;
-import com.openexchange.guard.UserTestResult;
+import com.openexchange.guard.auth.ResetPasswordHandler;
 import com.openexchange.guard.configuration.GuardConfigurationService;
 import com.openexchange.guard.configuration.GuardProperty;
+import com.openexchange.guard.databaseChecker.GuardDatabaseRepair;
+import com.openexchange.guard.email.storage.ogEmail.Email;
+import com.openexchange.guard.email.storage.ogEmail.EmailStorage;
 import com.openexchange.guard.exceptions.GuardCoreExceptionCodes;
 import com.openexchange.guard.guestreset.GuestResetService;
 import com.openexchange.guard.guestupgrade.GuestUpgradeService;
 import com.openexchange.guard.keymanagement.commons.GuardKeys;
 import com.openexchange.guard.keymanagement.services.GuardKeyService;
+import com.openexchange.guard.keymanagement.services.ImportSystemPublicKey;
 import com.openexchange.guard.mailcreator.MailCreatorService;
 import com.openexchange.guard.notification.GuardNotificationService;
 import com.openexchange.guard.osgi.Services;
 import com.openexchange.guard.oxapi.MailResolver;
 import com.openexchange.guard.ratifier.GuardRatifierService;
+import com.openexchange.guard.secondfactor.SecondFactorService;
+import com.openexchange.guard.servlets.authentication.GuardUserSession;
 import com.openexchange.guard.support.SupportService;
 import com.openexchange.guard.support.SupportServiceImpl;
 import com.openexchange.guard.support.UserChanger;
@@ -150,7 +156,8 @@ public class GuardMaintenanceServiceImpl implements GuardMaintenanceService {
                 reset(email, keyService, keys, templid, defaultLanguage);
                 LOG.info("Reset sent for email {}", email);
             } else {
-                new Auth().resetPass(keys.getUserid(), keys.getContextid(), null, null, null, false);
+                GuardUserSession userSession = new GuardUserSession(null, null, keys.getContextid(), keys.getUserid(), false, null, null);
+                new ResetPasswordHandler().resetPass(userSession, null, null, null, false);
             }
         } catch (Exception e) {
             LOG.error("Error resetting password for " + email, e);
@@ -183,8 +190,14 @@ public class GuardMaintenanceServiceImpl implements GuardMaintenanceService {
      */
     @Override
     public void removePIN(String mail) throws OXException {
+        // Pre 2.10, can be removed soon
         GuardKeyService keyService = Services.getService(GuardKeyService.class);
         keyService.removePin(mail);
+        // 2.10 and post
+        EmailStorage ogEmailStorage = Services.getService(EmailStorage.class);
+        Email ogEmail = ogEmailStorage.getByEmail(mail);
+        SecondFactorService secondFactor = Services.getService(SecondFactorService.class);
+        secondFactor.removeSecondFactor(ogEmail.getUserId(), ogEmail.getContextId());
     }
 
     /*
@@ -193,13 +206,13 @@ public class GuardMaintenanceServiceImpl implements GuardMaintenanceService {
      * @see com.openexchange.guard.GuardMaintenanceService#upgrade(java.lang.String)
      */
     @Override
-    public void upgrade(String mail) throws OXException {
+    public void upgrade(String mail, String userid, String cid) throws OXException {
         GuardRatifierService validatorService = Services.getService(GuardRatifierService.class);
         validatorService.validate(mail);
 
         try {
             GuestUpgradeService upgradeService = Services.getService(GuestUpgradeService.class);
-            upgradeService.upgrade(mail);
+            upgradeService.upgrade(mail, userid, cid);
         } catch (final Exception e) {
             throw GuardMaintenanceExceptionCodes.FAILED_UPGRADING_TO_OX_ACCOUNT.create(e, mail);
         }
@@ -220,6 +233,22 @@ public class GuardMaintenanceServiceImpl implements GuardMaintenanceService {
         resetService.reset(email, config.getIntProperty(GuardProperty.templateID), "", force, null);
     }
 
+    @Override
+    public void importPublic(String file) throws OXException {
+        ImportSystemPublicKey pubImport = Services.getService(ImportSystemPublicKey.class);
+        pubImport.importPublic(file);
+    }
+
+    /* (non-Javadoc)
+     * @see com.openexchange.guard.GuardMaintenanceService#repair()
+     */
+    @Override
+    public StringBuilder repair(boolean dryRun) throws OXException {
+        GuardDatabaseRepair repairService = new GuardDatabaseRepair();
+        return repairService.doRepair(dryRun);
+
+    }
+
     /* (non-Javadoc)
      * @see com.openexchange.guard.GuardMaintenanceService#changeUser(java.lang.String, java.lang.String, int, int)
      */
