@@ -55,21 +55,27 @@ import org.slf4j.LoggerFactory;
 import com.openexchange.config.ConfigTools;
 import com.openexchange.context.ContextService;
 import com.openexchange.guard.GuardMaintenanceService;
+import com.openexchange.guard.activity.ActivityTrackingService;
 import com.openexchange.guard.antiabuse.GuardAntiAbuseService;
 import com.openexchange.guard.cipher.GuardCipherFactoryService;
 import com.openexchange.guard.configuration.GuardConfigurationService;
 import com.openexchange.guard.configuration.GuardProperty;
 import com.openexchange.guard.cron.CleanAuthenticationTokenTask;
-import com.openexchange.guard.cron.CleanFileCacheTask;
 import com.openexchange.guard.cron.CleanRemoteKeyCacheTask;
 import com.openexchange.guard.cron.CleanTemporaryTokensTask;
 import com.openexchange.guard.cron.DailyTaskScheduler;
+import com.openexchange.guard.cron.GuestCleanupTask;
 import com.openexchange.guard.cron.ResetExposedKeysTask;
 import com.openexchange.guard.database.GuardDatabaseService;
 import com.openexchange.guard.database.GuardShardingService;
 import com.openexchange.guard.dns.DNSService;
 import com.openexchange.guard.email.storage.ogEmail.EmailStorage;
 import com.openexchange.guard.encryption.EncryptedItemsStorage;
+import com.openexchange.guard.guest.GuardGuestService;
+import com.openexchange.guard.guest.GuestConverterService;
+import com.openexchange.guard.guest.GuestLookupService;
+import com.openexchange.guard.guest.metadata.storage.GuardGuestEMailMetadataService;
+import com.openexchange.guard.guest.redirector.GuestRedirectorService;
 import com.openexchange.guard.guestreset.GuestResetService;
 import com.openexchange.guard.guestreset.storage.TemporaryTokenService;
 import com.openexchange.guard.guestupgrade.GuestUpgradeService;
@@ -79,8 +85,10 @@ import com.openexchange.guard.hkpclient.services.HKPClientService;
 import com.openexchange.guard.internal.GuardMaintenanceServiceImpl;
 import com.openexchange.guard.internal.GuardVersion;
 import com.openexchange.guard.keymanagement.services.AccountCreationService;
+import com.openexchange.guard.keymanagement.services.ContactKeyService;
 import com.openexchange.guard.keymanagement.services.GuardKeyService;
 import com.openexchange.guard.keymanagement.services.GuardMasterKeyService;
+import com.openexchange.guard.keymanagement.services.ImportSystemPublicKey;
 import com.openexchange.guard.keymanagement.services.KeyCreationService;
 import com.openexchange.guard.keymanagement.services.KeyImportService;
 import com.openexchange.guard.keymanagement.services.KeyRecoveryService;
@@ -95,24 +103,26 @@ import com.openexchange.guard.keymanagement.storage.PGPKeysStorage;
 import com.openexchange.guard.keymanagement.storage.RemoteKeyCacheStorage;
 import com.openexchange.guard.keys.PGPKeyService;
 import com.openexchange.guard.mailcreator.MailCreatorService;
-import com.openexchange.guard.mailvelope.MailvelopeStorage;
-import com.openexchange.guard.mailvelope.internal.MailvelopeStorageImpl;
 import com.openexchange.guard.mime.services.MimeEncryptionService;
 import com.openexchange.guard.notification.GuardNotificationService;
 import com.openexchange.guard.oxapi.pooling.HttpConnectionPoolService;
 import com.openexchange.guard.pgpcore.services.PGPCryptoService;
+import com.openexchange.guard.pgpcore.services.PGPKeySigningService;
+import com.openexchange.guard.pgpcore.services.PGPPacketService;
 import com.openexchange.guard.pgpcore.services.PGPSigningService;
 import com.openexchange.guard.pgpcore.services.TokenAuthenticationService;
 import com.openexchange.guard.ratifier.GuardRatifierService;
+import com.openexchange.guard.secondfactor.SecondFactorService;
 import com.openexchange.guard.servlets.GuardServlets;
 import com.openexchange.guard.session.GuardSessionService;
 import com.openexchange.guard.settings.GlobalSettingsStorage;
+import com.openexchange.guard.sharing.SharingService;
 import com.openexchange.guard.storage.Storage;
 import com.openexchange.guard.storage.cache.FileCacheStorage;
 import com.openexchange.guard.translation.GuardTranslationService;
 import com.openexchange.guard.update.GuardUpdateService;
-import com.openexchange.guard.user.GuardUserService;
 import com.openexchange.guard.update.internal.GuardKeysUpdater;
+import com.openexchange.guard.user.OXUserService;
 import com.openexchange.osgi.HousekeepingActivator;
 import com.openexchange.pgp.keys.parsing.PGPKeyRingParser;
 import com.openexchange.startup.SignalHttpApiAvailabilityService;
@@ -144,9 +154,16 @@ public class GuardServiceActivator extends HousekeepingActivator {
             GuardShardingService.class, KeyTableStorage.class, PGPKeysStorage.class, EncryptedItemsStorage.class, OGPGPKeysStorage.class,
             DeletedKeysStorage.class, Storage.class, GuardUpdateService.class, GuestUpgradeService.class, HKPClientService.class,
             PGPCryptoService.class, PGPSigningService.class, TokenAuthenticationService.class, FileCacheStorage.class, RemoteKeyCacheStorage.class,
-            GuestResetService.class, TemporaryTokenService.class, KeyCreationService.class, GuardUserService.class, KeyRecoveryService.class,
+            GuestResetService.class, TemporaryTokenService.class, KeyCreationService.class, OXUserService.class, KeyRecoveryService.class,
             PasswordChangeService.class, AccountCreationService.class, PublicExternalKeyService.class, KeyImportService.class, ContextService.class,
-            MimeEncryptionService.class, PGPKeyRingParser.class, GuardKeysUpdater.class };
+            MimeEncryptionService.class, PGPKeyRingParser.class, ImportSystemPublicKey.class, PGPPacketService.class, GuardGuestService.class,
+            PGPKeySigningService.class, ContactKeyService.class, SharingService.class, GuardGuestEMailMetadataService.class,
+            GuestConverterService.class, GuestRedirectorService.class, GuestLookupService.class, SecondFactorService.class, GuardKeysUpdater.class };
+    }
+
+    @Override
+    protected Class<?>[] getOptionalServices() {
+        return new Class[] { ActivityTrackingService.class };
     }
 
     /*
@@ -172,10 +189,6 @@ public class GuardServiceActivator extends HousekeepingActivator {
         registerService(ResponseHandler.class, new ResponseHandlerImpl(getService(GuardMasterKeyService.class), getService(GuardCipherFactoryService.class)));
         trackService(ResponseHandler.class);
 
-        // Maybe stuff Mailvelope storage and services to a different bundle?
-        registerService(MailvelopeStorage.class, new MailvelopeStorageImpl());
-        trackService(MailvelopeStorage.class);
-
         openTrackers();
 
         Services.getService(GuardUpdateService.class).createMasterKeysIfNecessary();
@@ -183,17 +196,21 @@ public class GuardServiceActivator extends HousekeepingActivator {
         // Initializing daily cron jobs
         GuardConfigurationService guardConfigurationService = getService(GuardConfigurationService.class);
         dailyJobScheduler = new DailyTaskScheduler(guardConfigurationService.getIntProperty(GuardProperty.cronHour));
-        dailyJobScheduler.register(new CleanFileCacheTask(guardConfigurationService.getIntProperty(GuardProperty.cacheDays)));
         dailyJobScheduler.register(new CleanRemoteKeyCacheTask(guardConfigurationService.getIntProperty(GuardProperty.pgpCacheDays)));
         dailyJobScheduler.register(new CleanAuthenticationTokenTask(ConfigTools.parseTimespan(guardConfigurationService.getProperty(GuardProperty.authLifeTime))));
         dailyJobScheduler.register(new CleanTemporaryTokensTask(guardConfigurationService.getIntProperty(GuardProperty.temporaryTokenLifespan)));
+        dailyJobScheduler.register(new GuestCleanupTask(guardConfigurationService.getIntProperty(GuardProperty.guestCleanedAfterDaysOfInactivity),
+            Services.getServiceLookup().getOptionalService(ActivityTrackingService.class),
+            Services.getService(FileCacheStorage.class),
+            Services.getService(GuardGuestEMailMetadataService.class),
+            Services.getService(GuestRedirectorService.class)));
         int exposedKeyDurationInHours = guardConfigurationService.getIntProperty(GuardProperty.exposedKeyDurationInHours);
         if (exposedKeyDurationInHours > 0) {
             dailyJobScheduler.register(new ResetExposedKeysTask(exposedKeyDurationInHours));
         }
 
         //Registering the OX Guard servlets
-        GuardServlets.registerServlets(getService(HttpService.class));
+        GuardServlets.registerServlets(getService(HttpService.class), getService(GuardConfigurationService.class));
     }
 
     /*
