@@ -99,6 +99,7 @@ import com.openexchange.guard.pgp.decryption.GuardEMailDecryptionService;
 import com.openexchange.guard.pgp.decryption.PGPDecryptionResult;
 import com.openexchange.guard.pgp.decryption.impl.GuardEMailDecryptionServiceImpl;
 import com.openexchange.guard.ratifier.GuardRatifierService;
+import com.openexchange.guard.servlets.authentication.GuardUserSession;
 import com.openexchange.pgp.keys.parsing.KeyRingParserResult;
 import com.openexchange.pgp.keys.parsing.PGPKeyRingParser;
 import com.openexchange.pgp.keys.parsing.PGPPublicKeyRingFactory;
@@ -269,10 +270,12 @@ public class PGPPublicHandler {
         return null;
     }
 
-    public void saveKeyAttachment(HttpServletRequest request, HttpServletResponse response, int userid, int cid, OxCookie ck) throws Exception {
+    public void saveKeyAttachment(HttpServletRequest request, HttpServletResponse response, OxCookie ck, GuardUserSession userSession) throws Exception {
         String folder = ServletUtils.getStringParameter(request, "folder", true);
         String emailid = ServletUtils.getStringParameter(request, "emailid", true);
         String attach = ServletUtils.getStringParameter(request, "attach", true);
+        int userid = userSession.getGuardUserId();
+        int cid = userSession.getGuardContextId();
         Api ap = new Api(ck, request);
         String session = request.getParameter("session");
         String userAgent = request.getHeader("User-Agent");
@@ -294,7 +297,7 @@ public class PGPPublicHandler {
             // Handle encrypted public key
             String filename = ServletUtils.getStringParameter(request, "filename", true);
             boolean inline = ServletUtils.getBooleanParameter(request, "inline",false);
-            UserData userdata = new UserData(auth, ck);
+            UserData userdata = new UserData(auth, userSession);
             String password = userdata.getEncr_password();
             if (password == null) {
                 ServletUtils.sendNotAcceptable(response, "bad password");
