@@ -69,44 +69,7 @@ public class PGPSender {
 
     private static Logger LOG = LoggerFactory.getLogger(PGPSender.class);
 
-    /**
-     * Sends provided email
-     *
-     * @param mail
-     * @throws OXException
-     * @throws Exception
-     */
-    public String sendPGPMail(PGPMail mail, String host, String remoteIp) throws OXException {
-        boolean lInline = mail.isInline();
-
-        GuardKeyService keyService = Services.getService(GuardKeyService.class);
-        GuardKeys senderkey = keyService.getKeys(mail.getUserid(), mail.getCid());
-        if (senderkey == null) {  // Not a good userid and cid
-            throw GuardPGPExceptionCodes.SENDER_KEYS_MISSING.create();
-        }
-
-        // Check if inline requested by a recipient
-        List<RecipKey> recipients = mail.getRecipients();
-        for (int i = 0; i < recipients.size(); i++) {
-            if (recipients.get(i).isInline()) {
-                lInline = true;
-            }
-        }
-
-        // we need to add the sender to the list of recipients so can be read in sent folder
-        RecipKey sender = new RecipKey();
-        sender.setPGPPrivateKeyRing(senderkey.getPGPPublicKeyRing());
-        mail.getRecipients().add(sender);
-
-        if (lInline && !mail.isDraft()) {  // Drafts will be saved as PGP Mime
-            sendPGPInline(mail, senderkey, host, remoteIp);
-        } else {
-            return sendPGPMime(mail, mail.getRecipients(), senderkey, host, remoteIp);
-        }
-        return null;
-    }
-
-    private void sendPGPInline(PGPMail mail, GuardKeys senderkey, String host, String remoteIp) throws OXException {
+    private void sendPGPInline(PGPMail mail, GuardKeys senderkey, String host) throws OXException {
         List<RecipKey> guestRecip = new ArrayList<RecipKey>();
         List<RecipKey> inlineRecip = new ArrayList<RecipKey>();
         RecipKey sender = new RecipKey();
@@ -129,7 +92,7 @@ public class PGPSender {
         // Send guest emails (these are PGP Mime)
         if (guestRecip.size() > 0) {
             guestRecip.add(sender);
-            sendPGPMime(mail, guestRecip, senderkey, host, remoteIp);
+            sendPGPMime(mail, guestRecip, senderkey, host);
             // If we have sent some of the emails to a guest, then we need to remove them for the inline emails and mark the headers
             updateJsonRecip(mail, inlineRecip);
         }
@@ -174,7 +137,7 @@ public class PGPSender {
                 JsonArray fromarray = data.get("from").getAsJsonArray().get(0).getAsJsonArray();
                 GuardNotificationService guardNotificationService = Services.getService(GuardNotificationService.class);
                 List<BodyPart> bpAttachments = getBodyParts(attachments);
-                guardNotificationService.send(content, bpAttachments, getFromEmailAddress(recipients, fromarray.get(1).getAsString()), senderkey.getContextid(), sender.getLang(), getMessageID(), remoteIp);
+                guardNotificationService.send(content, bpAttachments, getFromEmailAddress(recipients, fromarray.get(1).getAsString()), senderkey.getContextid(), sender.getLang(), getMessageID(), null);
             }
         }
     }
@@ -245,7 +208,7 @@ public class PGPSender {
         return toString.toString();
     }
 
-    private String sendPGPMime(PGPMail mail, List<RecipKey> guestRecip, GuardKeys senderkey, String host, String remoteIp) throws OXException {
+    private String sendPGPMime(PGPMail mail, List<RecipKey> guestRecip, GuardKeys senderkey, String host) throws OXException {
         byte[] mime = null;
         String messageId = getMessageID();
         try {
@@ -266,7 +229,7 @@ public class PGPSender {
             } else {
                 PGPUtils.encrypt(encrypted, mime, "encrypted.asc", guestRecip, true, true);
             }
-            String resp = sendMimeEmails(mail, guestRecip, encrypted, messageId, host, senderkey.getUserid(), senderkey.getContextid(), remoteIp);
+            String resp = sendMimeEmails(mail, guestRecip, encrypted, messageId, host, senderkey.getUserid(), senderkey.getContextid());
             if (Utilities.checkFail(resp) || !resp.contains("fail")) {
                 handleFlags(mail);
             } else {
@@ -325,7 +288,7 @@ public class PGPSender {
      * @return
      * @throws MessagingException
      */
-    private String sendMimeEmails(PGPMail mail, List<RecipKey> guestRecip, ByteArrayOutputStream encrypted, String messageId, String host, int senderId, int senderCid, String remoteIp) throws Exception {
+    private String sendMimeEmails(PGPMail mail, List<RecipKey> guestRecip, ByteArrayOutputStream encrypted, String messageId, String host, int senderId, int senderCid) throws Exception {
         JsonObject data = mail.getContent().getAsJsonObject("data");
         List<String> failures = new ArrayList<String>();
         Api ap = new Api(mail.getOXCookie(), mail.getSession(), mail.getUseragent());
@@ -436,7 +399,7 @@ public class PGPSender {
                             GuardNotificationService guardNotificationService = Services.getService(GuardNotificationService.class);
                             List<BodyPart> bpAttachments = getBodyParts(attachments);
                             try {
-                                guardNotificationService.send(email, bpAttachments, getFromEmailAddress(guestRecip, fromEmail), senderCid, recip.getLang(), messageId, remoteIp);
+                                guardNotificationService.send(email, bpAttachments, getFromEmailAddress(guestRecip, fromEmail), senderCid, recip.getLang(), messageId, null);
                             } catch (OXException e) {
                                 return "fail";
                             }
@@ -509,7 +472,7 @@ public class PGPSender {
             } else { // Otherwise, use the SMTP service
                 GuardNotificationService guardNotificationService = Services.getService(GuardNotificationService.class);
                 try {
-                    guardNotificationService.sendMessage(newMessage, getFromEmailAddress(guestRecip, fromaddr.getAddress()), senderCid, guestRecip.get(0).getLang(), remoteIp);
+                    guardNotificationService.sendMessage(newMessage, getFromEmailAddress(guestRecip, fromaddr.getAddress()), senderCid, guestRecip.get(0).getLang(), null);
                 } catch (OXException e) {
                     return "fail";
                 }
@@ -676,14 +639,14 @@ public class PGPSender {
      * @param recipients
      * @return
      */
-    private List<String> getLanguages(List<RecipKey> recipients) {
+    private String[] getLanguages(List<RecipKey> recipients) {
         List<String> languages = new ArrayList<String>();
         for (RecipKey recip : recipients) {
             if (!languages.contains(recip.getLang())) {
                 languages.add(recip.getLang());
             }
         }
-        return languages;
+        return languages.toArray(new String[languages.size()]);
     }
 
     /**
