@@ -58,7 +58,6 @@ import java.nio.charset.StandardCharsets;
 import java.security.NoSuchProviderException;
 import java.security.SecureRandom;
 import java.security.SignatureException;
-import java.util.ArrayList;
 import java.util.Date;
 import java.util.Iterator;
 import java.util.List;
@@ -99,6 +98,8 @@ import com.openexchange.guard.cipher.GuardCipherAlgorithm;
 import com.openexchange.guard.cipher.GuardCipherFactoryService;
 import com.openexchange.guard.cipher.GuardCipherService;
 import com.openexchange.guard.common.util.LongUtil;
+import com.openexchange.guard.configuration.GuardConfigurationService;
+import com.openexchange.guard.configuration.GuardProperty;
 import com.openexchange.guard.exceptions.GuardAuthExceptionCodes;
 import com.openexchange.guard.hkpclient.services.HKPClientService;
 import com.openexchange.guard.hkpclient.services.RemoteKeyResult;
@@ -107,9 +108,7 @@ import com.openexchange.guard.keymanagement.commons.RecipKey;
 import com.openexchange.guard.keys.PGPKeyService;
 import com.openexchange.guard.osgi.Services;
 import com.openexchange.guard.pgp.exceptions.GuardPGPExceptionCodes;
-import com.openexchange.guard.pgpcore.services.FromHeaderVerifier;
 import com.openexchange.guard.session.GuardSessionService;
-import com.openexchange.pgp.core.PGPSignatureVerificationResult;
 import com.openexchange.pgp.keys.tools.PGPKeysUtil;
 
 public class PGPUtils {
@@ -323,43 +322,6 @@ public class PGPUtils {
         return result;
     }
 
-    /**
-     * Verify the from address is in the list of userIds for the public keys
-     * @param result
-     * @param keyring
-     * @param fromAddress
-     * @return
-     */
-    private PGPResult verifyFrom(PGPResult result, PGPPublicKeyRing keyring, String fromAddress) {
-        if (!result.isVerified()) {
-            return result;
-        }
-        if (fromAddress == null || fromAddress.isEmpty()) {
-            result.setVerified(false);
-            result.setError("Unable to verify due to missing FROM address");
-            return result;
-        }
-        ArrayList<String> userIds = new ArrayList<String>();
-        Iterator<PGPPublicKey> keys = keyring.getPublicKeys();
-        while (keys.hasNext()) {
-            PGPPublicKey key = (PGPPublicKey) keys.next();
-            Iterator ids = key.getUserIDs();
-            while (ids.hasNext()) {
-                userIds.add((String) ids.next());
-            }
-        }
-        Iterator ids = userIds.iterator();
-        while (ids.hasNext()) {
-            String id = (String) ids.next();
-            if (id.toLowerCase().contains(fromAddress.toLowerCase())) return result;
-
-        }
-        result.setVerified(false);
-        result.setError("The issuer of the signature was not found in the FROM header for the MIME message.");
-        return result;
-
-    }
-
     /**
      * Verify signature in inline signature
      *
@@ -426,13 +388,12 @@ public class PGPUtils {
             } else {
                 result.setVerified(false);
             }
-            result = verifyFrom(result, pgpRing, fromAddress);
 
         } else {
             result.setSignature(false);
             // no signature
         }
-        return result;
+        return (result);
     }
 
     /**
@@ -528,13 +489,14 @@ public class PGPUtils {
         } else {
             result.setVerified(false);
         }
-        return (verifyFrom(result, pgpRing, fromAddress));
+        return (result);
 
     }
 
     private static PGPPublicKeyRing checkPublicKeys (Long id, String fromEmail, PGPResult result) throws OXException {
         HKPClientService hkpClient = Services.getService(HKPClientService.class);
-        RemoteKeyResult remote = hkpClient.find(null, fromEmail, id);
+        GuardConfigurationService guardConfig = Services.getService(GuardConfigurationService.class);
+        RemoteKeyResult remote = hkpClient.find(null, fromEmail, id, guardConfig.getIntProperty(GuardProperty.remoteKeyLookupTimeout));
         if (remote != null && remote.hasResult()) {
             if (remote.getSource().isTrusted()) {
                 result.setSource(remote.getSource());
@@ -775,16 +737,6 @@ public class PGPUtils {
 
     }
 
-    public static String encodeEPass(String password, String jSessionId, int userid, int cid) throws Exception {
-        GuardCipherService cipherService = Services.getService(GuardCipherFactoryService.class).getCipherService(GuardCipherAlgorithm.AES_CBC);
-        GuardSessionService sessionService = Services.getService(GuardSessionService.class);
-        String token = sessionService.getToken(jSessionId);
-        if (token == null) {
-            token = sessionService.newToken(jSessionId, userid, cid);
-        }
-        return (cipherService.encrypt(password, token));
-    }
-
     public static String decodeEPass(String epass, String sessionId) throws OXException {
         GuardSessionService sessionService = Services.getService(GuardSessionService.class);
         String token = sessionService.getToken(sessionId);
