@@ -77,8 +77,11 @@ import org.slf4j.LoggerFactory;
 
 import com.google.gson.JsonArray;
 import com.google.gson.JsonObject;
+import com.openexchange.antiabuse.Protocol;
+import com.openexchange.antiabuse.ReportValue;
 import com.openexchange.exception.OXException;
 import com.openexchange.guard.antiabuse.GuardAntiAbuseService;
+import com.openexchange.guard.common.servlets.utils.AntiAbuseUtils;
 import com.openexchange.guard.common.util.JsonUtil;
 import com.openexchange.guard.exceptions.GuardAuthExceptionCodes;
 import com.openexchange.guard.exceptions.GuardCoreExceptionCodes;
@@ -86,7 +89,7 @@ import com.openexchange.guard.file.FileTyper;
 import com.openexchange.guard.keymanagement.commons.GuardKeys;
 import com.openexchange.guard.keymanagement.commons.RecipKey;
 import com.openexchange.guard.keymanagement.services.GuardKeyService;
-import com.openexchange.guard.mail.Attachment;
+import com.openexchange.guard.mime.services.Attachment;
 import com.openexchange.guard.osgi.Services;
 import com.openexchange.guard.oxapi.Api;
 import com.openexchange.guard.oxapi.ApiResponse;
@@ -106,7 +109,7 @@ import com.openexchange.guard.pgp.exceptions.GuardPGPExceptionCodes;
  */
 public class GuardEMailDecryptionServiceImpl implements GuardEMailDecryptionService {
 
-	private static Logger LOG = LoggerFactory.getLogger(GuardEMailDecryptionServiceImpl.class);
+    private static Logger LOG = LoggerFactory.getLogger(GuardEMailDecryptionServiceImpl.class);
 
     /**
      * Retrieves the mime email from the OX backend
@@ -149,14 +152,14 @@ public class GuardEMailDecryptionServiceImpl implements GuardEMailDecryptionServ
         // Remove surrounding HTML
         int i = content.indexOf("-----BEGIN PGP MESSAGE");
         if (i > 0) {
-        	content = content.substring(i);
+            content = content.substring(i);
         }
         int j = content.indexOf("-----END PGP MESSAGE");
         if (j > 0) {
-        	int k = content.indexOf("\r", j);
-        	if (k > 0) {
-        		content = content.substring(0, k);
-        	}
+            int k = content.indexOf("\r", j);
+            if (k > 0) {
+                content = content.substring(0, k);
+            }
         }
         // Convert <br> to "\r", but not if \r already there
         content = content.replace("\r<br>", "\r").replace("<br>\r", "\r").replace("<br>", "\r");
@@ -164,29 +167,29 @@ public class GuardEMailDecryptionServiceImpl implements GuardEMailDecryptionServ
         char[] chars = content.toCharArray();
         // Remove non-ascii characters (sometimes appear in body due to encoding)
         for (char c : chars) {
-        	if (c < 0x7f) {
-        		sb.append(c);
-        	}
+            if (c < 0x7f) {
+                sb.append(c);
+            }
         }
         return sb.toString();
     }
 
     private String getInlineFrom (JsonObject json) {
-    	String address = null;
-    	try {
-	    	JsonObject data = json.get("data").getAsJsonObject();
-	    	if (data.get("from").isJsonArray()) {
-	    		JsonArray fromArray = data.get("from").getAsJsonArray();
-	    		address = fromArray.get(0).getAsJsonArray().get(1).getAsString().trim();
-	    	}
-	    	if (data.get("from").isJsonObject()) {
-	    		address = data.get("from").getAsJsonArray().get(1).getAsString().trim();
-	    	}
-	    	return address;
-    	} catch (Exception ex) {
-    		LOG.error("Problem parsing inline message for FROM address ", ex);
-    	}
-    	return address;
+        String address = null;
+        try {
+            JsonObject data = json.get("data").getAsJsonObject();
+            if (data.get("from").isJsonArray()) {
+                JsonArray fromArray = data.get("from").getAsJsonArray();
+                address = fromArray.get(0).getAsJsonArray().get(1).getAsString().trim();
+            }
+            if (data.get("from").isJsonObject()) {
+                address = data.get("from").getAsJsonArray().get(1).getAsString().trim();
+            }
+            return address;
+        } catch (Exception ex) {
+            LOG.error("Problem parsing inline message for FROM address ", ex);
+        }
+        return address;
     }
 
     //FIXME/TODO: this method should be placed in another class
@@ -254,7 +257,7 @@ public class GuardEMailDecryptionServiceImpl implements GuardEMailDecryptionServ
    private void checkForBruteForce(int userid, int cid, String password, String ip) throws OXException {
        //Check for BF
        GuardAntiAbuseService antiabuse = Services.getService(GuardAntiAbuseService.class);
-       if(antiabuse.blockLogin(userid, cid, password, ip)) {
+       if(antiabuse.blockLogin(AntiAbuseUtils.getAllowParameter(userid + "-" + cid, password, ip, null, null))) {
            throw GuardAuthExceptionCodes.LOCKOUT.create();
        }
    }
@@ -267,16 +270,16 @@ public class GuardEMailDecryptionServiceImpl implements GuardEMailDecryptionServ
     */
    private void countBruteForceAttempt(int userid, int cid, String password, String ip) throws OXException {
        GuardAntiAbuseService badService = Services.getService(GuardAntiAbuseService.class);
-       badService.reportLogin(false, userid, cid, password, ip);
+       badService.report(AntiAbuseUtils.getReportParameter(ReportValue.FAILURE, userid + "-" + cid, password, ip, null, null));
    }
 
    private String getFrom (MimeMessage msg) throws MessagingException {
-	   Address[] fromArray = msg.getFrom();
-	   if (fromArray != null && fromArray.length > 0) {
-		   InternetAddress from = new InternetAddress(fromArray[0].toString());
-		   return from.getAddress();
-	   }
-	   return "";
+       Address[] fromArray = msg.getFrom();
+       if (fromArray != null && fromArray.length > 0) {
+           InternetAddress from = new InternetAddress(fromArray[0].toString());
+           return from.getAddress();
+       }
+       return "";
    }
 
     @Override
@@ -312,7 +315,7 @@ public class GuardEMailDecryptionServiceImpl implements GuardEMailDecryptionServ
     @Override
     public PGPDecryptionResult decryptInlineEmail(OxCookie cookie, String session, String userAgent, String emailFolder, String emailId, int attachmentId, int userId, int contextId, String password, String remoteIp) throws OXException {
         try {
-        	checkForBruteForce(userId, contextId, password, remoteIp);
+            checkForBruteForce(userId, contextId, password, remoteIp);
 
             //Getting the Inline Email
             String jsonString = new Api(cookie, session, userAgent).getMail(emailId, emailFolder);
@@ -330,7 +333,7 @@ public class GuardEMailDecryptionServiceImpl implements GuardEMailDecryptionServ
         }
         catch(OXException e) {
             if(e.getExceptionCode() == GuardPGPExceptionCodes.BAD_PASSWORD_ERROR) {
-            	countBruteForceAttempt(userId, contextId, password, remoteIp);
+                countBruteForceAttempt(userId, contextId, password, remoteIp);
             }
             throw e;
         }
@@ -348,7 +351,7 @@ public class GuardEMailDecryptionServiceImpl implements GuardEMailDecryptionServ
     public PGPDecryptionResult decryptMimeAttachmentByName(OxCookie cookie, String session, String userAgent, String emailFolder, String emailId, String attachmentName, int userId, int contextId, String password, String remoteIp) throws OXException {
 
         try {
-        	checkForBruteForce(userId, contextId, password, remoteIp);
+            checkForBruteForce(userId, contextId, password, remoteIp);
 
             //Getting the encrypted mime email
             MimeMessage message = getMimeEMail(cookie, session, userAgent, emailFolder, emailId);
@@ -369,7 +372,7 @@ public class GuardEMailDecryptionServiceImpl implements GuardEMailDecryptionServ
         }
         catch(OXException e) {
             if(e.getExceptionCode() == GuardPGPExceptionCodes.BAD_PASSWORD_ERROR) {
-            	countBruteForceAttempt(userId, contextId, password, remoteIp);
+                countBruteForceAttempt(userId, contextId, password, remoteIp);
             }
             throw e;
         }
@@ -381,7 +384,7 @@ public class GuardEMailDecryptionServiceImpl implements GuardEMailDecryptionServ
     @Override
     public PGPDecryptionResult decryptMimeAttachmentById(OxCookie cookie, String session, String userAgent, String emailFolder, String emailId, String attachmentId, int userId, int contextId, String password, String remoteIp) throws OXException {
         try {
-        	checkForBruteForce(userId, contextId, password, remoteIp);
+            checkForBruteForce(userId, contextId, password, remoteIp);
 
             //Getting the encrypted mime email
             MimeMessage message = getMimeEMail(cookie, session, userAgent, emailFolder, emailId);
@@ -403,7 +406,7 @@ public class GuardEMailDecryptionServiceImpl implements GuardEMailDecryptionServ
         }
         catch(OXException e) {
             if(e.getExceptionCode() == GuardPGPExceptionCodes.BAD_PASSWORD_ERROR) {
-            	countBruteForceAttempt(userId, contextId, password, remoteIp);
+                countBruteForceAttempt(userId, contextId, password, remoteIp);
             }
             throw e;
         }
@@ -421,7 +424,7 @@ public class GuardEMailDecryptionServiceImpl implements GuardEMailDecryptionServ
     public PGPDecryptionResult decryptInlineAttachment(OxCookie cookie, String session, String userAgent, String emailFolder, String emailId, int attachmentId, int userId, int contextId, String password, String remoteIp) throws OXException {
 
         try {
-        	checkForBruteForce(userId, contextId, password, remoteIp);
+            checkForBruteForce(userId, contextId, password, remoteIp);
 
             //Get the encrypted attachment
             Api api = new Api(cookie, session, userAgent);
@@ -444,7 +447,7 @@ public class GuardEMailDecryptionServiceImpl implements GuardEMailDecryptionServ
         }
         catch (OXException e) {
             if(e.getExceptionCode() == GuardPGPExceptionCodes.BAD_PASSWORD_ERROR) {
-            	countBruteForceAttempt(userId, contextId, password, remoteIp);
+                countBruteForceAttempt(userId, contextId, password, remoteIp);
             }
             throw e;
         }
@@ -466,7 +469,7 @@ public class GuardEMailDecryptionServiceImpl implements GuardEMailDecryptionServ
         }
         catch (OXException e) {
             if(e.getExceptionCode() == GuardPGPExceptionCodes.BAD_PASSWORD_ERROR) {
-            	countBruteForceAttempt(userId, contextId, password, remoteIp);
+                countBruteForceAttempt(userId, contextId, password, remoteIp);
             }
             throw e;
         }
