@@ -57,7 +57,6 @@ import java.security.SignatureException;
 import java.util.Properties;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
-
 import javax.mail.Address;
 import javax.mail.BodyPart;
 import javax.mail.MessagingException;
@@ -68,15 +67,15 @@ import javax.mail.internet.MimeMessage;
 import javax.mail.internet.MimeMultipart;
 import javax.mail.internet.MimeUtility;
 import org.apache.commons.io.IOUtils;
+import org.apache.commons.lang.StringUtils;
 import org.bouncycastle.openpgp.PGPException;
 import org.bouncycastle.util.encoders.Base64;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import com.openexchange.exception.OXException;
 import com.openexchange.guard.exceptions.GuardCoreExceptionCodes;
-import com.openexchange.guard.mail.MimeParser;
-import com.openexchange.guard.mail.SignMime;
-import com.openexchange.guard.osgi.Services;
+import com.openexchange.guard.pgp.signing.impl.SignatureResults;
+import com.openexchange.guard.mime.services.MimeParser;
 import com.openexchange.guard.oxapi.Api;
 import com.openexchange.guard.oxapi.OxCookie;
 import com.openexchange.guard.pgp.PGPResult;
@@ -84,18 +83,21 @@ import com.openexchange.guard.pgp.PGPUtils;
 import com.openexchange.guard.pgp.exceptions.GuardPGPExceptionCodes;
 import com.openexchange.guard.pgp.signing.EmailSignatureVerificationResult;
 import com.openexchange.guard.pgp.signing.GuardEmailSigningService;
-import com.openexchange.guard.ratifier.GuardRatifierService;
+
 
 /**
  * Default implementation of {@link GuardEmailSignignService}
  *
  * @author <a href="mailto:benjamin.gruedelbach@open-xchange.com">Benjamin Gruedelbach</a>
+ * @author <a href="mailto:greg.hill@open-xchange.com">Greg Hill</a>
  * @since v2.4.0
  */
 public class GuardEmailSigningServiceImpl implements GuardEmailSigningService {
 
     private static Logger LOG = LoggerFactory.getLogger(GuardEmailSigningServiceImpl.class);
 
+    private final String BeginSigned = "-----BEGIN PGP SIGNED MESSAGE-----";
+
     /**
      * Retrieves the mime email from the OX backend
      *
@@ -136,10 +138,7 @@ public class GuardEmailSigningServiceImpl implements GuardEmailSigningService {
             if (encoding != null) {
                 String encoded = encoding[0];
                 InputStream encodedStream = bp.getInputStream();
-                InputStream decoded = MimeUtility.decode(encodedStream, encoded);
-                ByteArrayOutputStream out = new ByteArrayOutputStream();
-                IOUtils.copy(decoded, out);
-                return new String(out.toByteArray(), "UTF-8");
+                return getDecoded(encodedStream, encoded);
             } else {
                 ByteArrayOutputStream writer = new ByteArrayOutputStream();
                 mp.getBodyPart(attachmentIndex).writeTo(writer);
@@ -153,6 +152,22 @@ public class GuardEmailSigningServiceImpl implements GuardEmailSigningService {
         return null;
     }
 
+    /**
+     * For Encoded data from Mime message, get the decoded (remove quoted-prinatble, etc)
+     * @param encodedStream
+     * @param encoding
+     * @return
+     * @throws MessagingException
+     * @throws IOException
+     */
+    private String getDecoded(InputStream stream, String encoding) throws MessagingException, IOException {
+        //InputStream decoded = MimeUtility.decode(encodedStream, encoding);    // InputStream already outputs decoded
+        ByteArrayOutputStream out = new ByteArrayOutputStream();
+        IOUtils.copy(stream, out);
+        stream.close();
+        return new String(out.toByteArray(), "UTF-8");
+    }
+
     /**
      * Extracts the PGP MIME signed data from a mime message
      *
@@ -170,7 +185,7 @@ public class GuardEmailSigningServiceImpl implements GuardEmailSigningService {
                     String partData = writer.toString("UTF-8");
 
                     if (!mp.getBodyPart(i).getContentType().contains("application/pgp-signature")) {
-                        return SignMime.normalize(MimeParser.getMimeSection(partData, MimeParser.getBoundry(message)));
+                        return normalize(MimeParser.getMimeSection(partData, MimeParser.getBoundry(message)));
                     }
                 }
             }
@@ -178,6 +193,24 @@ public class GuardEmailSigningServiceImpl implements GuardEmailSigningService {
         return null;
     }
 
+    /**
+     * Remove any whitespaces and normalize with \r\n after each line
+     *
+     * @param content
+     * @return
+     */
+    private String normalize(String content) {
+        StringBuilder sb = new StringBuilder();
+        String[] lines = content.split("\n");
+        for (String line : lines) {
+            if (line.startsWith("- -")) {
+                line = line.substring(2);
+            }
+            sb.append(StringUtils.stripEnd(line, null) + "\r\n");
+        }
+        return (sb.toString());
+    }
+
     /**
      * Extracts the PGP Mime signature from a Mime message
      *
@@ -225,16 +258,32 @@ public class GuardEmailSigningServiceImpl implements GuardEmailSigningService {
      * @return The extracted PGP inline signature
      */
     private String extractInlineSignatureFromInline(String message) {
-        final String regex = "(-----BEGIN PGP SIGNATURE-----.*?-----END PGP SIGNATURE-----)";
+        final String regex = "(-----BEGIN PGP SIGNATURE-----[\\s\\S]*?-----END PGP SIGNATURE-----)";
         Pattern pattern = Pattern.compile(regex, Pattern.DOTALL);
         Matcher matcher = pattern.matcher(message);
         boolean signatureFound = matcher.find();
         if (signatureFound) {
-            return matcher.group(1);
+            return cleanupSignature(matcher.group(1));
         }
         return null;
     }
 
+    /**
+     * Remove any HTML markup from the actual signature data
+     * @param sig
+     * @return
+     */
+    private String cleanupSignature (String sig) {
+        StringBuilder sb = new StringBuilder();
+        String[] lines = sig.split("\r");
+        for (String line: lines) {
+            sb.append(line.trim().replaceAll("<br>", "").replaceAll("[^\\x20-\\x7E]", ""));
+            sb.append("\r");
+        }
+        sb.append("\r");
+        return (sb.toString());
+    }
+
     /**
      * Extracts the signed PGP inline data from an inline Message
      *
@@ -242,6 +291,9 @@ public class GuardEmailSigningServiceImpl implements GuardEmailSigningService {
      * @return The extracted PGP inline signed data
      */
     private String extractInlineMessageFromInline(String message) {
+        if (message.contains("<br>")) {
+            message = cleanupHTML(message);
+        }
         final String regex = "-----BEGIN PGP SIGNED MESSAGE-----.*?\nHash:.*?\n.*?\n(.*).\\s-----BEGIN PGP SIGNATURE-----";
         Pattern pattern = Pattern.compile(regex, Pattern.DOTALL);
         Matcher matcher = pattern.matcher(message);
@@ -252,12 +304,41 @@ public class GuardEmailSigningServiceImpl implements GuardEmailSigningService {
         return null;
     }
 
+    /**
+     * HTML emails have additional markup that often fail inline signatures
+     * Try to remove here
+     * @param data
+     * @return
+     */
+    private String cleanupHTML (String data) {
+        StringBuilder sb = new StringBuilder();
+        String[] lines = data.split("\r");
+        int indentation = 0;  // HTML often indented
+        for (String line: lines) {
+            if (line.contains("-----BEGIN")) {
+                indentation = line.indexOf("-----BEGIN");
+            }
+            line = line.replaceAll("<br>", "").replaceAll("[\\xA0]", " ");  // A0 is space in extended ASCII
+            line = line.substring(indentation > line.length() ? line.length() : indentation);
+            if (line.startsWith("- -")) line = line.substring(2);
+            sb.append(line);
+            sb.append("\r\n");
+        }
+        return (sb.toString());
+    }
+
+    /**
+     * Get the from address from a mimemessage
+     * @param email
+     * @return
+     * @throws MessagingException
+     */
     private String getFromAddress (MimeMessage email) throws MessagingException {
-    	Address[] from = email.getFrom();
-    	String fromEmail = null;
+        Address[] from = email.getFrom();
+        String fromEmail = null;
         if (from != null && from.length > 0) {
-        	InternetAddress addr = new InternetAddress(from[0].toString());
-        	fromEmail = addr.getAddress();
+            InternetAddress addr = new InternetAddress(from[0].toString());
+            fromEmail = addr.getAddress();
         }
         return fromEmail;
     }
@@ -271,26 +352,52 @@ public class GuardEmailSigningServiceImpl implements GuardEmailSigningService {
     public EmailSignatureVerificationResult verifyMimeEmailSignature(OxCookie cookie, String session, String userAgent, String emailFolder, String emailId, int userId, int contextId) throws OXException {
         try {
             MimeMessage email = getMimeEMail(cookie, session, userAgent, emailFolder, emailId);
-            String signedData = extractSignedDataFromMime(email);
-            if (signedData == null) {
-                throw GuardPGPExceptionCodes.SIGNATURE_ERROR_NO_SIGNED_DATA.create();
-            }
-            String signature = extractMimeSignatureFromMime(email);
-            if (signature == null) {
-                throw GuardPGPExceptionCodes.SIGNATURE_ERROR_NO_SIGNATURE.create();
-            }
-            PGPResult pgpResult = new PGPUtils().verifySignature(signedData, signature, userId, contextId, getFromAddress(email));
-            return new EmailSignatureVerificationResult(pgpResult);
+            return verifyMimeEmailSignature(email, userId, contextId);
         } catch (IOException | MessagingException | PGPException e) {
             throw GuardCoreExceptionCodes.UNEXPECTED_ERROR.create(e, e.getMessage());
         }
     }
 
+    private EmailSignatureVerificationResult verifyMimeEmailSignature(MimeMessage email, int userId, int contextId) throws IOException, MessagingException, OXException, PGPException {
+        String signedData = extractSignedDataFromMime(email);
+        if (signedData == null) {
+            throw GuardPGPExceptionCodes.SIGNATURE_ERROR_NO_SIGNED_DATA.create();
+        }
+        String signature = extractMimeSignatureFromMime(email);
+        if (signature == null) {
+            throw GuardPGPExceptionCodes.SIGNATURE_ERROR_NO_SIGNATURE.create();
+        }
+        PGPResult pgpResult = new PGPUtils().verifySignature(signedData, signature, userId, contextId, getFromAddress(email));
+        return new EmailSignatureVerificationResult(pgpResult);
+    }
+
     @Override
     public EmailSignatureVerificationResult verifyInlineEmailSignature(OxCookie cookie, String session, String userAgent, String emailFolder, String emailId, int attachmentId, int userId, int contextId) throws OXException {
         try {
             MimeMessage email = getMimeEMail(cookie, session, userAgent, emailFolder, emailId);
             String inlineData = extractInlineContentFromMime(email, attachmentId);
+            PGPResult pgpResult = verifyInlineEmailSignature (inlineData, userId, contextId, getFromAddress(email));
+                if (pgpResult.isVerified()) {
+                    pgpResult.setContent(getContent(email));
+                }
+                return new EmailSignatureVerificationResult(pgpResult);
+        } catch (MessagingException | IOException e) {
+            throw GuardCoreExceptionCodes.UNEXPECTED_ERROR.create(e, e.getMessage());
+        }
+    }
+
+    /**
+     * Do the verification of signature data
+     * @param inlineData
+     * @param userId
+     * @param contextId
+     * @param fromAddress
+     * @return
+     * @throws OXException
+     */
+    private PGPResult verifyInlineEmailSignature (String inlineData, int userId, int contextId, String fromAddress) throws OXException
+    {
+        try {
             if (inlineData == null) {
                 throw GuardPGPExceptionCodes.SIGNATURE_ERROR_NO_SIGNED_DATA.create();
             }
@@ -304,13 +411,10 @@ public class GuardEmailSigningServiceImpl implements GuardEmailSigningService {
                 throw GuardPGPExceptionCodes.SIGNATURE_ERROR_NO_SIGNED_MESSAGE_FOUND.create();
             }
             try (ByteArrayInputStream signatureStream = new ByteArrayInputStream(signature.getBytes("UTF-8"))) {
-                PGPResult pgpResult = new PGPUtils().verifyInlineSignature(signatureStream, inlineMessage, userId, contextId, getFromAddress(email));
-                if (pgpResult.isVerified()) {
-                    pgpResult.setContent(getContent(email));
-                }
-                return new EmailSignatureVerificationResult(pgpResult);
+                PGPResult pgpResult = new PGPUtils().verifyInlineSignature(signatureStream, inlineMessage, userId, contextId, fromAddress);
+                return pgpResult;
             }
-        } catch (MessagingException | PGPException | SignatureException | IOException e) {
+        } catch (PGPException | SignatureException | IOException e) {
             throw GuardCoreExceptionCodes.UNEXPECTED_ERROR.create(e, e.getMessage());
         }
     }
@@ -321,14 +425,14 @@ public class GuardEmailSigningServiceImpl implements GuardEmailSigningService {
      *
      * @param mime
      * @return
-     * @throws OXException 
+     * @throws OXException
      */
     private String getContent(MimeMessage mime) throws OXException {
         try {
             String newContent = null;
             Object content = mime.getContent();
             if (content instanceof String) {
-                return (getContentInlineBody((String) content));
+                return (getContentInlineBody((String) content, true));
             }
             if (content instanceof Multipart || content instanceof MimeMultipart) {
                 MimeMultipart mp = (MimeMultipart) content;
@@ -339,7 +443,7 @@ public class GuardEmailSigningServiceImpl implements GuardEmailSigningService {
                     if (disp == null || !disp.equals("attachment")) {
                         content = bp.getContent();
                         if (content instanceof String) {
-                            newContent = getContentInlineBody((String) content);
+                            newContent = getContentInlineBody((String) content, true);
                         }
                     }
                 }
@@ -357,9 +461,9 @@ public class GuardEmailSigningServiceImpl implements GuardEmailSigningService {
      *
      * @param data
      * @return
-     * @throws OXException 
+     * @throws OXException
      */
-    public String getContentInlineBody(String data) throws OXException {
+    public String getContentInlineBody(String data, boolean convert) throws OXException {
         int i = data.indexOf("----BEGIN PGP SIGNATURE");
         if (i > -1) {
             data = data.substring(0, i - 1);
@@ -368,10 +472,95 @@ public class GuardEmailSigningServiceImpl implements GuardEmailSigningService {
                 j = data.indexOf("\n", j) + 3;
                 data = data.substring(j);
             }
-            data = data.replace("\n", "<br>");
+            if (convert) data = data.replace("\n", "<br>");
         }
-        GuardRatifierService ratifier = Services.getService(GuardRatifierService.class);
-        data = ratifier.normalise(data);
         return (data);
     }
+
+    /* (non-Javadoc)
+     * @see com.openexchange.guard.pgp.signing.GuardEmailSigningService#verifyEmailSignature(javax.mail.internet.MimeMessage)
+     */
+    @Override
+    public MimeMessage verifyEmailSignature(MimeMessage msg, int userId, int cid) throws OXException {
+
+        try {
+            if (msg.getContentType().toLowerCase().contains("pgp-signature")) {
+                EmailSignatureVerificationResult result = verifyMimeEmailSignature(msg, userId, cid);
+                msg.addHeader("X-Guard-Signature-Result", SignatureResults.toHeader(result));
+            } else {
+                verifyInlineMessage (msg, userId, cid);
+            }
+        } catch (IOException | MessagingException | PGPException e) {
+            throw GuardCoreExceptionCodes.UNEXPECTED_ERROR.create(e, e.getMessage());
+        }
+        return msg;
+    }
+
+    /**
+     * Verify inline signed text message
+     * Remove signature from final email
+     * If HTML fails signature, then remove from message
+     * @param msg
+     * @param userId
+     * @param cid
+     * @return
+     * @throws OXException
+     */
+    private MimeMessage verifyInlineMessage (MimeMessage msg, int userId, int cid) throws OXException {
+        try {
+            Object content = msg.getContent();
+            if (content instanceof String) {  // Simple text only email
+                String data = getDecoded(msg.getInputStream(), msg.getEncoding());
+                PGPResult result = verifyInlineEmailSignature(normalize(data), userId, cid, getFromAddress(msg));
+                if (result.isVerified()) {  // If verified, clean up content
+                    msg.setContent(getContentInlineBody((String) content, false), msg.getContentType());
+                }
+                EmailSignatureVerificationResult res = new EmailSignatureVerificationResult(result);
+                msg.addHeader("X-Guard-Signature-Result", SignatureResults.toHeader(res));
+            } else {  // Multipart.  Check for any messages for display.  All must have signatures
+                if (content instanceof MimeMultipart) {
+                    MimeMultipart mp = (MimeMultipart) content;
+                    // Create a new messsage to return with the signature markup removed
+                    MimeMultipart newpart = new MimeMultipart(mp.getContentType().contains("alternative") ? "alternative" : "mixed");
+                    for (int i = 0; i < mp.getCount(); i++) {
+                        BodyPart bp = mp.getBodyPart(i);
+                        if (bp.getContent() instanceof String && (bp.getDisposition() == null || bp.getDisposition().contains("inline"))) {
+                            String[] encoding = bp.getHeader("Content-Transfer-Encoding");
+                            String data = "";
+                            if (encoding != null) {
+                                data = normalize(getDecoded(bp.getInputStream(), encoding[0]));
+                            } else {
+                                data = (String) bp.getContent();
+                            }
+                            try {
+                                PGPResult result = verifyInlineEmailSignature(data, userId, cid, getFromAddress(msg));
+                                EmailSignatureVerificationResult res = new EmailSignatureVerificationResult(result);
+                                msg.addHeader("X-Guard-Signature-Result", SignatureResults.toHeader(res));
+                                if (result.isVerified()) {  // If verified, clean up content
+                                    bp.setContent(getContentInlineBody((String) bp.getContent(), false), bp.getContentType());
+                                    newpart.addBodyPart(bp);
+                                } else {
+                                    if (bp.getContentType().contains("text/plain")) {  // If the plaintext fails, we'll just fail the entire thing and return original message
+                                        msg.saveChanges();
+                                        return msg;
+                                    }
+                                }
+                            } catch (OXException ex) {
+                                LOG.error("Problem checking inline signature in email", ex);
+                                return msg;
+                            }
+                        } else {
+                            // If not a text part or attachment, just add it back to the multipart
+                            newpart.addBodyPart(bp);
+                        }
+                    }
+                    msg.setContent(newpart);
+                }
+            }
+            msg.saveChanges();
+            return msg;
+        } catch (MessagingException | IOException e) {
+            return msg;
+        }
+    }
 }
