@@ -1,27 +1,26 @@
 
 package com.openexchange.guard.servlets;
 
+import static com.openexchange.guard.servlets.util.ServletLocaleUtil.getLocaleSaveFor;
 import java.io.IOException;
 import java.io.OutputStreamWriter;
 import java.io.PrintWriter;
 import java.util.List;
 import java.util.Locale;
-import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
-import org.apache.commons.codec.net.URLCodec;
 import com.google.gson.JsonArray;
 import com.google.gson.JsonElement;
 import com.google.gson.JsonObject;
 import com.google.gson.JsonPrimitive;
+import com.openexchange.ajax.AJAXUtility;
 import com.openexchange.exception.Category;
 import com.openexchange.exception.OXException;
 import com.openexchange.guard.common.java.Strings;
 import com.openexchange.guard.common.servlets.utils.ServletUtils;
 import com.openexchange.guard.osgi.Services;
 import com.openexchange.guard.translation.GuardTranslationService;
-import static com.openexchange.guard.servlets.util.ServletLocaleUtil.*;
 
 public class GuardErrorResponseRenderer {
 
@@ -134,8 +133,10 @@ public class GuardErrorResponseRenderer {
         Object[] logArgsArray = e.getLogArgs();
         if (logArgsArray != null) {
             for (Object logArgs : logArgsArray) {
-                JsonPrimitive displayArgParam = new JsonPrimitive(logArgs.toString());
-                errorParams.add(displayArgParam);
+                if(logArgs != null) {
+                    JsonPrimitive displayArgParam = new JsonPrimitive(logArgs.toString());
+                    errorParams.add(displayArgParam);
+                }
             }
         }
         errorObject.add(JSON_ERROR_PARAMS, errorParams);
@@ -204,57 +205,6 @@ public class GuardErrorResponseRenderer {
         }
     }
 
-    /**
-     * Sanitizes specified String input.
-     * <ul>
-     * <li>Do URL decoding until fully decoded
-     * <li>Drop ASCII control characters
-     * <li>Escape using HTML entities
-     * <li>Replace double slashes with single one
-     * </ul>
-     *
-     * @param sInput The input to sanitize, can be <code>null</code> or empty
-     * @return The sanitized input or the original value if <code>null</code> or empty
-     */
-    private String sanitizeParam(String sInput) {
-        if (sInput.isEmpty()) {
-            return sInput;
-        }
-
-        String s = sInput;
-
-        // Do URL decoding until fully decoded
-        {
-            int pos;
-            while ((pos = s.indexOf('%')) >= 0 && pos < s.length() - 1) {
-                try {
-                    s = new URLCodec("UTF-8").decode(s);
-                } catch (org.apache.commons.codec.DecoderException e) {
-                    break;
-                }
-            }
-        }
-
-        // Drop ASCII control characters
-        s = PATTERN_CONTROL.matcher(s).replaceAll("");
-
-        // Escape using HTML entities
-        s = org.apache.commons.lang.StringEscapeUtils.escapeHtml(s);
-
-        // Replace double slashes with single one
-        {
-            final Pattern patternDslash = PATTERN_DSLASH;
-            Matcher matcher = patternDslash.matcher(s);
-            while (matcher.find()) {
-                s = matcher.replaceAll("/");
-                matcher = patternDslash.matcher(s);
-            }
-        }
-
-        // Return result
-        return s;
-    }
-
     /**
      * Renders the given exception to a response
      *
@@ -274,12 +224,11 @@ public class GuardErrorResponseRenderer {
             if (callback != null) {
                 if (callback.indexOf('"') >= 0) {
                     callback = PATTERN_QUOTE.matcher(callback).replaceAll("$1\\\\\"");
-                    //sanitize callback name, because it is injected dynamically
-                    callback = sanitizeParam(callback);
                 }
             } else {
                 callback = actionName;
             }
+            callback = AJAXUtility.sanitizeParam(callback);
 
             PrintWriter writer = null;
             try {
