@@ -54,23 +54,30 @@ import java.util.Arrays;
 import java.util.List;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
+import org.json.JSONObject;
 import com.openexchange.antiabuse.AllowParameters;
 import com.openexchange.exception.OXException;
 import com.openexchange.guard.antiabuse.GuardAntiAbuseService;
+import com.openexchange.guard.cipher.GuardCipherFactoryService;
 import com.openexchange.guard.common.servlets.utils.ServletUtils;
+import com.openexchange.guard.exceptions.GuardAuthExceptionCodes;
 import com.openexchange.guard.exceptions.GuardCoreExceptionCodes;
 import com.openexchange.guard.keymanagement.commons.GuardKeys;
 import com.openexchange.guard.keymanagement.commons.antiabuse.AntiAbuseWrapper;
 import com.openexchange.guard.keymanagement.commons.antiabuse.KeyAntiAbuseWrapper;
 import com.openexchange.guard.keymanagement.commons.antiabuse.UserAntiAbuseWrapper;
+import com.openexchange.guard.keymanagement.services.GuardMasterKeyService;
 import com.openexchange.guard.logging.GuardLogProperties;
 import com.openexchange.guard.osgi.Services;
 import com.openexchange.guard.oxapi.OxCookie;
+import com.openexchange.guard.pgpcore.services.TokenAuthenticationService;
 import com.openexchange.guard.servlets.authentication.AuthenticationDataExtractor;
 import com.openexchange.guard.servlets.authentication.GuardAuthenticationHandler;
 import com.openexchange.guard.servlets.authentication.GuardUserSession;
 import com.openexchange.guard.servlets.authentication.GuestSessionValidator;
 import com.openexchange.guard.servlets.authentication.RestSessionValidator;
+import com.openexchange.guard.servlets.authentication.UserIdentityJsonParser;
+import com.openexchange.guard.servlets.authentication.UserIdentityParameterParser;
 import com.openexchange.guard.user.UserIdentity;
 
 /**
@@ -101,6 +108,21 @@ public abstract class GuardServletAction {
         this.authenticationHandlers = new ArrayList<GuardAuthenticationHandler>(Arrays.asList(authenticationHandlers));
     }
 
+    /**
+     * Internal method to null-check the given {@link UserIdentity}.
+     *
+     * @param userIdentity The {@link UserIdentity} to check.
+     * @param require true, if the method should throw an exception if the given userIdentity is null, false to return null.
+     * @return The given userIdentity
+     * @throws OXException
+     */
+    protected UserIdentity requireOrReturn(UserIdentity userIdentity, boolean require) throws OXException {
+        if (userIdentity == null && require == true) {
+            throw GuardAuthExceptionCodes.AUTH_MISSING.create();
+        }
+        return userIdentity;
+    }
+
     /**
      * Fluent like method to set the authentication handlers
      *
@@ -225,8 +247,8 @@ public abstract class GuardServletAction {
      * @return The password from the given request, or null if no password was found
      * @throws OXException
      */
-    protected String getPassword(HttpServletRequest request) throws OXException {
-        return new AuthenticationDataExtractor().getPassword(request, new OxCookie(request.getCookies()));
+    protected String getPassword(HttpServletRequest request, GuardUserSession userSession) throws OXException {
+        return new AuthenticationDataExtractor().getPassword(request, userSession);
     }
 
     /**
@@ -238,8 +260,8 @@ public abstract class GuardServletAction {
      * @return The password from the given request, or null if no password was found
      * @throws OXException
      */
-    protected String requirePassword(HttpServletRequest request) throws OXException {
-        String password = getPassword(request);
+    protected String requirePassword(HttpServletRequest request, GuardUserSession userSession) throws OXException {
+        String password = getPassword(request, userSession);
         if(password == null) {
             throw GuardCoreExceptionCodes.PARAMETER_MISSING.create("password or auth");
         }
@@ -278,6 +300,56 @@ public abstract class GuardServletAction {
             allowParams);
     }
 
+    /**
+     * Parses a {@link UserIdentity} from the given {@link HttpServletRequest}
+     *
+     * @param request The request to parse the {@link UserIdentity} from.
+     * @return The parsed {@link UserIdentity}, or null if the request did not contain enough information for creating a {@link UserIdentity} object.
+     * @throws OXException
+     */
+    protected UserIdentity getUserIdentityFrom(HttpServletRequest request) throws OXException {
+        return new UserIdentityParameterParser(Services.getService(GuardMasterKeyService.class),
+                                               Services.getService(GuardCipherFactoryService.class),
+                                               request).parse();
+    }
+
+    /**
+     * Parses a {@link UserIdentity} from the given {@link HttpServletRequest}, or throws an Exception if the request does not contain enough information for creating a {@link UserIdentity} object.
+     *
+     * @param request The request to parse the {@link UserIdentity} from.
+     * @return The parsed {@link UserIdentity}
+     * @throws OXException
+     */
+    protected UserIdentity requireUserIdentityFrom(HttpServletRequest request) throws OXException{
+        final UserIdentity userIdentity= getUserIdentityFrom(request);
+        final boolean require = true;
+        return requireOrReturn(userIdentity, require);
+    }
+
+    /**
+     * Parses a {@link UserIdentity} from the given {@link JSONObject}
+     *
+     * @param json The JSON object to parse the {@link UserIdentity} from.
+     * @return The parsed {@link UserIdentity}, or null if the JSON object did not contain enough information for creating a {@link UserIdentity} object.
+     * @throws OXException
+     */
+    protected UserIdentity getUserIdentityFrom(JSONObject json) throws OXException {
+        return new UserIdentityJsonParser(Services.getService(TokenAuthenticationService.class), json).parse();
+    }
+
+    /**
+     * Parses a {@link UserIdentity} from the given {@link JSONObject}, or throws an Exception if the request does not contain enough information for creating a {@link UserIdentity} object.
+     *
+     * @param json The JSON object to parse the {@link UserIdentity} from.
+     * @return The parsed {@link UserIdentity}.
+     * @throws OXException
+     */
+    protected UserIdentity requireUserIdentityFrom(JSONObject json) throws OXException {
+        final UserIdentity userIdentity = new UserIdentityJsonParser(Services.getService(TokenAuthenticationService.class), json).parse();
+        final boolean require = true;
+        return requireOrReturn(userIdentity, require);
+    }
+
     /**
      * Template method which allows implementation of the action execution by subclasses
      *
