@@ -71,11 +71,11 @@ public class AuthenticationDataExtractor {
     private static final String PARAM_AUTH_TOKEN = "auth";
     private static final String PARAM_PLAIN_TEXT_PASSWORD = "password";
 
-    private String getPassword(String authToken, String epassword, String password, OxCookie cookie) throws OXException {
+    private String getPassword(String authToken, String epassword, String password, GuardUserSession userSession) throws OXException {
         //Try to parse the RSA encrypted authentication structure
         if (authToken != null) {
             if (authToken.length() > 20) {
-                UserData data = new UserData(authToken, cookie);
+                UserData data = new UserData(authToken, userSession);
                 if ((data.getUserid() != -1) && (data.getEncr_password() != null)) {
                     return data.getEncr_password();
                 }
@@ -84,9 +84,9 @@ public class AuthenticationDataExtractor {
 
         //Try to parse the AES encrypted password
         if (epassword != null && !epassword.isEmpty()) {
-            String jSessionId = cookie.getJSESSIONID();
-            if(jSessionId != null && !jSessionId.isEmpty()) {
-                return PGPUtils.decodeEPass(epassword, jSessionId);
+            String sessionId = userSession.getGuardSession();
+            if(sessionId != null && !sessionId.isEmpty()) {
+                return PGPUtils.decodeEPass(epassword, sessionId);
             }
         }
 
@@ -105,19 +105,19 @@ public class AuthenticationDataExtractor {
         return ServletUtils.getStringParameter(request, PARAM_E_PASSWORD_ALTERNATIVE);
     }
 
-    public String getPassword(HttpServletRequest request, OxCookie cookie) throws OXException {
-        return getPassword(request.getParameter(PARAM_AUTH_TOKEN), extractEpasswordFromRequest(request), ServletUtils.getStringParameter(request, PARAM_PLAIN_TEXT_PASSWORD), cookie);
+    public String getPassword(HttpServletRequest request, GuardUserSession userSession) throws OXException {
+        return getPassword(request.getParameter(PARAM_AUTH_TOKEN), extractEpasswordFromRequest(request), ServletUtils.getStringParameter(request, PARAM_PLAIN_TEXT_PASSWORD), userSession);
     }
 
-    public String requirePassword(HttpServletRequest request, OxCookie cookie) throws OXException {
-        String password = getPassword(request,cookie);
+    public String requirePassword(HttpServletRequest request, GuardUserSession userSession) throws OXException {
+        String password = getPassword(request, userSession);
         if(password == null) {
             throw GuardCoreExceptionCodes.PARAMETER_MISSING.create("Password or auth missing.");
         }
         return password;
     }
 
-    public String getPassword(JsonObject json, OxCookie cookie) throws OXException {
+    public String getPassword(JsonObject json, GuardUserSession userSession) throws OXException {
         if (json != null) {
             String authToken = null;
             if (json.has(PARAM_AUTH_TOKEN) && !json.get(PARAM_AUTH_TOKEN).isJsonNull()) {
@@ -132,13 +132,13 @@ public class AuthenticationDataExtractor {
             if (json.has(PARAM_PLAIN_TEXT_PASSWORD) && !json.get(PARAM_PLAIN_TEXT_PASSWORD).isJsonNull()) {
                 password = json.get(PARAM_PLAIN_TEXT_PASSWORD).getAsString();
             }
-            return getPassword(authToken, epassword, password, cookie);
+            return getPassword(authToken, epassword, password, userSession);
         }
         return null;
     }
 
-    public String requirePassword(JsonObject json, OxCookie cookie) throws OXException {
-        String password = getPassword(json, cookie);
+    public String requirePassword(JsonObject json, GuardUserSession userSession) throws OXException {
+        String password = getPassword(json, userSession);
         if(password == null) {
             throw GuardCoreExceptionCodes.PARAMETER_MISSING.create("Password or auth missing.");
         }
@@ -146,16 +146,16 @@ public class AuthenticationDataExtractor {
     }
 
 
-    public String getPassword(HttpServletRequest request, JsonObject json, OxCookie cookie) throws OXException {
-        String password = getPassword(request, cookie);
+    public String getPassword(HttpServletRequest request, JsonObject json, GuardUserSession userSession) throws OXException {
+        String password = getPassword(request, userSession);
         if (password == null || password.isEmpty() /* UI seems to send empty password in some cases */) {
-            password = getPassword(json, cookie);
+            password = getPassword(json, userSession);
         }
         return password;
     }
 
-    public String requirePassword(HttpServletRequest request, JsonObject json, OxCookie cookie) throws OXException {
-        String password = getPassword(request, json, cookie);
+    public String requirePassword(HttpServletRequest request, JsonObject json, GuardUserSession userSession) throws OXException {
+        String password = getPassword(request, json, userSession);
         if(password == null) {
             throw GuardCoreExceptionCodes.PARAMETER_MISSING.create("Password or auth missing.");
         }
