@@ -73,6 +73,7 @@ public class DemoServlet extends AbstractGuardServlet {
     private static final Logger logger = LoggerFactory.getLogger(DemoServlet.class);
     private static final long serialVersionUID = -3685385753773851617L;
     private static final String RESET_ACTION = "reset";
+    private static final String RESET_ALL_ACTION = "resetall";
     private static final String RESET_BAD_ACTION = "resetAntiAbuse";
 
     private final HashMap<String,GuardServletAction> servletGetActions;
@@ -84,6 +85,7 @@ public class DemoServlet extends AbstractGuardServlet {
         }
         servletGetActions = new HashMap<String,GuardServletAction>();
         servletGetActions.put(RESET_ACTION, new ResetAction());
+        servletGetActions.put(RESET_ALL_ACTION, new ResetAllAction());
         servletGetActions.put(RESET_BAD_ACTION, new ResetAntiAbuseAction());
     }
 
