@@ -194,24 +194,6 @@ public class FileUploadHandler {
         }
     }
 
-    /**
-     * Parses a {@link FileItemIterator} from the given request with a max. upload size
-     *
-     * @param request The request
-     * @param maxUploadSize The max. allowed upload size
-     * @return The {@link FileItemIterator} parsed from the given request.
-     * @throws FileUploadException
-     * @throws IOException
-     */
-    public FileItemIterator parseIterator(HttpServletRequest request, long maxUploadSize) throws OXException {
-        try {
-            return createFileUpload(maxUploadSize).getItemIterator(request);
-        } catch (FileUploadException e) {
-            throw GuardCoreExceptionCodes.MULTIPART_UPLOAD_ERROR.create(e, e.getMessage());
-        } catch (IOException e) {
-            throw GuardCoreExceptionCodes.IO_ERROR.create(e, e.getMessage());
-        }
-    }
 
     /**
      * Gets a specific InputStream for a {@link FileItem} from a parsed collection of fileItems.
