@@ -57,7 +57,6 @@ import org.apache.commons.fileupload.FileItem;
 import org.apache.commons.io.IOUtils;
 import org.json.JSONException;
 import org.json.JSONObject;
-
 import com.openexchange.exception.OXException;
 
 /**
@@ -85,7 +84,7 @@ public class JsonFileUploadHandler {
      * @param jsonInputStream the input stream to parse the JSON from
      * @return The json object parse from the input stream
      * @throws IOException
-     * @throws JSONException 
+     * @throws JSONException
      */
     public JSONObject getJsonFrom(InputStream jsonInputStream) throws IOException, JSONException {
         ByteArrayOutputStream jsonData = new ByteArrayOutputStream();
@@ -100,7 +99,7 @@ public class JsonFileUploadHandler {
      * @param name The name of the JSON item
      * @return The JSON object, or null if the list does not contain a JSON object
      * @throws IOException
-     * @throws JSONException 
+     * @throws JSONException
      * @throws OXException If mandatory is set to true and the given FileItem was not found.
      */
     public JSONObject getJsonFrom(Collection<FileItem> fileItems, String name) throws IOException, JSONException {
@@ -120,13 +119,14 @@ public class JsonFileUploadHandler {
      * @return The JSON object, or null if the list does not contain a JSON object and mandatory is set to false
      * @throws IOException
      * @throws OXException If mandatory is set to true and the given FileItem was not found.
-     * @throws JSONException 
+     * @throws JSONException
      */
     public JSONObject getJsonFrom(Collection<FileItem> fileItems, String name, boolean mandatory) throws IOException, OXException, JSONException {
-        InputStream jsonStream = fileUploadFactory.getFileItemStreamFrom(fileItems, name, mandatory);
-        if (jsonStream != null) {
-            return getJsonFrom(jsonStream);
+        try(InputStream jsonStream = fileUploadFactory.getFileItemStreamFrom(fileItems, name, mandatory);){
+            if (jsonStream != null) {
+                return getJsonFrom(jsonStream);
+            }
+            return null;
         }
-        return null;
     }
 }
