@@ -62,9 +62,12 @@ import com.openexchange.guard.servlets.keymanagement.actions.CreateKeyPairAction
 import com.openexchange.guard.servlets.keymanagement.actions.DeleteExternalPublicKeyAction;
 import com.openexchange.guard.servlets.keymanagement.actions.DeleteKeyPairAction;
 import com.openexchange.guard.servlets.keymanagement.actions.DownloadKeyAction;
+import com.openexchange.guard.servlets.keymanagement.actions.GetContactKeysAction;
 import com.openexchange.guard.servlets.keymanagement.actions.GetExternalPublicKeysAction;
-import com.openexchange.guard.servlets.keymanagement.actions.GetKeysAction;
 import com.openexchange.guard.servlets.keymanagement.actions.GetKeyAction;
+import com.openexchange.guard.servlets.keymanagement.actions.GetKeysAction;
+import com.openexchange.guard.servlets.keymanagement.actions.GetRecipKeyAction;
+import com.openexchange.guard.servlets.keymanagement.actions.GetSignaturesAction;
 import com.openexchange.guard.servlets.keymanagement.actions.HasKeyAction;
 import com.openexchange.guard.servlets.keymanagement.actions.RevokeKeyAction;
 import com.openexchange.guard.servlets.keymanagement.actions.SetCurrentKeyAction;
@@ -72,7 +75,6 @@ import com.openexchange.guard.servlets.keymanagement.actions.SetExternalKeyInlin
 import com.openexchange.guard.servlets.keymanagement.actions.SetExternalKeyShareModeAction;
 import com.openexchange.guard.servlets.keymanagement.actions.UploadExternalPublicKeyAction;
 import com.openexchange.guard.servlets.keymanagement.actions.UploadKeysAction;
-import com.openexchange.guard.servlets.keymanagement.actions.GetRecipKeyAction;
 
 /**
  * {@link KeymanagementServlet}
@@ -93,12 +95,14 @@ public class KeymanagementServlet extends AbstractGuardServlet {
     private static final String GET_RECIP_KEY_ACTION = "getRecipKey";
     private static final String DELETE_KEY_ACTION = "delete";
     private static final String GET_EXTERNAL_PUBLIC = "getExternalPublicKeys";
+    private static final String GET_CONTACT_KEYS = "getContactKeys";
     private static final String UPLOAD_EXTERNAL_PUBLIC = "uploadExternalPublicKey";
     private static final String DELETE_EXTERNAL_PUBLIC = "deleteExternalPublicKey";
     private static final String SHARE_EXTERNAL_PUBLIC = "shareExternalPublicKey";
     private static final String INLINE_EXTERNAL_PUBLIC = "inlineExternalPublicKey";
     private static final String ADD_USER_ID = "addUserId";
     private static final String REVOKE_KEY = "revoke";
+    private static final String GET_SIGNATURES = "getSignatures";
     private final HashMap<String, GuardServletAction> getActions;
     private final HashMap<String, GuardServletAction> postActions;
     private final HashMap<String, GuardServletAction> putActions;
@@ -117,6 +121,8 @@ public class KeymanagementServlet extends AbstractGuardServlet {
         getActions.put(GET_RECIP_KEY_ACTION, new GetRecipKeyAction().setAuthenticationHandler(sessionAuthenticationHandler));
         getActions.put(GET_KEYS_ACTION, new GetKeysAction().setAuthenticationHandler(sessionAuthenticationHandler));
         getActions.put(GET_EXTERNAL_PUBLIC, new GetExternalPublicKeysAction().setAuthenticationHandler(sessionAuthenticationHandler));
+        getActions.put(GET_CONTACT_KEYS, new GetContactKeysAction().setAuthenticationHandler(sessionAuthenticationHandler));
+        getActions.put(GET_SIGNATURES, new GetSignaturesAction().setAuthenticationHandler(sessionAuthenticationHandler));
 
         //POST
         postActions = new HashMap<String, GuardServletAction>();
