@@ -63,6 +63,7 @@ import com.openexchange.guard.keymanagement.services.GuardKeyService;
 import com.openexchange.guard.osgi.Services;
 import com.openexchange.guard.servlets.GuardServletAction;
 import com.openexchange.guard.servlets.authentication.GuardUserSession;
+import com.openexchange.guard.user.UserIdentity;
 
 /**
  * {@link AddUserIDAction} adds a new ID to a user's key
@@ -82,19 +83,19 @@ public class AddUserIDAction extends GuardServletAction {
         final long keyId = ServletUtils.getLongParameter(request, Parameters.PARAM_KEYID, mandatory);
         final String name = ServletUtils.getStringParameter(request, Parameters.PARAM_NAME, mandatory);
         final String email = new EmailValidator().assertInput(ServletUtils.getStringParameter(request, Parameters.PARAM_EMAIL, mandatory), Parameters.PARAM_EMAIL);
-        final String password = ServletUtils.getStringParameter(request, Parameters.PARAM_PASSWORD, mandatory);
+        final UserIdentity userIdentity = requireUserIdentityFrom(request);
         final String newUserId = name + " <" + email + ">";
         final GuardKeyService keyService = Services.getService(GuardKeyService.class);
-        final GuardKeys keys = keyService.getKeys(userSession.getUserId(), userSession.getContextId(), keyId);
+        final GuardKeys keys = keyService.getKeys(userSession.getGuardUserId(), userSession.getGuardContextId(), keyId);
 
         if(keys != null) {
             //Adding the user ID in a Brute Force protected way
-            AntiAbuseWrapper bruteForceProtection = getAntiAbuseWrapper(AntiAbuseUtils.getAllowParameters(request, userSession.getUserId(), userSession.getContextId(), password));
+            AntiAbuseWrapper bruteForceProtection = getAntiAbuseWrapper(AntiAbuseUtils.getAllowParameters(request, userSession.getUserId(), userSession.getContextId(), new String(userIdentity.getPassword())));
             bruteForceProtection.doAction(new AntiAbuseAction<Void>() {
 
                 @Override
                 public Void doAction() throws OXException {
-                    keyService.addUserId(keys, newUserId, password);
+                    keyService.addUserId(keys, newUserId, new String(userIdentity.getPassword()));
                     return null;
                 }});
         }
