@@ -49,6 +49,9 @@
 
 package com.openexchange.guard.servlets.keymanagement.actions;
 
+import static com.openexchange.guard.common.util.JsonUtil.emptyJsonString;
+import static com.openexchange.guard.servlets.keymanagement.actions.Parameters.PARAM_KEYID;
+import static com.openexchange.guard.servlets.keymanagement.actions.Parameters.PARAM_KEY_TYPE;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 import com.openexchange.exception.OXException;
@@ -64,8 +67,7 @@ import com.openexchange.guard.osgi.Services;
 import com.openexchange.guard.servlets.GuardServletAction;
 import com.openexchange.guard.servlets.authentication.GuardUserSession;
 import com.openexchange.guard.servlets.keymanagement.responses.GuardKeyInfoResponse;
-import static com.openexchange.guard.common.util.JsonUtil.*;
-import static com.openexchange.guard.servlets.keymanagement.actions.Parameters.*;
+import com.openexchange.guard.user.UserIdentity;
 
 /**
  * {@link GetKeyAction} returns a specific key for a user, or the "current" key-
@@ -92,13 +94,13 @@ public class GetKeyAction extends GuardServletAction {
      * @throws OXException if the user provided a bad password or the account is locked due.
      */
     private GuardKeyInfoResponse createProtectedResponse(final HttpServletRequest request, final GuardUserSession userSession, final GuardKeys keys, final boolean omitPublicKey) throws Exception {
-        final String password = ServletUtils.getStringParameter(request, Parameters.PARAM_PASSWORD, true);
-        AntiAbuseWrapper antiAbuseProtection = getAntiAbuseWrapper(keys, AntiAbuseUtils.getAllowParameters(request, userSession.getUserId(),  userSession.getContextId(), password));
+        final UserIdentity userIdentity = requireUserIdentityFrom(request);
+        AntiAbuseWrapper antiAbuseProtection = getAntiAbuseWrapper(keys, AntiAbuseUtils.getAllowParameters(request, userSession.getUserId(),  userSession.getContextId(), new String(userIdentity.getPassword())));
         return antiAbuseProtection.doAction(new AntiAbuseAction<GuardKeyInfoResponse>() {
 
             @Override
             public GuardKeyInfoResponse doAction() throws Exception {
-                return new GuardKeyInfoResponse(keys, password, omitPublicKey);
+                return new GuardKeyInfoResponse(keys, new String(userIdentity.getPassword()), omitPublicKey);
             }
         });
     }
@@ -114,10 +116,10 @@ public class GetKeyAction extends GuardServletAction {
     protected GuardKeys getKey(GuardUserSession userSession, Long keyId) throws OXException {
         GuardKeyService keyService = Services.getService(GuardKeyService.class);
         GuardKeys key = keyId == null ?
-               keyService.getKeys(userSession.getUserId(), userSession.getContextId()) :
+               keyService.getKeys(userSession.getGuardUserId(), userSession.getGuardContextId()) :
                keyService.getKeys(keyId);
         //Only return the queried key if it belongs to the user
-        return (key != null && key.getContextid() == userSession.getContextId() && key.getUserid() == userSession.getUserId()) ? key : null;
+        return (key != null && key.getContextid() == userSession.getGuardContextId() && key.getUserid() == userSession.getGuardUserId()) ? key : null;
     }
 
     /**
