@@ -63,6 +63,7 @@ import com.openexchange.guard.keymanagement.services.RevocationReason;
 import com.openexchange.guard.osgi.Services;
 import com.openexchange.guard.servlets.GuardServletAction;
 import com.openexchange.guard.servlets.authentication.GuardUserSession;
+import com.openexchange.guard.user.UserIdentity;
 
 /**
  * {@link RevokeKeyAction} marks a key ring as "revoked"
@@ -81,14 +82,14 @@ public class RevokeKeyAction extends GuardServletAction {
     protected void doActionInternal(HttpServletRequest request, HttpServletResponse response, GuardUserSession userSession) throws Exception {
         final boolean mandatory = true;
         final long keyId = ServletUtils.getLongParameter(request, Parameters.PARAM_KEYID, mandatory);
-        final String password = ServletUtils.getStringParameter(request, Parameters.PARAM_PASSWORD, mandatory);
+        final UserIdentity userIdentity = requireUserIdentityFrom(request);
         final String reason = ServletUtils.getStringParameter(request, Parameters.PARAM_REASON);
         final GuardKeyService keyService = Services.getService(GuardKeyService.class);
-        final GuardKeys key = keyService.getKeys(userSession.getUserId(), userSession.getContextId(), keyId);
+        final GuardKeys key = keyService.getKeysBySubKeyId(userSession.getGuardUserId(), userSession.getGuardContextId(), keyId);
         if (key != null) {
 
             //Revoke the key in a brute force protected way
-            AntiAbuseWrapper bruteForceProtection = getAntiAbuseWrapper(key, AntiAbuseUtils.getAllowParameters(request, userSession.getUserId(),  userSession.getContextId(), password));
+            AntiAbuseWrapper bruteForceProtection = getAntiAbuseWrapper(key, AntiAbuseUtils.getAllowParameters(request, userSession.getUserId(),  userSession.getContextId(), new String(userIdentity.getPassword())));
             bruteForceProtection.doAction(new AntiAbuseAction<Void>() {
 
                 @Override
@@ -103,7 +104,7 @@ public class RevokeKeyAction extends GuardServletAction {
                         }
                     }
 
-                    keyService.revokeKey(key, revocationReason, password);
+                    keyService.revokeKey(key, keyId, revocationReason, new String(userIdentity.getPassword()));
                     return null;
                 }
             });
