@@ -67,26 +67,31 @@ public class PublicKeyInfoResponse {
 
     private final PGPPublicKey key;
     private final boolean hasPrivateaKey;
+    private final boolean usedForEncryption;
 
     /**
      * Initializes a new {@link PublicKeyInfoResponse}.
      * @param key
+     * @param usedForEncryption Whether or not Guard is considering using this key for encryption.
      */
-    public PublicKeyInfoResponse(PGPPublicKey key) {
-        this(key, false);
+    public PublicKeyInfoResponse(PGPPublicKey key, boolean usedForEncryption) {
+        this(key, false, usedForEncryption);
     }
 
     /**
      * Initializes a new {@link PublicKeyInfoResponse}.
      * @param key
+     * @param hasPrivateaKey Whether or not this key has a corresponding private key
+     * @param usedForEncryption Whether or not Guard is considering using this key for encryption.
      */
-    public PublicKeyInfoResponse(PGPPublicKey key, boolean hasPrivateaKey) {
+    public PublicKeyInfoResponse(PGPPublicKey key, boolean hasPrivateaKey, boolean usedForEncryption) {
         this.key = key;
         this.hasPrivateaKey = hasPrivateaKey;
+        this.usedForEncryption = usedForEncryption;
     }
 
-    public long getId() {
-        return this.key.getKeyID();
+    public String getId() {
+        return Long.toString(this.key.getKeyID());
     }
 
     public boolean isMasterKey() {
@@ -118,6 +123,10 @@ public class PublicKeyInfoResponse {
         return PGPKeysUtil.isEncryptionKey(key);
     }
 
+    public boolean isUsedForEncryption() {
+       return this.usedForEncryption;
+    }
+
     public boolean isRevoked() {
         return key.hasRevocation();
     }
@@ -133,11 +142,10 @@ public class PublicKeyInfoResponse {
     public PublicKeyImageResponse[] getImages() {
         ArrayList<PublicKeyImageResponse> ret = new ArrayList<PublicKeyImageResponse>();
         Iterator<PGPUserAttributeSubpacketVector> userAttributes = this.key.getUserAttributes();
-        int imageCounter = 0;
         while (userAttributes.hasNext()) {
             ImageAttribute imageAttribute = userAttributes.next().getImageAttribute();
             if (imageAttribute != null && imageAttribute.getType() == 1) {
-                ret.add(new PublicKeyImageResponse(imageCounter++, imageAttribute));
+                ret.add(new PublicKeyImageResponse(imageAttribute));
             }
         }
         return ret.toArray(new PublicKeyImageResponse[ret.size()]);
