@@ -55,8 +55,6 @@ import javax.servlet.http.HttpServletResponse;
 import com.openexchange.guard.servlets.AbstractGuardServlet;
 import com.openexchange.guard.servlets.GuardServletAction;
 import com.openexchange.guard.servlets.authentication.OXGuardSessionAuthenticationHandler;
-import com.openexchange.guard.servlets.keymanagement.actions.SetExternalKeyInlineModeAction;
-import com.openexchange.guard.servlets.keymanagement.actions.SetExternalKeyShareModeAction;
 
 /**
  * Provides general PGP functionality
@@ -68,22 +66,9 @@ public class PGPServlet extends AbstractGuardServlet{
 
     private static final long serialVersionUID = -5662408424447605671L;
     private static final String GET_EXTERNAL_PUBLIC_KEYLIST_ACTION = "getpublist";
-    private static final String GET_USER_KEYS_ACTION = "getuserkeys";
     private static final String GET_VERIFY_SIGNATURES_ACTION = "getsignatures";
     private static final String GET_PUBLIC_KEY_DETAILS_ACTION = "getpubdetail";
-    private static final String GET_KEY_IMAGE_ACTION = "getkeyimage";
-    private static final String GET_PRIVATE_KEY_ACTION = "getprivkeybyid";
-    private static final String GET_SET_CURRENT_KEY_ACTION = "makecurrent";
-    private static final String DELETE_EXTERNAL_PUBLIC_KEY_ACTION = "share";
-    private static final String PUT_EXTERNAL_KEY_SHARE_MODE_ACTION = "share";
-    private static final String PUT_EXTERNAL_KEY_INLINE_MODE_ACTION = "inline";
-    private static final String PUT_SAVE_DECODED_ATTACHMENT_ACTION = "savedecodedattachment";
     private static final String POST_UPLOAD_EXTERNAL_PUBLIC_KEYS_ACTION = "uploadkeys";
-    private static final String POST_UPLOAD_KEYS_ACTION = "uploadprivate";
-    private static final String POST_DELETE_KEY_RING_ACTION = "deleteprivkey";
-    private static final String POST_DELETE_PUBLIC_KEY_ACTION = "deletelocalpublic";
-    private static final String POST_REVOKE_PRIVATE_KEY_ACTION = "revokeprivkey";
-    private static final String POST_ADD_UID_ACTION = "adduserid";
 
     private final HashMap<String, GuardServletAction> getActions;
     private final HashMap<String, GuardServletAction> deleteActions;
@@ -97,32 +82,19 @@ public class PGPServlet extends AbstractGuardServlet{
         //GET
         getActions = new HashMap<String,GuardServletAction>();
         getActions.put(GET_EXTERNAL_PUBLIC_KEYLIST_ACTION, new GetExternalPublicKeyListAction().setAuthenticationHandler(sessionAuthenticationHandler));
-        getActions.put(GET_USER_KEYS_ACTION, new GetUserKeysAction().setAuthenticationHandler(sessionAuthenticationHandler));
         getActions.put(GET_VERIFY_SIGNATURES_ACTION, new VerifyKeySignaturesAction().setAuthenticationHandler(sessionAuthenticationHandler));
         getActions.put(GET_PUBLIC_KEY_DETAILS_ACTION, new GetPublicKeyDetailsAction().setAuthenticationHandler(sessionAuthenticationHandler));
-        getActions.put(GET_KEY_IMAGE_ACTION, new GetKeyImageAction().setAuthenticationHandler(sessionAuthenticationHandler));
-        getActions.put(GET_PRIVATE_KEY_ACTION, new GetPrivateKeyAction().setAuthenticationHandler(sessionAuthenticationHandler));
-        getActions.put(GET_SET_CURRENT_KEY_ACTION, new SetCurrentKeyAction().setAuthenticationHandler(sessionAuthenticationHandler));
 
         //DELETE
         deleteActions = new HashMap<String,GuardServletAction>();
-        deleteActions.put(DELETE_EXTERNAL_PUBLIC_KEY_ACTION, new DeleteExternalPublicKeyAction().setAuthenticationHandler(sessionAuthenticationHandler));
 
         //PUT
         putActions = new HashMap<String,GuardServletAction>();
-        putActions.put(PUT_EXTERNAL_KEY_SHARE_MODE_ACTION, new SetExternalKeyShareModeAction().setAuthenticationHandler(sessionAuthenticationHandler));
-        putActions.put(PUT_EXTERNAL_KEY_INLINE_MODE_ACTION, new SetExternalKeyInlineModeAction().setAuthenticationHandler(sessionAuthenticationHandler));
-        putActions.put(PUT_SAVE_DECODED_ATTACHMENT_ACTION, new SaveDecodedAttachmentAction().setAuthenticationHandler(sessionAuthenticationHandler));
 
         //POST
         postActions = new HashMap<String,GuardServletAction>();
         postActions.put(POST_UPLOAD_EXTERNAL_PUBLIC_KEYS_ACTION, new UploadPublicKeysAction().setAuthenticationHandler(sessionAuthenticationHandler));
-        postActions.put(POST_UPLOAD_KEYS_ACTION, new UploadKeysAction().setAuthenticationHandler(sessionAuthenticationHandler));
-        postActions.put(POST_DELETE_KEY_RING_ACTION, new DeleteKeyRingAction().setAuthenticationHandler(sessionAuthenticationHandler));
-        postActions.put(POST_DELETE_PUBLIC_KEY_ACTION, new DeletePublicKeyAction().setAuthenticationHandler(sessionAuthenticationHandler));
-        postActions.put(POST_REVOKE_PRIVATE_KEY_ACTION, new RevokePrivateKeyAction().setAuthenticationHandler(sessionAuthenticationHandler));
-        postActions.put(POST_ADD_UID_ACTION, new KeyAddUserIdAction().setAuthenticationHandler(sessionAuthenticationHandler));
-    }
+     }
 
     @Override
     protected void doGet(HttpServletRequest request, HttpServletResponse response) {
