@@ -58,11 +58,11 @@ import org.apache.commons.fileupload.FileItem;
 import com.openexchange.guard.common.servlets.utils.ServletUtils;
 import com.openexchange.guard.configuration.GuardConfigurationService;
 import com.openexchange.guard.osgi.Services;
-import com.openexchange.guard.pgpcore.commons.PGPSignatureVerificationResult;
 import com.openexchange.guard.pgpcore.services.PGPSigningService;
 import com.openexchange.guard.servlets.GuardServletAction;
 import com.openexchange.guard.servlets.authentication.GuardUserSession;
 import com.openexchange.guard.servlets.fileupload.FileUploadHandler;
+import com.openexchange.pgp.core.PGPSignatureVerificationResult;
 
 /**
  * {@link VerifyAction}
