@@ -53,9 +53,6 @@ import java.util.HashMap;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 import com.openexchange.exception.OXException;
-import com.openexchange.guard.configuration.GuardConfigurationService;
-import com.openexchange.guard.configuration.GuardProperty;
-import com.openexchange.guard.osgi.Services;
 import com.openexchange.guard.servlets.AbstractGuardServlet;
 import com.openexchange.guard.servlets.GuardErrorResponseRenderer;
 import com.openexchange.guard.servlets.GuardServletAction;
@@ -71,16 +68,9 @@ import com.openexchange.guard.servlets.authentication.OXGuardSessionAuthenticati
 public class PGPMailServlet extends AbstractGuardServlet {
 
     private static final long serialVersionUID = -3402143663178340210L;
-    private static final String GET_PUBLIC_KEY_BY_MAIL_ACTION = "getkey";
-    private static final String GET_PUBLIC_KEY_BY_ID_ACTION = "getkeybyid";
     private static final String GET_VERIFY_EMAIL_SIGNATURE = "verify";
-    private static final String GET_ATTACHMENT_BY_NAME_ACTION = "getattach";
-    private static final String GET_ATTACHMENT_BY_ID_ACTION = "getattachcid";
-    private static final String GET_INLINE_ATTACHMENT_ACTION = "getinlineattach";
     private static final String GET_PUBLIC_KEY_FROM_ATTACHMENT_ACTION = "savepublicattach";
     private static final String GET_IMPORT_VCARD_FROM_ATTACHMENT_ACTION_ = "importvcard";
-    private static final String POST_GET_PGPMAIL_ACTION = "getmail";
-    private static final String POST_GET_PGPMAIL_INLINE_ACTION = "getinline";
 
     private static final String POST_PROCESS_INCOMING_MIME = "process_mime";
     private static final String POST_VERIFY_MESSAGE = "verify";
@@ -100,19 +90,12 @@ public class PGPMailServlet extends AbstractGuardServlet {
 
         //GET
         getActions = new HashMap<String, GuardServletAction>();
-        getActions.put(GET_PUBLIC_KEY_BY_MAIL_ACTION, new GetPublicKeyByMailAction().setAuthenticationHandler(userSessionAuthenticationHandler));
-        getActions.put(GET_PUBLIC_KEY_BY_ID_ACTION, new GetPublicKeyAction().setAuthenticationHandler(userSessionAuthenticationHandler));
         getActions.put(GET_VERIFY_EMAIL_SIGNATURE, new VerifyEmailSignatureAction().setAuthenticationHandler(userSessionAuthenticationHandler));
-        getActions.put(GET_ATTACHMENT_BY_NAME_ACTION, new GetAttachmentByNameAction().setAuthenticationHandler(userSessionAuthenticationHandler));
-        getActions.put(GET_ATTACHMENT_BY_ID_ACTION, new GetAttachmentByIdAction().setAuthenticationHandler(userSessionAuthenticationHandler));
-        getActions.put(GET_INLINE_ATTACHMENT_ACTION, new GetInlineAttachmentAction().setAuthenticationHandler(userSessionAuthenticationHandler));
         getActions.put(GET_PUBLIC_KEY_FROM_ATTACHMENT_ACTION, new GetPublicKeyFromAttachmentAction().setAuthenticationHandler(userSessionAuthenticationHandler));
         getActions.put(GET_IMPORT_VCARD_FROM_ATTACHMENT_ACTION_, new ImportVCardAction().setAuthenticationHandler(userSessionAuthenticationHandler));
 
         //POST
         postActions = new HashMap<String, GuardServletAction>();
-        postActions.put(POST_GET_PGPMAIL_ACTION, new GetPGPMailAction().setAuthenticationHandler(userSessionAuthenticationHandler));
-        postActions.put(POST_GET_PGPMAIL_INLINE_ACTION, new GetPGPMailInlineAction().setAuthenticationHandler(userSessionAuthenticationHandler));
         postActions.put(POST_PROCESS_INCOMING_MIME,
             new MimeEmailAction()
                 .setAuthenticationHandler(basicAuthAuthenticationHandler)
@@ -123,18 +106,12 @@ public class PGPMailServlet extends AbstractGuardServlet {
                 .setErrorResponseRenderer(new GuardErrorResponseRenderer(HttpServletResponse.SC_INTERNAL_SERVER_ERROR)));
         postActions.put(POST_VERIFY_MESSAGE,
             new VerifyMimeEmailAction()
+                .setAuthenticationHandler(basicAuthAuthenticationHandler)
                 .setErrorResponseRenderer(new GuardErrorResponseRenderer(HttpServletResponse.SC_INTERNAL_SERVER_ERROR)));
 
 
     }
 
-    private BasicAuthServletAuthenticationHandler createBasicAuthHandler() throws OXException {
-        //Protecting the servlet's actions with BASIC-AUTH
-        GuardConfigurationService configService = Services.getService(GuardConfigurationService.class);
-        String restApiUsername = configService.getProperty(GuardProperty.restApiUsername);
-        String restApiPassword = configService.getProperty(GuardProperty.restApiPassword);
-        return new BasicAuthServletAuthenticationHandler(restApiUsername, restApiPassword);
-    }
 
     /* (non-Javadoc)
      * @see javax.servlet.http.HttpServlet#doGet(javax.servlet.http.HttpServletRequest, javax.servlet.http.HttpServletResponse)
