@@ -51,19 +51,14 @@ package com.openexchange.guard.servlets.pgpmail;
 
 import java.io.IOException;
 import java.io.InputStream;
-import java.io.UnsupportedEncodingException;
 import java.util.Collection;
-
 import javax.mail.MessagingException;
 import javax.mail.internet.MimeMessage;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
-
 import org.apache.commons.fileupload.FileItem;
 import org.apache.commons.fileupload.FileUploadException;
 import org.json.JSONException;
-import org.json.JSONObject;
-
 import com.openexchange.exception.OXException;
 import com.openexchange.guard.common.servlets.utils.ServletUtils;
 import com.openexchange.guard.configuration.GuardConfigurationService;
@@ -72,12 +67,9 @@ import com.openexchange.guard.mime.services.GuardParsedMimeMessage;
 import com.openexchange.guard.osgi.Services;
 import com.openexchange.guard.pgp.signing.GuardEmailSigningService;
 import com.openexchange.guard.pgp.signing.impl.GuardEmailSigningServiceImpl;
-import com.openexchange.guard.pgpcore.services.TokenAuthenticationService;
 import com.openexchange.guard.servlets.GuardServletAction;
 import com.openexchange.guard.servlets.authentication.GuardUserSession;
 import com.openexchange.guard.servlets.fileupload.FileUploadHandler;
-import com.openexchange.guard.servlets.fileupload.JsonFileUploadHandler;
-import com.openexchange.guard.user.UserIdentity;
 
 /**
  * {@link VerifyMimeEmailAction}
@@ -90,7 +82,7 @@ public class VerifyMimeEmailAction extends GuardServletAction  {
 	private static final String MESSAGE_FIELD_NAME = "file";
 
     private GuardParsedMimeMessage parseMimeMessage(HttpServletRequest request, InputStream message, int userId, int contextId) throws MessagingException, JSONException, OXException, FileUploadException, IOException {
-        return ParseIncoming.parse(request, null, message, userId, contextId, null);
+        return ParseIncoming.parse(request, null, message, userId, contextId, null, null, false);
     }
 
     /* (non-Javadoc)
@@ -103,7 +95,7 @@ public class VerifyMimeEmailAction extends GuardServletAction  {
         final boolean mandatory = true;
         final int userId = positiveValidator.assertInput(ServletUtils.getIntParameter(request, "user", mandatory), "user");
         final int contextId = positiveValidator.assertInput(ServletUtils.getIntParameter(request, "context", mandatory), "context");
-        
+
         FileUploadHandler fileUploadHandler = new FileUploadHandler(Services.getService(GuardConfigurationService.class));
         Collection<FileItem> items = fileUploadHandler.parseItems(request);
         try(InputStream messageStream = fileUploadHandler.getFileItemStreamFrom(items, MESSAGE_FIELD_NAME, true);){
