@@ -91,7 +91,7 @@ public class PasswordReseter {
         JsonObject mail = mailCreatorService.getResetEmail(secondaryEmail, mailCreatorService.getFromAddress(emailToRest, emailToRest, userid, cid), newpass, language, templid, "", userid, cid);
 
         GuardNotificationService guardNotificationService = Services.getService(GuardNotificationService.class);
-        guardNotificationService.send(mail);
+        guardNotificationService.send(mail, null);
 
         keyService.resetPassword(emailToRest, newpass);
     }
@@ -116,8 +116,11 @@ public class PasswordReseter {
             boolean secondary = true;
 
             //First check if the user has secondary email address wich we can use
-            String rc = Services.getService(GuardMasterKeyService.class).getMasterKey().getRC();
-            String email = cipherService.decrypt(encr_answer, rc, "e");
+            String email = null;
+            if (key.getQuestion() != null && key.getQuestion().equals("e")) {
+                String rc = Services.getService(GuardMasterKeyService.class).getMasterKey().getRC();
+                email = cipherService.decrypt(encr_answer, rc, "e");
+            }
 
             //Fall back to primary email address if no secondary email address was found for the user
             if (email == null || email.isEmpty()) {
