@@ -57,6 +57,7 @@ import com.openexchange.guard.exceptions.GuardCoreExceptionCodes;
 import com.openexchange.guard.guestupgrade.GuestUpgradeService;
 import com.openexchange.guard.keymanagement.services.GuardKeyService;
 import com.openexchange.guard.osgi.Services;
+import com.openexchange.guard.secondfactor.SecondFactorService;
 import com.openexchange.guard.support.PasswordReseter.EmailTarget;
 
 /**
@@ -107,13 +108,20 @@ public class SupportServiceImpl implements SupportService {
 
     @Override
     public void removePin(String email) throws OXException {
+        // Pre 2.10, can be removed soon
         GuardKeyService keyService = Services.getService(GuardKeyService.class);
         keyService.removePin(email);
+        // 2.10 and post
+        EmailStorage ogEmailStorage = Services.getService(EmailStorage.class);
+        Email ogEmail = ogEmailStorage.getByEmail(email);
+        SecondFactorService secondFactor = Services.getService(SecondFactorService.class);
+        secondFactor.removeSecondFactor(ogEmail.getUserId(), ogEmail.getContextId());
+
     }
 
     @Override
-    public void upgradeGuestAccount(String email) throws OXException {
+    public void upgradeGuestAccount(String email, String userid, String cid) throws OXException {
         GuestUpgradeService guestUpgradeService = Services.getService(GuestUpgradeService.class);
-        guestUpgradeService.upgrade(email);
+        guestUpgradeService.upgrade(email, userid, cid);
     }
 }
